********************************************************************************************************************
* ILE: BASELINE VARIABLE CONSTRUCTION CODE
*********************************************************************************************************************

/* CONTENT **********************************************

1. Directory information

2. Demographics and health
3. Skills and education
4. Household and networks
5. Cash and savings
6. Psychosocial
7. Conscientiousness
8. Employment / Income generating activities
9. Formal employment
10. Wealth and consumption
11. Cognitive
12. Non-cognitive skills
13. Time and risk
14. Agression and abuse
15. Income risk
16. IBM 

*********************************************************/

clear
clear matrix
set mem 500m
set more off
tempfile tempdata
set matsize 800

// 1. DIRECTORY INFORMATION //

	//a. Select database
		use "$ILEdata\ILE.bl_clean.dta"
		
// 2. DEMOGRAPHICS & HEALTH (Section 2) //

		// RECODE GENDER VARS: GENERATES NEW VARIABLES (MALE AND FEMALE DUMMIES)
				tab gender, mi
				recode gender (1=1)(2=0)(else=.c), gen(male) lab(yesno)
				lab var male "Male respondent"
				recode gender (2=1)(1=0)(else=.c), gen(female) lab(yesno)
				lab var female "Female respondent"

		// ASSUMING AGE FOR "AGE RANGE"
				replace exactage=18 if agerange=="A"
				replace exactage=23 if agerange=="B"
				replace exactage=28 if agerange=="C"
				replace exactage=33 if agerange=="D"
				replace exactage=38 if agerange=="E"
				replace exactage=43 if agerange=="F"
				replace exactage=48 if agerange=="G"
				replace exactage=53 if agerange=="H"
				replace exactage=58 if agerange=="I"
				replace exactage=65 if agerange=="J"
				
		// SQUARED AGE VARIABLE
			tab exactage , mi
			gen age2=(exactage)*(exactage)
			lab var age2 "Age, squared"
				
			tab exactage , mi
			gen age3=(exactage)*(exactage)*(exactage)
			lab var age3 "Age, cubed"				
			
			tab exactage , mi
			gen age4=(exactage)*(exactage)*(exactage)*(exactage)
			lab var age4 "Age, quartic"

		// RELIGOUS AFFILIATION DUMMIES
			tab religion , mi
			gen r_orthodox=cond(religion==2,1,0)
			lab var r_orthodox "Religion: Orthodox"
			gen r_muslim=cond(religion==3,1,0)
			lab var r_muslim "Religion: Muslim"
			gen r_christian=cond(religion==2 | religion==4 | religion==5 | religion==6,1,0)
			lab var r_christian "Religion: Christian (any)"

		// LANGUAGE/MOTHER TONGUE DUMMIES
				tab tongue, mi
				gen la_amharic=cond(tongue==1,1,0)
				lab var la_amharic "Mother tongue: Amharic"
				gen la_oromifa=cond(tongue==2,1,0)
				lab var la_oromifa "Mother tongue: Oromifa"

		// LITERACY VARIABLES
				foreach x in lit othlang1 othlang2 othlang3 othlit1 othlit2 othlit3 {
				tab `x', mi
				}

				// dummy for highly literate in mother tongue
					gen lit_high=cond(lit==1,1,0)
					lab var lit_high "Reads and writes very well in mother tongue"

				// recode: level of literacy (generates new var "lit_level")
					recode lit (1 = 3 "Very well") (2 = 2 "Somewhat well") (3=1 "Little") (4=0 "Not at all"), ///
					gen(lit_level) lab(well2)
					lab var lit_level "Reading/writing level for mother tongue: 0=not at all, 4=very well"

				// dummy for literacy in any language (somewhat well or very well)
					gen lit_any=cond(lit==1 | lit==2 | othlit1!=13,1,0)
					lab var lit_any "Reads and writes at least somewhat well in at least one language"
					
				// dummy for illiteracy
					gen illit = (lit!=1 & lit!=2 ) if lit!=.
					la var illit "Unable to read or write well in any language"

		// PHYSICAL HEALTH VARIABLES
/*
			foreach x in walk2km carry20liters dayactiv workout workbench {
				tab `x', mi
				}

				*recode: level of difficulty in conducting physical tasks (generates new var with prefix "h_")
					recode  walk2km carry20liters dayactiv workout workbench ///
					(1=0 "Easily") (2=1 "Slight difficulty") (3=2 "Great difficulty") (4=3 "Unable"), pre(h_) lab(difficulty2)
					lab var h_walk2km	"Ability to walk 2 kilometers: 0=Easily,3=Unable"
					lab var h_carry20liters	"Ability to carry 20 litres of water for 20 meters: 0=Easily,3=Unable"
					lab var h_dayactiv "Ability to carry out usual daily activities: 0=Easily,3=Unable" 
					lab var h_workout	"Ability to work on feet outdoors for full day: 0=Easily,3=Unable"
					lab var h_workbench "Ability to stand at workbench/assembly line for 6-8 hrs: 0=Easily,3=Unable"
			
				*additive health index and dummy for having any health problem
					egen healthproblems=rowtotal(h_walk2km h_carry20liters h_dayactiv h_workout h_workbench ), m
					lab var healthproblems "Additive health: 0=no problems, 15=unable to complete any task"
					gen anyhealthproblem=cond(healthproblems!=0,1,0) 
					replace anyhealthproblem=. if healthproblems==.
					lab var anyhealthproblem "Mentioned as least one health problem"
*/				
				*recode: level of difficulty in conducting physical tasks (generates new var with prefix "h_")
					recode  walk2km carry20liters dayactiv workout workbench ///
					(1=3 "Easily") (2=2 "Slight difficulty") (3=1 "Great difficulty") (4=0 "Unable"), pre(h_) lab(difficulty2)
					lab var h_walk2km	"Ability to walk 2 kilometers: 3=Easily,0=Unable"
					lab var h_carry20liters	"Ability to carry 20 litres of water for 20 meters: 3=Easily,0=Unable"
					lab var h_dayactiv "Ability to carry out usual daily activities: 3=Easily,0=Unable" 
					lab var h_workout	"Ability to work on feet outdoors for full day: 3=Easily,0=Unable"
					lab var h_workbench "Ability to stand at workbench/assembly line for 6-8 hrs: 3=Easily,0=Unable"
					
				*additive health index and dummy for having any health problem
					egen healthproblems=rowtotal(h_walk2km h_carry20liters h_dayactiv h_workout h_workbench ), m
					lab var healthproblems "Additive health: 15=no problems, 0=unable to complete any task"
					gen anyhealthproblem=cond(healthproblems!=0,1,0) 
					replace anyhealthproblem=. if healthproblems==.
					lab var anyhealthproblem "Mentioned at least one health problem"
				
				// DUMMY FOR HAVING 2 or MORE SERIOS HEALTH PROBLEMS
					qui gen temp = 0
					foreach x in walk2km carry20liters dayactiv workout workbench {
						replace temp = temp + 1 if `x'==3 | h_`x' == 4
					}
					qui gen disabled = cond(temp>=2,1,0) if !missing(healthproblems)
					la var disabled "Has great difficulty doing two or more daily activities"
					drop temp


				
		// RELABEL YES/NO CONVERSIONS ON DEMOG VARIABLES
				foreach x of varlist male female r_orthodox r_muslim r_christian /// 
				la_amharic la_oromifa lit_high lit_any anyhealthproblem {
				lab val `x' yesno
				}
	

// 3. SKILLS AND EDUCATION (Section 3) //

	// Replace 0 for missing if indicator says no work 
	
	*daytraining techtraining1 techtraining2 university1 university2 othertraining
		
		replace techtraining2 = 0 if techtraining1 == 0
		replace university2 = 0 if university1 == 0
		
		foreach x in techlength1 techlengthunit1 techdaysweek1 techhoursday1 techrelevant1 technow1 {
		replace `x' = 0 if techtraining1 == 0
		}
		
		foreach x in techlength2 techlengthunit2 techdaysweek2 techhoursday2 techrelevant2 technow2 {
		replace `x' = 0 if techtraining2 == 0
		replace `x' = 0 if techtraining1 == 0
		}
		
		foreach x in unilength1 unilengthunit1 unidaysweek1 unihoursday1 unirelevant1 uninow1 {
		replace `x' = 0 if university1 == 0
		}

		foreach x in unilength2 unilengthunit2 unidaysweek2 unihoursday2 unirelevant2 uninow2 {
		replace `x' = 0 if university2 == 0
		replace `x' = 0 if university1 == 0
		}
		
		foreach x in trainlength trainlengthunit traindaysweek trainhoursday trainrelevant trainnow {
		replace `x' = 0 if othertraining == 0
		}

		
		// GENERATE: DAYS/WEEKS/MONTHS/YEARS OF TRAINING FOR TECH AND UNIVERSITY TRAINING 1 & 2
			foreach y in tech uni {
			foreach x in 1 2 {
			gen `y'`x'_days=`y'length`x' if `y'lengthunit`x'==1
			replace `y'`x'_days=`y'length`x' *7 if `y'lengthunit`x'==2
			replace `y'`x'_days=`y'length`x' *30 if `y'lengthunit`x'==3
			replace `y'`x'_days=`y'length`x' *365 if `y'lengthunit`x'==4
			lab var `y'`x'_days "Total days of training: `y' `x'"
			
			gen `y'`x'_mo= `y'length`x' if `y'lengthunit`x'==3
			replace `y'`x'_mo= `y'length`x' *12 if `y'lengthunit`x'==4
			replace `y'`x'_mo= `y'length`x' *.24 if `y'lengthunit`x'==2
			replace `y'`x'_mo= `y'length`x'/30 if `y'lengthunit`x'==1
			lab var `y'`x'_mo "Total months of training: `y' `x'"
			
			gen `y'`x'_yr=`y'`x'_mo/12
			lab var `y'`x'_yr "Total years of training: `y' `x'"

			gen `y'`x'_wks=`y'length1 if `y'lengthunit`x'==2
			replace `y'`x'_wks=`y'length1 /7 if `y'lengthunit`x'==1
			replace `y'`x'_wks=`y'length1 *4 if `y'lengthunit`x'==3
			replace `y'`x'_wks=`y'length1 *52 if `y'lengthunit`x'==4
			lab var `y'`x'_wks "Total weeks of training: `y' `x'"
			}
			}
			
		// DAYS/WEEKS/MONTHS/YEARS OF TRAINING FOR ANY OTHER TRAINING

				gen train_days=trainlength if trainlengthunit==1
				lab var train_days "Total days of training: other training"
				replace train_days=techlength1 *7 if trainlengthunit==2
				replace train_days=techlength1 *30 if trainlengthunit==3
				replace train_days=techlength1 *365 if trainlengthunit==4

				gen train_mo= trainlength if trainlengthunit==3
				lab var train_mo "Total months of training: other training"
				replace train_mo= trainlength *12 if trainlengthunit==4
				replace train_mo= trainlength *.24 if trainlengthunit==2
				replace train_mo= trainlength/30 if trainlengthunit==1

				gen train_yr=train_mo/12
				lab var train_yr "Total years of training: other training"
				
				gen train_wks=trainlength if trainlengthunit==2
				replace train_wks=trainlength /7 if trainlengthunit==1
				replace train_wks=trainlength *4 if trainlengthunit==3
				replace train_wks=trainlength *52 if trainlengthunit==4
				lab var train_wks "Total weeks of training: other training"
			
		// TOTAL DAYS OF TRAINING & DUMMY FOR ANY TRAINING

				egen daystraining=rowtotal(tech1_days tech2_days uni1_days uni2_days train_days), m
				lab var daystraining "Total training/educ mentioned in days"
				gen byte daytraining=cond(daystraining!=0,1,0) 
				lab var daytraining "Indicator for some training/educ (days)"

		// DUMMIES FOR TRAINING: (1) ANY TECHNICAL (2) ANY UNIVERSITY AND (3) ANY OTHER 

				gen tech_any=cond((tech1_yr>0 & tech1_yr<.) |(tech2_yr>0 & tech2_yr<.),1,0)
				lab var tech_any "Indicator for receiving any technical/vocational training"
				gen uni_any=cond((uni1_yr>0 & uni1_yr<.) |(uni2_yr>0 & uni2_yr<.),1,0)
				lab var uni_any "Indicator for receiving any university/college education"
				gen train_any=cond((train_yr>0 & train_yr<.),1,0)
				lab var train_any "Indicator for receiving any 'other' training"
				
		// HOURS PER WEEK OF TRAINING
			foreach x in 1 2 {
				gen tech`x'hourswk= techdaysweek`x'*techhoursday`x'
					la var tech`x'hourswk "Tech training `x': Hours per week"
			}
			gen trainhourswk= traindaysweek*trainhoursday
				la var trainhourswk "Other tech training: Hours per week"
						
		// TOTAL YEARS OF EDUCATION/TRAINING (ASSUMPTION: 12 MONTHS= 1 YEAR)
			
				replace tech1_yr = 0 if techtraining1 == 0
				replace tech2_yr = 0 if techtraining2 == 0 
				replace uni1_yr = 0 if university1 == 0 
				replace uni2_yr = 0 if university2 == 0 
				replace train_yr =0 if othertraining == 0
				
					egen eductemp=rowtotal(uni1_yr uni2_yr), m
					gen educ = highesteduc + eductemp
					foreach x in tech1 tech2 train {
						qui replace educ = educ + `x'_yr if !missing(`x'_yr) ///
														& !missing(`x'_days) & `x'_days >=130 ///
														& !missing(`x'hourswk) & `x'hourswk >=20
					}					
					lab var educ "Total years of education and full time training"
					drop eductemp /* NOTE---MAKE THIS "FULL TIME" VARAIBLE THE MAIN EDUC VARIABLE */
					
		// HOURS OF TRAINING (ACCOUNTS FOR TRAINING INTENSITY)
					gen tech1hours= tech1_wks*techdaysweek1*techhoursday1
					gen tech2hours= tech2_wks*techdaysweek2*techhoursday2
					gen uni1hours= uni1_wks*unidaysweek1*unihoursday1
					gen uni2hours= uni2_wks*unidaysweek2*unihoursday2
					gen trainhours= train_wks*traindaysweek*trainhoursday
					egen hourstraining= rowtotal (tech1hours tech2hours uni1hours uni2hours trainhours)
					lab var hourstraining "Total hours training (tech/voc/uni/other)"
					drop tech1hours tech2hours uni1hours uni2hours trainhours
						
		// DUMMY FOR COMPLETED SECONDARY SCHOOL
				gen finsecondary = (highesteduc>=10) if !missing(highesteduc)
					la var finsecondary "Completed secondary school"
					
		// DUMMY FOR ANY TRAINING RELEVANT TO JOB
				gen byte relevant=cond(techrelevant1==1 | techrelevant2==1 | unirelevant1==1 | unirelevant2==1 | trainrelevant==1,1,0)
				lab var relevant "Indicator: studies/training relevant to job"

		// RECODE & RELABEL "YES/NO" FOR SKILLS/EDUC VARIABLES
				recode technow1 technow2 uninow1 uninow2 trainnow (2=0)
				foreach x of varlist daytraining tech_any uni_any tech_any relevant ///
					technow1 technow2 uninow1 uninow2 trainnow {
					lab val `x' yesno
					}
	
// 4. HOUSEHOLD AND NETWORKS (Section 4) //

		// RECODE "OFTEN" SCALE VARIABLES: (a new var is generated with prefix "r_")
				recode famcaring famadvice famhelp famquarrel ///    
				famvalued friendcaring friendadvice ///  
				friendhelp friendquarrel commvalued ///    
				(4=0 "Never")  (3=1 "Rarely")  (2=2 "Sometimes")  (1=3 "Often"), pre(r_) lab (often_recode)

		// RECODE "AGREE" SCALE VARIABLES: (a new var is generated with prefix "r_")
				recode honest trusted trustofficials watchhome ///
				(4=0 "Strongly disagree") (3=1 "Somewhat disagree") ///
				(2=2 "Somewhat agree") (1=3 "Strongly agree"), pre(r_) lab (agree_recode)

		// NUMBER OF DEPENDENTS, DEPENDENTS RATIO AND HOUSEHOLD SIZE
				egen dependents=rowtotal(dep15 depold), m
				lab var dependents "Total household dependents (aged, disabled, ill, or under 15 years)"
				gen dep_worker=dependents/ablework   
				lab var dep_worker "Household ratio: dependents to able-bodied workers"
				egen hhsize=rowtotal(dependents ablework), m 
				lab var hhsize "Total number of household members"

		// BINARY VARIABLES FOR CIVIL STATUS (SINGLE, MARRIED, PARTNER)
				ren married civil
				gen byte single=cond(civil==1,1,0)
				lab var single "Civil status: single"
				gen byte married=cond(civil==2,1,0)
				lab var married "Civil status: married"
				gen byte partner=cond(civil==3,1,0)
				lab var partner "Civil status: lives with unmarried partner"

		// RECODE: "YES/NO" LABELING FOR GROUP VARIABLES
				foreach x in g_equb g_iddir g_mfi g_coop g_workgroup g_commcouncil /// 
					g_cultural g_churchgroup g_commcomm g_political g_youth g_sports g_womens {
					lab val `x' yesno
				}

		// ADDITIVE INDEX ON QUALITY OF FAMILY RELATIONS
				gen r_revfamquarrel=r_famquarrel
				recode r_revfamquarrel (0=3) (1=2) (2=1) (3=0)
				egen famsupport=rowtotal(r_famcaring r_famadvice r_famhelp r_famquarrel ///    
				r_famvalued r_revfamquarrel), m
				lab var famsupport "Family Support: Additive Index 0-15 (15=better relations)"
				drop r_revfamquarrel

		// ADDITIVE INDEX ON QUALITY OF COMMUNITY RELATIONS
				gen r_revfriendquarrel=r_friendquarrel
				recode r_revfriendquarrel (0=3) (1=2) (2=1) (3=0)
				egen commsupport=rowtotal(r_friendcaring r_friendadvice ///  
				r_friendhelp r_revfriendquarrel r_commvalued), m   
				lab var commsupport "Community Support: Additive Index 0-15 (15=better relations)"
				drop r_revfriendquarrel

		// ADDITIVE TRUST INDEX
				egen trust=rowtotal (r_honest r_trusted r_trustofficials r_watchhome), m
				lab var trust "Trust: Additive Index"

		// TOTAL NUMBER OF GROUPS RESPONDENT BELONGS TO
				gen othgroup1temp=cond(othgroup1!="",1,0)
				gen othgroup2temp=cond(othgroup2!="",1,0)
				gen othgroup3temp=cond(othgroup3!="",1,0)
				egen groups=rowtotal(g_equb g_iddir g_mfi g_coop g_workgroup g_commcouncil /// 
					g_cultural g_churchgroup g_commcomm g_political g_youth ///       
					g_sports g_womens othgroup1temp othgroup2temp othgroup3temp), m
				drop othgroup1temp othgroup2temp othgroup3temp
				lab var groups "Number of community groups belong to"

		// LEADERSHIP POSITION- LEADS ANY GROUP OR KEBELE
				gen lead_any=cond(kebelelead==1|grouplead==1, 1, 0)
				lab var lead_any "Holds leadership position in any group or Kebele"

		// ADDITIVE INDEX ON DEGREE OF COMMUNITY PARTICIPATION
				egen comminvolved=rowtotal(kebelelead grouplead giveadvice speakup commpart vote vote2010 churchreg), m
				lab var comminvolved "Degree of community participation: Additive Index 0-8 (8=more involved)"
			
		// NUMBER OF PEOPLE CAN RELY ON FOR FINANCIAL HELP (HAS AT LEAST 5 / HAS NONE)
				tab financialhelp, mi  
				recode financialhelp (5/200=1)(0/4=0), gen(finhelp_5plus) lab(yesno)
				lab var finhelp_5plus "Has at least 5 people who could be relied on for financial or in-kind support"
				recode financialhelp (0=1)(1/200=0), gen(finhelp_none) lab(yesno)
				lab var finhelp_none "Has no one who could be relied on for financial or in-kind support"

		// NUMBER OF *WEALTHIER* PEOPLE CAN RELY ON FOR FINANCIAL HELP (HAS AT LEAST 5 / HAS NONE)
				tab finwealthier, mi 
				recode finwealthier (5/200=1)(0/4=0), gen(finwealth_5plus) lab(yesno)
				lab var finwealth_5plus "Has at least 5 people wealthier than him/her who could be relied on"
				recode finwealthier (0=1)(1/200=0), gen(finwealth_none) lab(yesno)
				lab var finwealth_none "Has no one wealthier than him/her who could be relied on"
					replace finwealthier =0 if financialhelp==0
					replace finwealth_5plus =0 if financialhelp==0
					replace finwealth_none =0 if financialhelp==0 
				
		// NUMBER OF NEIGHBORS CAN RELY ON FOR FINANCIAL HELP (HAS AT LEAST 1)
				tab finneighbor, mi      
				recode finneighbor(1/200=1)(0=0), gen(finneigh_1plus) lab(yesno)
				lab var finneigh_1plus "Has at least 1 neighbor who could be relied on"
				replace finneigh_1plus =0 if financialhelp==0

		// NUMBER OF PEOPLE CAN DISCUSS AG/BUSINESS MATTERS WITH (HAS AT LEAST 5 / HAS NONE)
				tab agmatters, mi        
				recode agmatters (5/200=1)(0/4=0), gen(agmatters_5plus) lab(yesno)
				lab var agmatters_5plus "Has at least 5 people to comfortably discuss agri/business matters with"
				recode agmatters (0=1)(1/200=0), gen(agmatters_none) lab(yesno)
				lab var agmatters_none "Has no one to comfortably discuss agri/business matters with"

		// NUMBER OF *WEALTHIER* PEOPLE CAN DISCUSS AG/BUSINESS MATTERS WITH (HAS AT LEAST 5 / HAS NONE)
				tab agwealthier, mi
				recode agwealthier (5/200=1)(0/4=0), gen(agwealth_5plus) lab(yesno)
				lab var agwealth_5plus "Has at least 5 people wealthier to comfortably discuss agri/business matters with"
				recode agwealthier (0=1)(1/200=0), gen(agwealth_none) lab(yesno)
				lab var agwealth_none "Has no one wealthier than him/her to comfortably discuss agri/business matters with"
					replace agwealthier =0 if agmatters==0
					replace agwealth_5plus =0 if agmatters ==0
					replace agwealth_none =0 if agmatters ==0 
			 
		// NUMBER OF NEIGHBORS CAN DISCUSS AG/BUSINESS MATTERS WITH (HAS AT LEAST 1)
				tab agneighbors, mi   
				recode agneighbors (1/200=1)(0=0), gen(agneigh_1plus) lab(yesno)
				lab var agneigh_1plus "Has at least 1 neighbor to comfortably discuss agri/business matters with"
				replace agneigh_1plus =0 if agmatters ==0
		 
		// RELABEL YES/NO HH & NETWORKS VARIABLES
				foreach x of varlist single married partner headlive lead_any { 
				lab val `x' yesno
				}


// 5. CASH AND SAVINGS (Section 5) //

		// RECODE: PERCEIVED HOUSEHOLD STATUS VARIABLE (CONVERT TO ASCENDING ORDER OF SCALE) 
				recode hhstatus (7=0 "Destitute") (6=1 "Poor") (5=2 "Never Have Enough") (4=3 "Can Manage to Get By") ///
				(3=4 "Comfortable") (2=5 "Rich") (1=6 "Very Rich"), pre (r_) lab(status2)
				lab var r_hhstatus "Perceived HH Status; 0=Destitute-6=Very Rich"

		// STATUS YEAR AGO VS. STATUS TODAY
				gen status=laddnow
				lab var status "Subjective: Status today"
				
		// STATUS YEAR AGO VS. STATUS TODAY
				gen stat_change1= laddnow-laddyearago
				lab var stat_change1 "Subjective: Status today minus status last year (10 point ladder)"

		// STATUS NEXT YEAR VS. STATUS TODAY (OPTIMISM)
				gen stat_change2= laddnxtyear-laddnow
				lab var stat_change2 "Subjective: Status next year minus status today (10 point ladder)" 

		// STATUS IN 5 YEARS VS. STATUS TODAY (OPTIMISM)
				gen stat_change3= ladd5years-laddnow
				lab var stat_change3 "Subjective: Status in five years minus status today (10 point ladder)"

		// REPLACE: BLANKS WITH 0'S FOR VARIABLES ON WHO OWE MONEY TO
			foreach var of varlist owebank-oweother debttotal {
				replace `var'=0 if `var'==.
			}
			
// 6. PSYCHOSOCIAL (Section 6) //
/*		
		// PATIENT HEALTH QUESTIONNAIRE (PHQ-9): USES STANDARD PHQ CALCULATION *F*
			recode  phq* (1=0) (2=1) (3=2) (4=3), pre(r_) 
			egen phqtotal=rowtotal(r_phq*), m
			gen phqscore=0 if phqtotal<=4
			replace phqscore=1 if phqtotal==5 | phqtotal==6 | phqtotal==7 | phqtotal==8 | phqtotal==9
			replace phqscore=2 if phqtotal==10 | phqtotal==11 | phqtotal==12 | phqtotal==13 | phqtotal==14
			replace phqscore=3 if phqtotal==15 | phqtotal==16 | phqtotal==17 | phqtotal==18 | phqtotal==19
			replace phqscore=4 if phqtotal>=20
			label define phqscore 0 "None" 1 "Mild Depression" 2 "Moderate Depression" ///
			3 "Moderate Severe Depression" 4 "Severe Depression"
			label val phqscore phqscore
			label var phqscore "Degree of Depression: using PHQ scale categories"
			label var phqtotal "Total points on PHQ 0-27, 27: More Depressed"
			
			*replace phqtotal=. if projid==101 // This question did not exist in projid==101 
			*replace phqscore=. if projid==101 // This question did not exist in projid==101 
			
		// GENERALIZED ANXIETY DISORDER ASSESSMENT (GAD-7): USES STANDARD GAD CALCULATION *F*
			recode  gad* (1=0) (2=1) (3=2) (4=3), pre(r_) 
			foreach x in gad1 gad2 gad3 gad4 gad5 gad6 gad7 {
			drop if `x'==.
			}
			egen gadtotal=rowtotal(r_gad*), m
			gen gadscore=0 if gadtotal<=5
			replace gadscore=1 if gadtotal==6 | gadtotal==7 | gadtotal==8 | gadtotal==9 | gadtotal==10
			replace gadscore=2 if gadtotal==11 | gadtotal==12 | gadtotal==13 | gadtotal==14 | gadtotal==15
			replace gadscore=3 if gadtotal>=16
			label define gadscore 0 "Mild Anxiety" 1 "Moderate Anxiety" 2 "Moderate Sever Anxiety" 3 "Severe Anxiety"
			label val gadscore gadscore
			label var gadscore "Degree of Anxiety Disorder: using GAD scale categories"	
			label var gadtotal "Total points on GAD 0-21, 21: More Anxiety"
			
			*replace gadtotal=. if projid==101 // This question did not exist in projid==101
			*replace gadscore=. if projid==101 // This question did not exist in projid==101 
*/
			// PATIENT HEALTH QUESTIONNAIRE (PHQ-9): USES STANDARD PHQ CALCULATION *F* // Flipped on 8/28 so higher is better CH
			recode  phq* (1=3) (2=2) (3=1) (4=0), pre(r_) 
			egen phqtotal=rowtotal(r_phq*), m
			gen phqscore=0 if phqtotal<=7
			replace phqscore=1 if phqtotal==8 | phqtotal==9 | phqtotal==10 | phqtotal==11 | phqtotal==12
			replace phqscore=2 if phqtotal==13 | phqtotal==14 | phqtotal==15 | phqtotal==16 | phqtotal==17
			replace phqscore=3 if phqtotal==18 | phqtotal==19 | phqtotal==20 | phqtotal==21 | phqtotal==22
			replace phqscore=4 if phqtotal>=23
			label define phqscore 4 "None" 3 "Mild Depression" 2 "Moderate Depression" ///
			1 "Moderate Severe Depression" 0 "Severe Depression"
			label val phqscore phqscore
			label var phqscore "Degree of Depression: using PHQ scale categories"
			label var phqtotal "Total points on PHQ 0-27 (0: More Depressed)"
			gen phqtotal_r = -phqtotal + 27
			la var phqtotal_r "Total points on PHQ 0-27 (27: More Depressed)"
			
			*replace phqtotal=. if projid==101 // This question did not exist in projid==101 
			*replace phqscore=. if projid==101 // This question did not exist in projid==101 
			
			// GENERALIZED ANXIETY DISORDER ASSESSMENT (GAD-7): USES STANDARD GAD CALCULATION *F*
			recode  gad* (1=3) (2=2) (3=1) (4=0), pre(r_) 
			egen gadtotal=rowtotal(r_gad*), m
			gen gadscore=0 if gadtotal<=4
			replace gadscore=1 if gadtotal==6 | gadtotal==7 | gadtotal==8 | gadtotal==9 | gadtotal==5
			replace gadscore=2 if gadtotal==11 | gadtotal==12 | gadtotal==13 | gadtotal==14 | gadtotal==10
			replace gadscore=3 if gadtotal>=15
			label define gadscore 3 "Mild Anxiety" 2 "Moderate Anxiety" 1 "Moderate Severe Anxiety" 0 "Severe Anxiety"
			label val gadscore gadscore
			label var gadscore "Degree of Anxiety Disorder: using GAD scale categories"	
			label var gadtotal "Total points on GAD 0-21 (0: More Anxiety)"
			gen gadtotal_r = -gadtotal + 21
			label var gadtotal "Total points on GAD 0-21 (21: More Anxiety)"
			*replace gadtotal=. if projid==101 // This question did not exist in projid==101 
			*replace gadscore=. if projid==101 // This question did not exist in projid==101 


			
// 7. CONSCIENTIOUSNESS (Section 7) //

			recode consc1-consc4 (1=0) (2=1) (3=2) (4=3) (5=4), pre(r_)
			recode consc5-consc10 (1=4) (2=3) (3=2) (4=1) (5=0), pre(r_)
			egen consc=rowtotal(r_consc*), m
			label var consc "Degree of conscientiousness (0-40), 40: More Conscientious"
		

// 8. GENERAL EMPLOYMENT / INCOME GENERATING ACTIVITIES- (Section 8) //
		
		/* OUTLINE
		a. Total months experience in IGA (longest IGA)-- BL measure only
		b. Hours worked (each IGA, total, category)
			past 12 months
			past 4 weeks
			past 7 days
			past 7 days before last 7 days
		c. Hours worked: by work for self or other; 4 weeks, 12 months
		d. Hours worked: by minimum education for job; 4 weeks, 12 months
		e. Hours worked: by regularity of payment; 4 weeks, 12 months
		f. Hours worked: by certainty of employment; 4 weeks, 12 months
		g. Hours worked: by size of IGA organization; 4 weeks, 12 months
		h. Cash and Profit
			* Cash earned: 7 days and 7 days before last 7 days
			* Profit earned: 7 days and 7 days before last 7 days
			* Cash per hour: 7 days and 7 days before last 7 days
			* Cash per day: By activity and total
		i. Factory work 
		j. Any income-generating activities

		ASSUMPTIONS: we assume that hours (the smallest unit of time measurement) do not overlap across
		activities so that we can aggregate them into indicators/categories and not double count hours. 
		
		*/ 
	*
	// General global
		global igacateg psnp farm share casual animal farmwage food shop trade voc tailor crafts fac mining driver sec soldier dom clerical famwork wait teach othwork1 othwork2 othwork3
	
	// Make sure missing is not being imputed as zero and vice versa
		gl igacateg0 psnp farm share casual animal farmwage food shop trade voc tailor crafts fac mining driver sec soldier dom clerical famwork wait teach
	
		replace casualmonths = ".067" if casualmonths == "2 days"
		replace casualmonths = ".25" if casualmonths == "1/4"
		destring casualmonths, replace 
		
	// 
		foreach var in $igacateg0 {
		
		replace `var'years = 0 if `var' == 0
		replace `var'months = 0 if `var' == 0
		replace `var'payment = 0 if `var' == 0
		replace `var'length = 0 if `var' == 0
		replace `var'wage = 0 if `var' == 0
		replace `var'12months = 0 if `var' == 0
		replace `var'increport = 0 if `var' == 0
		replace `var'daysmonth = 0 if `var' == 0
		replace `var'hoursday = 0 if `var' == 0
		replace `var'4weeks = 0 if `var' == 0
		replace `var'7days = 0 if `var' == 0
		replace `var'7hours = 0 if `var' == 0
		replace `var'cash7d = 0 if `var' == 0
		replace `var'prof7d = 0 if `var' == 0
		replace `var'14days = 0 if `var' == 0
		replace `var'14hours = 0 if `var' == 0
		replace `var'14cash = 0 if `var' == 0
		replace `var'14prof = 0 if `var' == 0
		}
				
		foreach var in othwork1 othwork2 othwork3 {
		replace `var'years = 0 if `var' == 0
		replace `var'months = 0 if `var' == 0
		replace `var'payment = 0 if `var' == 0
		replace `var'length = 0 if `var' == 0
		replace `var'wage = 0 if `var' == 0
		replace `var'12months = 0 if `var' == 0
		replace `var'increport = 0 if `var' == 0
		replace `var'daysmonth = 0 if `var' == 0
		replace `var'hoursday = 0 if `var' == 0
		replace `var'4weeks = 0 if `var' == 0
		replace `var'7days = 0 if `var' == 0
		replace `var'7hours = 0 if `var' == 0
		replace `var'cash7d = 0 if `var' == 0
		replace `var'prof7d = 0 if `var' == 0
		replace `var'14days = 0 if `var' == 0
		replace `var'14hours = 0 if `var' == 0
		replace `var'14cash = 0 if `var' == 0
		replace `var'14prof = 0 if `var' == 0
		}
	
		// 8.a. MONTHS EXPERIENCE IN IGA
								
			// TIME CONVERSION: Convert years to months total experience doing each activity (generating month variables)
					
					foreach x in $igacateg {
					gen `x'_monthtemp=`x'years*12
					egen `x'_mo=rowtotal (`x'_monthtemp `x'months), m
					}
					
			// GENERATE: months of experience in activity with longest experience
				// We cannot aggregate experience since a respondent can simultaneously do two activities

					egen exper_months=rowmax(psnp_mo farm_mo share_mo animal_mo farmwage_mo food_mo ///
					shop_mo trade_mo voc_mo tailor_mo crafts_mo fac_mo casual_mo mining_mo ///
					driver_mo sec_mo soldier_mo dom_mo clerical_mo famwork_mo wait_mo teach_mo ///
					othwork1_mo othwork2_mo othwork3_mo) 
					lab var exper_months "Total months experience in IGA with longest experience"
					
			// GENERATE MONTHS EXPERIENCE FOR MAJOR IGA CATEGORIES
				egen agexper_mo = rowtotal(farmwage_mo animal_mo share_mo farm_mo), m
					lab var agexper_mo "Months experience: Agriculture"
							
				egen casexper_mo = rowtotal(casual_mo psnp_mo), m
					lab var casexper_mo "Months experience: Casual work"
								
				gen factexper_mo = fac_mo
					lab var factexper_mo "Months experience: Factory labor"
								
				egen pettybusnexper_mo = rowtotal(famwork_mo shop_mo food_mo trade_mo), m
					lab var pettybusnexper_mo "Months experience: Petty business"
								
				egen skilledexper_mo = rowtotal(crafts_mo tailor_mo  voc_mo), m
					lab var skilledexper_mo "Months experience: Skilled trade"
								
				egen wagelowexper_mo = rowtotal(mining_mo wait_mo dom_mo sec_mo), m
					lab var wagelowexper_mo "Months experience: Wage labor - Low skill"
								
				egen wagemedexper_mo = rowtotal(clerical_mo soldier_mo driver_mo teach_mo), m
					lab var wagemedexper_mo "Months experience: Wage labor - medium skill"
								
				egen othexper_mo = rowtotal(othwork1_mo othwork2_mo othwork3_mo)
					lab var othexper_mo "Months experience: Other"

				egen workexper_mo = rowtotal(farmwage_mo animal_mo share_mo farm_mo casual_mo ///
				psnp_mo fac_mo famwork_mo shop_mo food_mo trade_mo crafts_mo tailor_mo  ///
				voc_mo mining_mo wait_mo dom_mo sec_mo clerical_mo soldier_mo driver_mo teach_mo ///
				othwork1_mo othwork2_mo othwork3_mo), m
					la var workexper_mo "Months experience: All work"
					
				egen workexper2_mo = rowtotal( ///
				psnp_mo fac_mo famwork_mo shop_mo food_mo trade_mo crafts_mo tailor_mo  ///
				voc_mo mining_mo wait_mo dom_mo sec_mo clerical_mo soldier_mo driver_mo teach_mo ///
				othwork1_mo othwork2_mo othwork3_mo), m
					la var workexper2_mo "Months experience: All work (excluding agriculture and casual labor)"
					
					foreach x in $igacateg {
						if "`x'"!="psnp" {
							drop `x'_monthtemp `x'_mo
						}
						else {
							drop `x'_monthtemp
						}
					}
				rename psnp_mo psnpexper_mo
				la var psnpexper_mo "Months experience: PSNP"
		
		// 8.b. TOTAL HOURS WORKED
					
			// HOURS WORKED PAST 12 MONTHS FOR EACH ACTIVITY
				// using average days worked per month/hours worked per day
				
				foreach x in $igacateg {
					gen `x'hours= `x'12months * `x'daysmonth * `x'hoursday
					label var `x'hours "Hours worked in the past 12 months: `x'"
					qui sum `x'hours, d
					replace `x'hours=r(p99) if inrange(`x'hours,r(p99),.)
				}
				
			// CREATE SUBCATEGORIES
				egen aghours = rowtotal(farmwagehours animalhours sharehours farmhours), m
					lab var aghours "Hours in past year: Agriculture"
							
				egen cashours = rowtotal(casualhours psnphours), m
					lab var cashours "Hours in past year: Casual work"
								
				gen facthours = fachours
					lab var facthours "Hours in past year: Factory labor"
								
				egen pettybusnhours = rowtotal(famworkhours shophours foodhours tradehours), m
					lab var pettybusnhours "Hours in past year: Petty business"
								
				egen skilledhours = rowtotal(craftshours tailorhours  vochours), m
					lab var skilledhours "Hours in past year: Skilled trade"
								
				egen wagelowhours = rowtotal(mininghours waithours domhours sechours), m
					lab var wagelowhours "Hours in past year: Wage labor - Low skill"
								
				egen wagemedhours = rowtotal(clericalhours soldierhours driverhours teachhours), m
					lab var wagemedhours "Hours in past year: Wage labor - medium skill"
								
				egen othhours = rowtotal(othwork1hours othwork2hours othwork3hours)
					lab var othhours "Hours in past year: Other"
					
			// TOTAL HOURS WORKED PAST 12 MONTHS
					
					egen hourswork=rowtotal(farmhours sharehours animalhours ///
					farmwagehours foodhours shophours tradehours vochours ///
					tailorhours craftshours fachours casualhours mininghours ///
					driverhours sechours soldierhours domhours clericalhours ///
					famworkhours waithours teachhours othwork1hours othwork2hours ///
					othwork3hours), m
					qui sum hourswork, d
					qui replace hourswork = r(p99) if inrange(hourswork,r(p99),.)
					lab var hourswork "Total hours worked in the past 12 months"
					
			// HOURS worked in the past 4 WEEKS for each activity
				// using days worked in 4 weeks and average hours worked per day
				
				foreach x in $igacateg {
					gen `x'hours_4w= `x'4weeks * `x'hoursday 
					label var `x'hours_4w "Hours worked in the past 4 weeks: `x'"
					replace `x'hours_4w=0 if `x'hours==0
				}
				
			// HOURS worked in the past 4 weeks 
			
				 egen hourswork_4w = rowtotal(*hours_4w), m
				 lab var hourswork_4w "Hours worked in the past 4 weeks"
				
			// HOURS worked in the past WEEK (FOUR WEEKS DIVIDED BY 4) for each activity
				// use days worked in past 4 weeks and avg hours worked per day divided by 4 
					
				foreach x in $igacateg {
					gen `x'hours_1w = (`x'hours_4w / 4)
					lab var `x'hours_1w "Average weekly hours of work: `x'"
					}
						
			// AVG HOURS worked in the past week by category
			
			gl categories aghours_1w cashours_1w facthours_1w pettybusnhours_1w skilledhours_1w wagelowhours_1w wagemedhours_1w othhours_1w
			
				egen aghours_1w = rowtotal(farmwagehours_1w animalhours_1w sharehours_1w farmhours_1w), m
					lab var aghours_1w "Hours worked in the past week: Agriculture"
					
				egen aghoursoth_1w = rowtotal(animalhours_1w sharehours_1w farmhours_1w), m
					lab var aghoursoth_1w "Hours worked in the past week: Agriculture other"
				
				gen aghourscom_1w = farmwagehours_1w
					lab var aghourscom_1w "Hours worked in the past week: Commercial farm"
							
				egen cashours_1w = rowtotal(casualhours_1w psnphours_1w), m
					lab var cashours_1w "Hours worked in the past week: Casual work"
								
				gen facthours_1w = fachours_1w
					lab var facthours_1w "Hours worked in the past week: Factory labor"
								
				egen pettybusnhours_1w = rowtotal(famworkhours_1w shophours_1w foodhours_1w tradehours_1w), m
					lab var pettybusnhours_1w "Hours worked in the past week: Petty business"
								
				egen skilledhours_1w = rowtotal(craftshours_1w tailorhours_1w  vochours_1w), m
					lab var skilledhours_1w "Hours worked in the past week: Skilled trade"
								
				egen wagelowhours_1w = rowtotal(mininghours_1w waithours_1w domhours_1w sechours_1w), m
					lab var wagelowhours_1w "Hours worked in the past week: Wage labor - Low skill"
								
				egen wagemedhours_1w = rowtotal(clericalhours_1w soldierhours_1w driverhours_1w teachhours_1w), m
					lab var wagemedhours_1w "Hours worked in the past week: Wage labor - medium skill"
								
				egen othhours_1w = rowtotal(othwork1hours_1w othwork2hours_1w othwork3hours_1w)
					lab var othhours_1w "Hours worked in the past week: Other"

			// AVERAGE TOTAL HOURS of work in a week
					
					egen hourswork_1w = rowtotal(aghours_1w cashours_1w facthours_1w pettybusnhours_1w skilledhours_1w wagelowhours_1w wagemedhours_1w othhours_1w), 
					lab var hourswork_1w "Average weekly hours of work"		
					
			// HOURS worked in the past 7 DAYS BEFORE THE LAST 7 DAYS for each activity, average hours per day
				
				foreach x in $igacateg {
					gen `x'hours_7d7= `x'14days * `x'14hours
					lab var `x'hours_7d7 "Hours worked in the past 7 days before the last 7 days: `x'"
					replace `x'hours_7d7=0 if `x'14days==0
					replace `x'hours_7d7=0 if `x'14hours==0
				}
					
			// HOURS worked in the past 7 DAYS for each activity, average hours per day
				
				foreach x in $igacateg {
					gen `x'hours_7d= `x'7days * `x'7hours
					lab var `x'hours_7d "Hours worked in the past 7 days: `x'"
					replace `x'hours_7d=0 if `x'7days==0
					replace `x'hours_7d=0 if `x'7hours==0
				}
					
			// TOTAL HOURS worked in the past 7 DAYS, average hours per day

					egen hourswork_7d=rowtotal(*_7d), m
					lab var hourswork_7d "Total hours worked in the past 7 days"
					
			// TOTAL HOURS worked in the past 7 DAYS BEFORE THE LAST 7 DAYS, average hours per day

					egen hourswork_7d7=rowtotal(*_7d7), m
					lab var hourswork_7d7 "Total hours worked in the past 7 days before the last 7 days"
					
		// HOURS WORKED EACH WEEK BY CATEGORY
		
		foreach x in 7d 7d7 {
			
			egen aghours_`x' = rowtotal(farmwagehours_`x' animalhours_`x' sharehours_`x' farmhours_`x'), m
				lab var aghours_1w "Hours worked in the past week: Agriculture"
				if ("`x'" == "7d7") lab var aghours_`x' "Hours worked in the week before the past week: Agriculture"

			egen aghoursoth_`x' = rowtotal(animalhours_`x' sharehours_`x' farmhours_`x'), m
				lab var aghoursoth_`x' "Hours worked in the past week: Agriculture other"
				if ("`x'" == "7d7") lab var aghoursoth_`x' "Hours worked in the week before the past week: Agriculture other"
				
			gen aghourscom_`x'  = farmwagehours_`x' 
				lab var aghourscom_`x'  "Hours worked in the past week: Commercial farm"
				if ("`x'" == "7d7") lab var aghourscom_`x'  "Hours worked in the week before the past week: Commercial farm"
				
			egen cashours_`x' = rowtotal(casualhours_`x'  psnphours_`x' ), m
				lab var cashours_`x' "Hours worked in the past week: Casual work"
				if ("`x'" == "7d7") lab var cashours_`x' "Hours worked in the week before the past week: Casual work"
								
			gen facthours_`x'  = fachours_`x' 
				lab var facthours_`x'  "Hours worked in the past week: Factory labor"
				if ("`x'" == "7d7") lab var facthours_`x'  "Hours worked in the week before the past week: Factory labor"
							
			egen pettybusnhours_`x' = rowtotal(famworkhours_`x'  shophours_`x'  foodhours_`x'  tradehours_`x'), m
				lab var pettybusnhours_`x' "Hours worked in the past week: Petty business"
				if ("`x'" == "7d7") lab var pettybusnhours_`x'  "Hours worked in the week before the past week: Petty business"
								
			egen skilledhours_`x' = rowtotal(craftshours_`x' tailorhours_`x'  vochours_`x'), m
				lab var skilledhours_`x' "Hours worked in the past week: Skilled trade"
				if ("`x'" == "7d7") lab var skilledhours_`x' "Hours worked in the week before the past week: Skilled trade"
								
			egen wagelowhours_`x' = rowtotal(mininghours_`x' waithours_`x' domhours_`x' sechours_`x'), m
				lab var wagelowhours_`x' "Hours worked in the past week: Wage labor - Low skill"
				if ("`x'" == "7d7") lab var wagelowhours_`x' "Hours worked in the week before the past week: Wage labor - Low skill"
								
			egen wagemedhours_`x' = rowtotal(clericalhours_`x' soldierhours_`x' driverhours_`x' teachhours_`x'), m
				lab var wagemedhours_`x' "Hours worked in the past week: Wage labor - medium skill"
				if ("`x'" == "7d7") lab var wagemedhours_`x' "Hours worked in the week before the past week: Wage labor - medium skill"

			egen othhours_`x' = rowtotal (othwork1hours_`x' othwork2hours_`x' othwork3hours_`x'), m
				lab var othhours_`x' "Hours worked in the past week: Other"
				if ("`x'" == "7d7") lab var othhours_`x' "Hours worked in the week before the past week: Other"
				
	}
					
			// WEEKLY HOURS OVER THE PAST 2 WEEKS
				egen hourswork_wk = rowmean(hourswork_7d7 hourswork_7d)
				lab var hourswork_wk "Average weekly hours of work (over past 2 weeks)"	
				
			foreach x in aghours aghoursoth aghourscom cashours facthours pettybusnhours skilledhours wagelowhours wagemedhours othhours {
				egen `x'_wk=rowmean(`x'_7d7 `x'_7d)
				lab var `x'_wk "Average weekly work hours (over past 2 weeks) :`=substr("`:var la `x'_7d'",strpos("`:var la `x'_7d'",":")+2,.)'"
			}

		// 8.c. HOURS WORKED BY EMPLOYMENT TYPE (WORK FOR SELF, OTHER OR BOTH)
		
			// BY EMPLOYMENT TYPE-- 4 WEEKS
			
				// TOTAL HOURS worked PAST 4 WEEKS (SELF EMPLOYED), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_self= `x'hours_4w if `x'workfor==1
					}
					egen hourswork4_self=rowtotal(*_4w_self), 
					lab var hourswork4_self "Self-Employed: Total hours worked in past 4 weeks"
					drop *_4w_self 
						
				// TOTAL HOURS worked PAST 4 WEEKS (WORK FOR OTHER), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_other= `x'hours_4w if `x'workfor==2
					}
					egen hourswork4_other=rowtotal(*_4w_other), m
					lab var hourswork4_other "Work for other: Total hours worked in past 4 weeks"
					drop *_4w_other
					
				// TOTAL HOURS worked PAST 4 WEEKS (SELF & OTHER), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_both = `x'hours_4w if `x'workfor==3
					}
					egen hourswork4_both=rowtotal(*_4w_both), m
					lab var hourswork4_both "Work for self & other: Total hours worked in past 4 weeks"
					drop *_4w_both
				
			// BY EMPLOYMENT TYPE-- 12 MONTHS
		
			// TOTAL HOURS worked PAST 12 MONTHS (SELF EMPLOYED), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_self= `x'hours if `x'workfor==1
				}
				egen hourswork_self=rowtotal(*_12m_self), m
				lab var hourswork_self "Self-Employed: Total hours worked in past 12 months"
				
				drop *_12m_self 
					
			// TOTAL HOURS worked PAST 12 MONTHS (WORK FOR OTHER), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_other= `x'hours if `x'workfor==2
				}
				egen hourswork_other=rowtotal(*_12m_other), m
				lab var hourswork_other "Work for other: Total hours worked in past 12 months"
				drop *_12m_other
				
			// TOTAL HOURS worked PAST 12 MONTHS (SELF & OTHER), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_both = `x'hours if `x'workfor==3
				}
				egen hourswork_both=rowtotal(*_12m_both), m
				lab var hourswork_both "Work for self & other: Total hours worked in past 12 months"
				drop *_12m_both			
	
		// 8.d. HOURS WORKED BY MIN EDUCATION LEVEL REQUIRED FOR IGA (PRIMARY, SECONDARY, TECHNICAL OR COLLEGE)

			// BY MIN EDUCATION LEVEL-- 4 WEEKS
			
				// TOTAL HOURS worked PAST 4 WEEKS (PRIMARY OR LESS), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_primary= `x'hours_4w if `x'educ==0
					}
					egen hourswork4_primary=rowtotal(*_4w_primary), m
					lab var hourswork4_primary "Min education for job= primary: total hours worked in past 4 weeks"
					drop *_4w_primary 
						
				// TOTAL HOURS worked PAST 4 WEEKS (SECONDARY), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_second= `x'hours_4w if `x'educ==1 | `x'educ==2
					}
					egen hourswork4_second=rowtotal(*_4w_second), m
					lab var hourswork4_second "Min education for job= secondary: total hours worked in past 4 weeks"
					drop *_4w_second 
					
				// TOTAL HOURS worked PAST 4 WEEKS (TECHNICAL TRAINING), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_tech= `x'hours_4w if `x'educ==3
					}
					egen hourswork4_tech=rowtotal(*_4w_tech), m
					lab var hourswork4_tech "Min education for job= technical: total hours worked in past 4 weeks"
					drop *_4w_tech 
					
				// TOTAL HOURS worked PAST 4 WEEKS (COLLEGE), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_coll= `x'hours_4w if `x'educ==4
					}
					egen hourswork4_coll=rowtotal(*_4w_coll), m
					lab var hourswork4_coll "Min education for job= college: total hours worked in past 4 weeks"
					drop *_4w_coll
			
			// BY MIN EDUCATION LEVEL-- 12 MONTHS
			
				// TOTAL HOURS worked PAST 12 MONTHS (PRIMARY OR LESS), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_primary= `x'hours if `x'educ==0
					}
					egen hourswork_primary=rowtotal(*_12m_primary), m
					lab var hourswork_primary "Min education for job= primary: total hours worked in past 12 months"
					drop *_12m_primary 
						
				// TOTAL HOURS worked PAST 12 MONTHS (SECONDARY), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_second= `x'hours if `x'educ==1 | `x'educ==2
					}
					egen hourswork_second=rowtotal(*_12m_second), m
					lab var hourswork_second "Min education for job= secondary: total hours worked in past 12 months"
					drop *_12m_second 
					
				// TOTAL HOURS worked PAST 12 MONTHS (TECHNICAL TRAINING), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_tech= `x'hours if `x'educ==3
					}
					egen hourswork_tech=rowtotal(*_12m_tech), m
					lab var hourswork_tech "Min education for job= technical: total hours worked in past 12 months"
					drop *_12m_tech 
					
				// TOTAL HOURS worked PAST 12 MONTHS (COLLEGE), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_coll= `x'hours if `x'educ==4
					}
					egen hourswork_coll=rowtotal(*_12m_coll), m
					lab var hourswork_coll "Min education for job= college: total hours worked in past 12 months"
					drop *_12m_coll
		
		
		// 8.e. HOURS WORKED BY INTERVAL/REGULARITY OF PAYMENT (IRREGULAR VS. REGULAR)
		
			// BY REGULARITY OF PAYMENT-- 4 WEEKS
		
			// TOTAL HOURS worked PAST 4 WEEKS (IRREGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_irreg= `x'hours_4w if `x'payment==1 | `x'payment==2
				}
				egen hourswork4_irreg=rowtotal(*_4w_irreg), m
				lab var hourswork4_irreg "Payment effected irregularly: total hours worked in past 4 weeks"
				drop *_4w_irreg 
					
			// TOTAL HOURS worked PAST 4 WEEKS (REGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_reg= `x'hours_4w if `x'payment==3 | `x'payment==4 | `x'payment==5 
				}
				egen hourswork4_reg=rowtotal(*_4w_reg), m
				lab var hourswork4_reg "Payment effected regularly: total hours worked in past 4 weeks"
				drop *_4w_reg 
			
		// BY REGULARITY OF PAYMENT-- 12 MONTHS
		
			// TOTAL HOURS worked PAST 12 MONTHS (IRREGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_irreg= `x'hours if `x'payment==1 | `x'payment==2
				}
				egen hourswork_irreg=rowtotal(*_12m_irreg), m
				lab var hourswork_irreg "Payment effected irregularly: total hours worked in past 12 months"
				drop *_12m_irreg 
					
			// TOTAL HOURS worked PAST 12 MONTHS (REGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_reg= `x'hours if `x'payment==3 | `x'payment==4 | `x'payment==5 
				}
				egen hourswork_reg=rowtotal(*_12m_reg), m
				lab var hourswork_reg "Payment effected regularly: total hours worked in past 12 months"
				drop *_12m_reg 
			
		// 8.f. HOURS WORKED BY CERTAINTY/LENGTH OF EMPLOYMENT (UNCERTAINTY and LENGTH)
			
				// BY CERTAINTY/LENGTH OF EMPLOYMENT-- 4 WEEKS
					
					// TOTAL HOURS worked PAST 4 WEEKS (Certain & shorter), average hours per day
						foreach x in $igacateg {
						gen `x'hours_4w_cershort= `x'hours_4w if `x'length==1
						}
						egen hourswork4_cershort=rowtotal(*_4w_cershort), m
						lab var hourswork4_cershort "Certain & short: total hours worked in past 4 weeks"
						drop *_4w_cershort 
							
					// TOTAL HOURS worked PAST 4 WEEKS (Certain & longer), average hours per day
						foreach x in $igacateg {
						gen `x'hours_4w_cerlong= `x'hours_4w if `x'length==2
						}
						egen hourswork4_cerlong=rowtotal(*_4w_cerlong), m
						lab var hourswork4_cerlong "Certain & longer: total hours worked in past 4 weeks"
						drop *_4w_cerlong
						
					// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & shorter), average hours per day
						foreach x in $igacateg {
						gen `x'hours_4w_uncshort= `x'hours_4w if `x'length==3
						}
						egen hourswork4_uncshort=rowtotal(*_4w_uncshort), m
						lab var hourswork4_uncshort "Uncertain & shorter: total hours worked in past 4 weeks"
						drop *_4w_uncshort
						
					// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & longer), average hours per day
						foreach x in $igacateg {
						gen `x'hours_4w_unclong= `x'hours_4w if `x'length==4
						}
						egen hourswork4_unclong=rowtotal(*_4w_unclong), m
						lab var hourswork4_unclong "Uncertain & longer: total hours worked in past 4 weeks"
						drop *_4w_unclong
					
				// BY CERTAINTY/LENGTH OF EMPLOYMENT-- 12 MONTHS
					
					// TOTAL HOURS worked PAST 4 WEEKS (Certain & shorter), average hours per day
						foreach x in $igacateg {
						gen `x'hours_12m_cershort= `x'hours if `x'length==1
						}
						egen hourswork_cershort=rowtotal(*_12m_cershort), m
						lab var hourswork_cershort "Certain & short: total hours worked in past 4 weeks"
						drop *_12m_cershort 
							
					// TOTAL HOURS worked PAST 4 WEEKS (Certain & longer), average hours per day
						foreach x in $igacateg {
						gen `x'hours_12m_cerlong= `x'hours if `x'length==2
						}
						egen hourswork_cerlong=rowtotal(*_12m_cerlong), m
						lab var hourswork_cerlong "Certain & longer: total hours worked in past 4 weeks"	
						drop *_12m_cerlong
						
					// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & shorter), average hours per day
						foreach x in $igacateg {
						gen `x'hours_12m_uncshort= `x'hours if `x'length==3
						}
						egen hourswork_uncshort=rowtotal(*_12m_uncshort), m
						lab var hourswork_uncshort "Uncertain & shorter: total hours worked in past 4 weeks"
						drop *_12m_uncshort
						
					// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & longer), average hours per day
						foreach x in $igacateg {
						gen `x'hours_12m_unclong= `x'hours if `x'length==4
						}
						egen hourswork_unclong=rowtotal(*_12m_unclong), m
						lab var hourswork_unclong "Uncertain & longer: total hours worked in past 4 weeks"
						drop *_12m_unclong				
			
		// 8.g. HOURS WORKED BY SIZE OF IGA ORGANIZATION (MICRO, SMALL, MEDIUM, LARGE)

			// BY SIZE OF IGA-- 4 WEEKS
				
				// TOTAL HOURS worked PAST 4 WEEKS (MICRO), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_micro= `x'hours_4w if `x'size==1
					}
					egen hourswork4_micro=rowtotal(*_4w_micro), m
					lab var hourswork4_micro "Micro Firm 0-10 workers: total hours worked in past 4 weeks"
					drop *_4w_micro
						
				// TOTAL HOURS worked PAST 4 WEEKS (SMALL), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_small= `x'hours_4w if `x'size==2
					}
					egen hourswork4_small=rowtotal(*_4w_small), m
					lab var hourswork4_small "Small Firm 11-50 workers: total hours worked in past 4 weeks"
					drop *_4w_small
					
				// TOTAL HOURS worked PAST 4 WEEKS (MEDIUM), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_med= `x'hours_4w if `x'size==3 | `x'size==4
					}
					egen hourswork4_med=rowtotal(*_4w_med), m
					lab var hourswork4_med "Medium Firm 51-200 workers: total hours worked in past 4 weeks"
					drop *_4w_med
					
				// TOTAL HOURS worked PAST 4 WEEKS (LARGE), average hours per day
					foreach x in $igacateg {
					gen `x'hours_4w_large= `x'hours_4w if `x'size==5
					}
					egen hourswork4_large=rowtotal(*_4w_large), m
					lab var hourswork4_large "Large Firm 200+ workers: total hours worked in past 4 weeks"
					drop *_4w_large
			
			// BY SIZE OF IGA-- 12 MONTHS
				
				// TOTAL HOURS worked PAST 12 MONTHS (MICRO), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_micro= `x'hours if `x'size==1
					}
					egen hourswork_micro=rowtotal(*_12m_micro), m
					lab var hourswork_micro "Micro Firm 0-10 workers: total hours worked in past 12 months"
					drop *_12m_micro
						
				// TOTAL HOURS worked PAST 12 MONTHS (SMALL), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_small= `x'hours if `x'size==2
					}
					egen hourswork_small=rowtotal(*_12m_small), m
					lab var hourswork_small "Small Firm 11-50 workers: total hours worked in past 12 months"
					drop *_12m_small
					
				// TOTAL HOURS worked PAST 12 MONTHS (MEDIUM), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_med= `x'hours if `x'size==3 | `x'size==4
					}
					egen hourswork_med=rowtotal(*_12m_med), m
					lab var hourswork_med "Medium Firm 51-200 workers: total hours worked in past 12 months"
					drop *_12m_med
					
				// TOTAL HOURS worked PAST 12 MONTHS (LARGE), average hours per day
					foreach x in $igacateg {
					gen `x'hours_12m_large= `x'hours if `x'size==5
					}
					egen hourswork_large=rowtotal(*_12m_large), m
					lab var hourswork_large "Large Firm 200+ workers: total hours worked in past 12 months"
					drop *_12m_large
					
				// WORKED AT LEAST ONE DAY IN IGA IN PAST 4 WEEKS
			
					foreach x in $igacateg {
						gen `x'_pastmonth = cond(`x'4weeks,1,0,.)
						replace `x'_pastmonth = 0 if `x'length==0 | `x'length==0 | `x'size==1
						lab var `x'_pastmonth "Worked in `x' at least one day in the past 4 weeks"
					}
					
				// WORKED AT LEAST ONE DAY IN A FACTORY OR COMMERCIAL FARM 
					foreach x in fac farmwage {
						gen big`x'_pastmonth = cond(`x'_pastmonth==1 & (`x'length==2 | `x'length==4) & `x'size>1,1,0,.)
							replace big`x'_pastmonth = . if missing(`x'_pastmonth)
							la var big`x'_pastmonth "Worked in `x' with >10 employees, long term, in past month"
					}
					gen facfarm = cond(bigfac_pastmonth == 1 | bigfarmwage_pastmonth == 1,1,0,.)
					replace facfarm =. if bigfac_pastmonth ==. & bigfarmwage_pastmonth ==.
					la var facfarm "Worked in factory or commercial farm in past month"
					
		// 8.h. CASH & PROFIT
			
			// TOTAL CASH EARNED IN PAST 7 DAYS
					egen totalcash7d= rowtotal(*cash7d), m
					label var totalcash7d "Total cash earned from act: past 7 days"

			// TOTAL PROFIT EARNED IN PAST 7 DAYS
					egen totalprofit7d= rowtotal(*prof7d), m
					label var totalprofit7d "Total profit earned from act: past 7 days"
			
			// TOTAL CASH EARNED IN PAST 7 DAYS (BEFORE PAST 7 DAYS)
					egen totalcash7d7= rowtotal(*14cash), m
					label var totalcash7d7 "Total cash earned activities (past 7 days before past 7)"

			// TOTAL PROFIT EARNED IN PAST 7 DAYS (BEFORE PAST 7 DAYS)
					egen totalprofit7d7= rowtotal(*14prof), m
					label var totalprofit7d7 "Total profit earned activities (past 7 days, before past 7)"		
			
			// TOTAL CASH EARNED (AVERAGE: PAST 7 DAYS and 7 DAYS BEFORE PAST 7 DAYS)
					egen totalcash7_av= rowmean(totalcash7d totalcash7d7)
					label var totalcash7_av "Average weekly gross earnings (Average of last week and previous week)"
				
			// TOTAL PROFIT EARNED (AVERAGE: PAST 7 DAYS and 7 DAYS BEFORE PAST 7 DAYS)
					egen totalprofit7_av= rowmean(totalprofit7d totalprofit7d7)
					label var totalprofit7_av "Weekly cash earnings (Average of last week and previous week)"
							
			// ESTIMATED CASH EARNED PER HOUR PER ACTIVITY IN PAST 7 DAYS
				
				// PAST 7 DAYS
					foreach x in $igacateg {
					gen `x'_cashhour7= `x'cash7d/`x'hours_7d
					lab var `x'_cashhour7 "Cash earned per hour (past 7 days): `x'"
					}
					egen cashhour7=rowtotal(*_cashhour7), m
					lab var cashhour7 "Total cash earned per hour (past 7 days)"
				
				// PAST 7 DAYS (BEFORE LAST 7 DAYS)
					foreach x in $igacateg {
					gen `x'_cashhour77= `x'14cash/`x'hours_7d7
					lab var `x'_cashhour77 "Cash earned per hour (past 7 days before last 7 days): `x'"
					}
					egen cashhour77=rowtotal(*_cashhour77), m
					lab var cashhour77 "Total cash earned per hour (past 7 days before last 7 days)"
			
				// Average over last 14 days
				foreach x in $igacateg {
					egen `x'_cashhour= rowmean(`x'_cashhour7 `x'_cashhour77)
					lab var `x'_cashhour "Average cash earned per hour: `x'"
				}
				 
			// CASH PER DAY (CONVERTED): Assuming 5 work days per week
				foreach x in $igacateg {
				gen `x'_cashday=`x'increport if `x'incperiod==1
				replace `x'_cashday=`x'increport/5 if `x'incperiod==2
				replace `x'_cashday=`x'increport/10 if `x'incperiod==3
				replace `x'_cashday=`x'increport/20 if `x'incperiod==4
				replace `x'_cashday=`x'increport/60 if `x'incperiod==6
				replace `x'_cashday=`x'increport/120 if `x'incperiod==7
				replace `x'_cashday=`x'increport/240 if `x'incperiod==8
				label var `x'_cashday "Cash per day (assuming 5 work days a week)"
				}
				egen totcashday=rowtotal(*_cashday), m
				lab var hourswork_large "Total cash per day across IGAs (assuming 5 work days a week)"
				
		// 8.i. FACTORY WORK

			// WORKED AT LEAST ONE MONTH IN FACTORY IN 12 MONTHS
			gen fac_pastyear= cond(fac12months, 1, 0, .)
			lab var fac_pastyear "Worked in factory at least one month in past year"
			
			// WORKED AT LEAST SIX MONTHS IN FACTORY IN 12 MONTHS
			gen fac_halfyear= cond(fac12months, 1, 0, .)
			lab var fac_halfyear "Worked in factory at least six months in past year"
			
			*X* Factory and maybe farm wage labor (for flower farms)
			
		// 8.j. WORK IN ANY IGA
			
			// DID ANY INCOME-GENERATING ACTIVITY IN PAST 4 WEEKS
			gen work_4weeks=cond(hourswork_4w!=0 & hourswork_4w!=., 1, 0)
			lab var work_4weeks "Did any type of work IGA in the past 4 weeks (formal & informal)"
			
			// NO WORK IN PAST 4 WEEKS
			gen nowork_4weeks = cond(hourswork_4w!=0 & hourswork_4w!=., 0, 1)
			la var nowork_4weeks "Did no work in the past 4 weeks (formal & informal)"

			// NO WORK IN PAST 4 WEEKS
			gen nowork_2weeks = cond(hourswork_wk!=0 & hourswork_wk!=., 0, 1)
			la var nowork_2weeks "Did no work in the past 2 weeks (formal & informal)"
			
// 9. FORMAL EMPLOYMENT (Section 9) //

		// EVER WORKED IN FACTORY OR PRIVATE FIRM
				gen factory=cond(fac1==1 | fac2==1 | fac3==1, 1, 0)
				lab var factory "Ever worked in a factory OR private firm"

		// TOTAL MONTHS EXPERIENCE WORKED IN FACTORY OR PRIVATE FIRM:
					replace fac1years = "0" if fac1years=="o"
					destring fac1years, replace
				foreach var of varlist fac1years fac2years fac3years {
					gen `var'_monthtemp=`var'*12
					replace `var'_monthtemp=0 if `var'_monthtemp==.
				}
				egen fac_exper=rowtotal(fac1years_monthtemp fac2years_monthtemp ///
				fac3years_monthtemp fac1months fac2months fac3months), m
				lab var fac_exper "Total months experience working in factory OR private firm"
				drop *_monthtemp
				
				gen fac_expery = fac_exper/12
					lab var fac_expery "Total years experience working in factory OR private firm"


		// EVER WORKED IN WORKSHOP
				gen workshop=cond(shop1==1 | shop2==1 | shop3==1, 1, 0)
				lab var workshop "Ever worked in a workshop"

		// TOTAL MONTHS EXPERIENCE WORKED IN WORKSHOP
				foreach var of varlist shop1years shop2years shop3years {
					gen `var'_monthtemp=`var'*12 
					replace `var'_monthtemp=0 if `var'_monthtemp==.
				}
				egen shop_exper=rowtotal(shop1years_monthtemp shop2years_monthtemp ///
				shop3years_monthtemp shop1months shop2months shop3months), m
				lab var shop_exper "Total months experience working in workshop"
				drop *_monthtemp
				
				gen shop_expery = shop_exper/12
					la var shop_expery "Total years experience working in workshop"

		// EVER WORKED IN STATE ORGANIZATION
				gen state=cond(state1==1 | state2==1, 1 , 0)
				lab var state "Ever worked in a state/parastatal organization"

		// TOTAL MONTHS EXPERIENCE WORKED IN STATE ORGANIZATION
				foreach var of varlist state1years state2years {
					gen `var'_monthtemp=`var'*12
					replace `var'_monthtemp=0 if `var'_monthtemp==.
				}
				egen state_exper=rowtotal(state1years_monthtemp state2years_monthtemp ///
				state1months state2months), m
				lab var state_exper "Total months experience working in state/parastatatal org"
				drop *_monthtemp
				
				gen state_expery = state_exper / 12
					la var state_expery "Total years experience working in state/parastatal org"

		// EVER WORKED IN NGO
				gen ngo=cond(ngo1==1 | ngo2==1, 1, 0)
				lab var ngo "Ever worked in an NGO"

		// TOTAL MONTHS EXPERIENCE WORKED IN NGO
				foreach var of varlist ngo1years ngo2years {
					gen `var'_monthtemp=`var'*12
					replace `var'_monthtemp=0 if `var'_monthtemp==.
				}
				egen ngo_exper=rowtotal(ngo1years_monthtemp ngo2years_monthtemp ///
				ngo1months ngo2months), m
				lab var ngo_exper "Total months experience working in NGO"
				drop *_monthtemp
				
				gen ngo_expery = ngo_exper/12
					la var ngo_expery "Total years experience working in NGO"
		// TOTAL YEARS EXPERIENCE IN STATE/PARASTATAL/NGO WORK
			gen statengo_expery = ngo_expery + state_expery
				la var statengo_expery "Total years experience working in State/Parastatal Org or NGO"
					
		// TOTAL EXPERIENCE IN FORMAL SECTOR WORK
			gen formal_expery = statengo_expery + shop_expery + fac_expery
				la var formal_expery "Total years experience working in factory, workshop, state org, or NGO"
		
		// TOTAL EXPERIENCE IN OTHER FORMAL SECTOR WORK (OTHER OFFICE WORK AND REGULAR WAGE LABOR)
				foreach var of varlist officeyears regworkyears {
					gen `var'_monthtemp=`var'*12 
					*replace `var'_monthtemp=0 if `var'_monthtemp==.
				}
				egen office_exper=rowtotal (officeyears_monthtemp officemonths), m
				lab var office_exper "Total months experience working in Office Job"
				egen regwork_exper=rowtotal (regworkyears_monthtemp regworkmonths), m
				lab var regwork_exper "Total months experience working in other Regular Wage Job"
				drop *_monthtemp
				gen regwork_expery = regwork_exper /12
					la var regwork_expery "Total years experience workin in other Regular Wage Job"
					
		// NOTE: 4 peope working in "Other" jobs were actually working in industrial farms. I switch them to factory here
				qui replace fac_expery = regwork_expery if (regworkind == "FLOWER FARM" | regworkind == "FARM" | regworkind == "IN THIS FLOWER FACTORY THAT I AM APPLIN")
				qui replace regwork_expery = 0 if (regworkind == "FLOWER FARM" | regworkind == "FARM" | regworkind == "IN THIS FLOWER FACTORY THAT I AM APPLING NOW")
				
		// YEARS EXPERIENCE IN NON-FACTORY REGULAR WORK
		egen regwork_nofac_exper=rowtotal (regwork_expery statengo_expery shop_expery ), m
				lab var regwork_nofac_exper "Total years experience working in other regular work that is not a factory"

		// EVER HAD ANY FORMAL SECTOR JOB
				gen formal_sector=cond(factory==1 | shop==1 | state==1 | ngo==1 |office==1 |regwork==1, 1, 0)
				lab var formal_sector "Ever had formal sector job"
				
		// EVER WORKED IN FIRM/ORGANIZATION WITH RELEVANT SKILL
				egen formal_relevant=rowmax(fac1relev fac2relev fac3relev shop1relev shop2relev ///
				shop3relev state1relev state2relev ngo1relev ngo2relev officerelev regworkrelev)
				replace formal_relevant=0 if formal_relevant==.
				lab var formal_relevant "Ever worked in firm with relevant skill"
				
		// RECEIVED ANY ON-THE-JOB TRAINING
				egen ojt=rowtotal(fac1train fac2train fac3train shop1train shop2train shop3train ///
				state1train state2train ngo1train ngo2train officetrain regworktrain), m
				replace ojt=1 if ojt>1
				replace ojt=0 if ojt==.
				lab var ojt "Received on-job training in formal sector"

		// EVER WORKED IN MICRO FIRM (0-10 WORKERS)

			gen formal_micro=1 if fac1workers==1 | fac2workers==1 | fac3workers==1 | shop1workers==1 | shop2workers==1 | shop3workers==1 | ///
			state1workers==1 | state2workers==1 | ngo1workers==1 | ngo2workers==1 | officeworkers==1 | regworkworkers==1 
			replace formal_micro=0 if formal_micro==. 
			label var formal_micro "Ever worked in a small firm (0-10 workers)"

		// EVER WORKED IN SMALL FIRM (11-50 WORKERS)

			gen formal_small=1 if fac1workers==2 | fac2workers==2 | fac3workers==2 | shop1workers==2 | shop2workers==2 | shop3workers==2 | ///
			state1workers==2 | state2workers==2 | ngo1workers==2 | ngo2workers==2 | officeworkers==2 | regworkworkers==2 
			replace formal_small=0 if formal_small==. 
			label var formal_small "Ever worked in a small firm (11-50 workers)"

		// WORKED IN MEDIUM FIRM (50-200 WORKERS)

			gen formal_medium=1 if fac1workers==3 | fac2workers==3 | fac3workers==3 | shop1workers==3 | shop2workers==3 | shop3workers==3 | ///
			state1workers==3 | state2workers==3 | ngo1workers==3 | ngo2workers==3 | officeworkers==3 | regworkworkers==3 | ///
			fac1workers==4 | fac2workers==4 | fac3workers==4 | shop1workers==4 | shop2workers==4 | shop3workers==4 | ///
			state1workers==4 | state2workers==4 | ngo1workers==4 | ngo2workers==4| officeworkers==4 | regworkworkers==4 
			replace formal_medium=0 if formal_medium==. 
			label var formal_medium "Ever worked in a medium firm (50-200 workers)"
				
		// EVER WORKED IN LARGE FIRM (200+ WORKERS)

			gen formal_large=1 if fac1workers==5 | fac2workers==5 | fac3workers==5 | shop1workers==5 | shop2workers==5 | shop3workers==5 | ///
			state1workers==5 | state2workers==5 | ngo1workers==5 | ngo2workers==5 | officeworkers==5 | regworkworkers==5 
			replace formal_large=0 if formal_large==. 
			label var formal_large "Ever worked in a large firm (200+ workers)"
				
		// RELABEL YES/NO VARIABLES FOR FORMAL & GENERAL EMPLOYMENT		
				foreach var of varlist factory workshop state ngo formal_sector ///
				formal_relevant ojt fac_pastmonth work_4weeks ///
				formal_micro formal_small formal_medium formal_large {
					lab val `var' yesno
				}
					
		*X* Create variables using minimum education needed to do job "*educ"


// 10. WEALTH AND CONSUMPTION (Section 10) //

		// CONVERTING COHORT 101 DATA (TIME UNIT)

			// SPEND OUT VARIABLES
				gen x_eatout=eatout
				replace x_eatout=x_eatout*7 if eatoutunit==1
				replace x_eatout=eatout/4 if eatoutunit==3
				replace eatout=x_eatout if projid==101
				
				gen x_tea=tea
				replace x_tea=x_tea*7 if teaunit==1
				replace x_tea=tea/4 if teaunit==3
				replace tea=x_tea if projid==101
				
				gen x_alco=alco
				replace x_alco=x_alco*7 if alcounit==1
				replace x_alco=alco/4 if alcounit==3
				replace alco=x_alco if projid==101
				
				drop x_eatout x_tea x_alco eatoutunit teaunit alcounit
				
			// CONSUMPTION VARIABLES
				gen x_mobile=mobile
				replace x_mobile=x_mobile*30 if mobileunit==1
				replace x_mobile=mobile*4 if mobileunit==2
				replace mobile=x_mobile if projid==101
			
				gen x_transpo=transpo
				replace x_transpo=x_transpo*30 if transpounit==1
				replace x_transpo=transpo*4 if transpounit==2
				replace transpo=x_transpo if projid==101

				gen x_cigs=cigs
				replace x_cigs=x_cigs*30 if cigsunit==1
				replace x_cigs=cigs*4 if cigsunit==2
				replace cigs=x_cigs if projid==101
				
				gen x_chat=chat
				replace x_chat=x_chat*30 if chatunit==1
				replace x_chat=chat*4 if chatunit==2
				replace chat=x_chat if projid==101
			
				drop x_mobile x_transpo x_cigs x_chat 
				drop mobileunit transpounit cigsunit chatunit
			
		// WEALTH INDEX VARIABLES: CREATE HOUSING QUALITY VARIABLES

				gen roompc=rooms/hhsize
				lab var roompc "Rooms per person" 

				recode hometen (1=1)(2/7=0)(else=.), gen(home_own) lab(yesno)
				lab var home_own "Owns home"
				recode hometen (4=1)(1/3 5/7=0)(else=.), gen(home_rentpr) lab(yesno)
				lab var home_rentpr "Rents home, private person"

				recode walls (1/4=1) (5/8=0)(else=.), gen(impr_walls) lab(yesno)
				lab var impr_walls "Walls constructed of improved materials (brick, concrete)"
				recode roof (1 2=1) (3/6=0)(else=.), gen(impr_roof) lab(yesno)
				lab var impr_roof "Roof constructed of improved materials (iron, concrete)"
				recode floor (2/5=1) (1 6=0)(else=.), gen(impr_floor) lab(yesno)
				lab var impr_floor "Floor constructed of improved materials (tiles, concrete)"

				recode water (1=1)(2/8=0)(else=.), gen(water_taphouse) lab(yesno)
				lab var water_taphouse "Tap inside house"
				recode water (2=1)(1 3/8=0)(else=.), gen(water_tapcompound) lab(yesno)
				lab var water_tapcompound "Tap inside compound"
				recode water (3/5 7=1)(1 2 6 8=0)(else=.), gen(water_protect) lab(yesno)
				lab var water_protect "Tap or other protected source outside compound"
				recode water (6 8=1)(1/5 7=0)(else=.), gen(water_unprotect) lab(yesno)
				lab var water_unprotect "Unprotected source"

				recode toilet (1 2=1)(3/5=0)(else=.), gen(toil_flush) lab(yesno)
				lab var toil_flush "Flush toilet"                 
				recode toilet (3=1)(1 2 4 5=0)(else=.), gen(toil_pitprivate) lab(yesno)
				lab var toil_pitprivate "Private pit latrine"                
				recode toilet (4=1)(1 2 3 5=0)(else=.), gen(toil_pitshare) lab(yesno)
				lab var toil_pitshare "Shared pit latrine"                
				recode kitchen (1 2=1)(3/7=0)(else=.), gen(kitch_modern) lab(yesno)
				lab var kitch_modern "Modern kitchen, private or shared"   

				recode kitchen (3 4=1)(1 2 5/7=0)(else=.), gen(kitch_semimodern) lab(yesno)
				lab var kitch_semimodern "Semi-modern kitchen, private or shared"   
				recode kitchen (5=1)(1/4 6 7=0)(else=.), gen(kitch_trad_priv) lab(yesno)
				lab var kitch_trad_priv "Private traditional kitchen"                 
				recode kitchen (6=1)(1/5 7=0)(else=.), gen(kitch_trad_share) lab(yesno)
				lab var kitch_trad_share "Shared traditional kitchen"                

				recode kitchen (7=1)(1/6=0)(else=.), gen(kitch_none) lab(yesno)
				lab var kitch_none "No kitchen"   
				recode cooking (4/7=1)(1/3 8 9=0)(else=.), gen(cook_woodchar) lab(yesno)
				lab var cook_woodchar "Use wood, charcoal for cooking"
				recode cooking (1/3=1)(4/9=0)(else=.), gen(cook_gaselect) lab(yesno)
				lab var cook_gaselect "Use gas, electricity for cooking"

				recode bathing (7=1)(1/6 8=0)(else=.), gen(bath_pay) lab(yesno)
				lab var bath_pay "Bathe in paid facility" 
				recode bathing (8=1)(1/7=0)(else=.), gen(bath_none) lab(yesno)
				lab var bath_none "No bathing facility" 
				recode bathing (1/6=1)(7 8=0)(else=.), gen(bath_tubshower) lab(yesno)
				lab var bath_tubshower "Private or shared shower or tub"                
				
		// DUMMY ON HUNGER (FOOD SECURITY)
				recode hungry (1/7=1)(0=0)(else=.), gen(bed_hungry) lab(yesno)
				lab var bed_hungry "Went to bed hungry at least once in past week"                

		// CONSUMPTION/EXPENDITURE VARIABLES
				gen mobilex=mobile
				lab var mobilex "Amount spent on mobile cards or fixed phones per month(Birr)"
						
		// DUMMIES FOR LAND OWNERSHIP
				
				gen haslandbus=cond(landbus>0 & landbus<.,1,0)
				lab var haslandbus "Has access to land for business use"
				replace haslandbus=. if landbus==.
				gen haslandrent=cond(landrent>0 & landrent<.,1,0)
				lab var haslandrent "Has access to land that is rented out"
				replace haslandrent=. if landrent==.
				gen haslandcult=cond(landcult>0 & landcult<.,1,0)
				lab var haslandcult "Has access to land that is being cultivated"
				replace landcult=. if landcult==-77
				replace haslandcult=. if landcult==. 
				gen haslandfallow=cond(landfallow>0 & landfallow<.,1,0)
				replace haslandfallow=. if landfallow==.
				lab var haslandfallow "Has access to land that is left fallow"

				egen hasland=rowtotal(haslandbus haslandrent haslandcult haslandfallow), m
				recode hasland (1 2 3 4=1)
				lab var hasland "Has access to land"

			// GENERATE WEALTH INDEX [Need consistency with endline HH]
		
				desc home_own home_rentpr rooms roompc impr_walls impr_roof impr_floor water_taphouse ///
				water_tapcompound water_protect water_unprotect toil_flush toil_pitprivate toil_pitshare kitch_trad_priv ///
				kitch_trad_share kitch_modern kitch_semimodern kitch_none cook_woodchar cook_gaselect bath_pay bath_none ///
				bath_tubshower fanos radio bike watch jewelry phone tv videocasette satellite refrigerator ///
				mitad stove sewing cattle goats donkeys poultry hasland

				*X* haslandfallow haslandcult haslandrent haslandbus  replaced with hasland // bsm 2012.03.26
				*X* water_taphouse toil_flush bike donkeys haslandrent impr_roof : Dropped because of Zero variance
				 
				
				factor home_own home_rentpr rooms roompc impr_walls impr_floor  ///
				water_tapcompound water_protect toil_pitprivate toil_pitshare kitch_trad_priv ///
				kitch_trad_share kitch_semimodern kitch_none cook_woodchar cook_gaselect bath_pay bath_none ///
				bath_tubshower fanos radio  watch jewelry phone tv videocasette satellite refrigerator ///
				mitad stove water_unprotect kitch_modern

				predict consdur
					qui sum consdur
					qui replace consdur = (consdur-r(mean))/r(sd)
				lab var consdur "Wealth index: Consumption Durables"
				
				factor sewing cattle goats poultry hasland 
				predict proddur
					qui sum proddur
					qui replace proddur = (proddur-r(mean))/r(sd)
				lab var proddur "Wealth index: Production Durables"
				
		// RELABEL YES/NO FOR CASH/SAVINGS VARIABLES
				foreach var of varlist owebank-oweother compland othercomp borr1000med borr3000bus borr10000bus owe100birr {
				lab val `var' yesno
				}

		// PURCHASES CONSUMED OUTSIDE HOME (FOOD/DRINKS)
			egen spendout=rowtotal (eatout tea alco), m
			label var spendout "Amount spend on items consumed outside home, last 7 days"
			
		// PERSONAL EXPENDITURES IN LAST MONTH (micro ITEMS)
			egen ownconsume=rowtotal (mobile transpo cigs chat cosmetics luxury), m
			label var ownconsume "Amount spent on micro expenditures for self in last month"	
			
		// GENERATE ECONOMIC WELL-BEING INDEX
			foreach x in consdur totalprofit7_av {
				sum `x', d
				gen temp = cond(`x'>r(p99),r(p99),`x') if !missing(`x')
				sum temp
				gen `x'_std = (temp - r(mean))/r(sd)
				drop temp
			}
			egen success_index = rowmean (consdur_std totalprofit7_av_std)
				sum success_index
				qui replace success_index = (success_index - r(mean))/r(sd)
				la var success_index "Economic success index (wealth and weekly profit)"
			drop consdur_std totalprofit7_av_std
				
// 11. COGNITIVE (Section 11) //

		// SIMPLE COGNITIVE ADDITIVE INDEXES (SUMMING CORRECT SCORES)
			
			// NUMBER SEQUENCE
			egen sequence=rowtotal(seq2 seq3 seq4a seq4b seq5 seq6 seq7 seq8), m
			lab var sequence "Number of number sequence questions correct, of 8"
			
			// REVERSE NUMBER SEQUENCE
			egen revsequence=rowtotal(revseq2 revseq3a revseq3b revseq4a revseq4b revseq5 revseq6), m
			lab var revsequence  "Number of reverse sequence questions correct, of 8"
			
			// MATH QUESTIONS
			egen all_math= rowtotal( plus3 plus36 minus9 calcprofit divide6 times11 ///
			multiplydivide multiplydivide2 calcincome doubling calcinterest), m
			lab var all_math "Total math questions correct (11)"
			
			// ARROWS
			foreach x in totaltime_ra totime_oa totime_da {
				split `x', parse(":") destring
				gen `x'sec = `x'1/60 + `x'2 + `x'3*100
				drop `x'1 `x'2 `x'3
			}
			ren totaltime_rasec timesec_ra
				la var timesec_ra "Seconds spent on regular arrows"
			ren totime_oasec timesec_oa
				la var timesec_oa "Seconds spent on opposite arrows"
			ren totime_dasec timesec_da
				la var timesec_da "Seconds spent on different arrows"
				
			// Mazes
			forv x = 1/3 {
				split totaltime_m`x', parse(":") destring
				gen totsec_m`x' = totaltime_m`x'1/60 + totaltime_m`x'2 + totaltime_m`x'3*100
				drop totaltime_m`x'1 totaltime_m`x'2 totaltime_m`x'3	
				la var totsec_m`x' "Seconds spent on maze `x'"
			}
			forv x = 1/3 {
				split timetouch_m`x', parse(":") destring
				gen touchsec_m`x' = timetouch_m`x'1/60 + timetouch_m`x'2 + timetouch_m`x'3*100
				drop timetouch_m`x'1 timetouch_m`x'2 timetouch_m`x'3	
				la var touchsec_m`x' "Seconds before first touch on maze `x'"
			}
			
			// Create overall index
			/* Orthogonalize components */
			foreach x in oa da {
				foreach m in timesec numwrong {
					qui reg `m'_`x' `m'_ra
					qui predict `m'_`x'_res, xb
				}
			}
			qui regress revsequence sequence
			qui predict revsequence_res, xb
			
			/* Standardize components */
			foreach x in touchsec_m3 backtrack_m3 revsequence_res sequence {
				qui sum `x', d
				qui gen `x'_m = cond(!missing(`x'),`x',r(p50))
				qui sum `x'_m
				qui gen `x'_std = (`x'_m - r(mean))/r(sd)
			}
			/* Standardize and reverse */
			foreach x in timesec_oa_res timesec_da_res 	///
			numwrong_oa_res numwrong_da_res timesec_ra numwrong_ra {
				qui sum `x', d
				qui gen `x'_m = cond(!missing(`x'),`x',r(p50))
				qui sum `x'_m
				qui gen `x'_std = -(`x'_m - r(mean))/r(sd)
			}
			egen cognitive_score = rowmean(timesec_ra_std numwrong_ra_std sequence_std)
				qui sum cognitive_score
				qui replace cognitive_score = (cognitive_score-r(mean))/r(sd)
				la var cognitive_score "Additive index of performance on regular arrows and forward digit recall"
			egen executive_score = rowmean(touchsec_m3_std backtrack_m3_std revsequence_res_std 	///
			timesec_oa_res_std timesec_da_res_std numwrong_oa_res_std numwrong_da_res_std)
				qui sum executive_score
				qui replace executive_score = (executive_score-r(mean))/r(sd)
				la var executive_score "Additive index of performance on mazes, arrows, and digit recall excercises"
			drop touchsec_m3_std revsequence_res_std 	///
			timesec_oa_res_std timesec_da_res_std numwrong_oa_res_std ///
			numwrong_da_res_std revsequence_res 	///
			timesec_oa_res timesec_da_res numwrong_oa_res ///
			numwrong_da_res
			
			* Generate overall cognitive index
			egen cog_overall_index = rowmean (cognitive_score executive_score)
				qui sum cog_overall_index
				qui replace cog_overall_index = (cog_overall_index - r(mean))/r(sd)
				la var cog_overall_index "Index combining cognitive score and executive function"
				
// 12. NON-COGNITIVE (Section 12) //

		// RECODE "AGREE" SCALE VARIABLES: (a new var is generated with prefix "r_")
				recode locus1-locus8 ///
				(4=0 "Strongly disagree") (3=1 "Somewhat disagree") ///
				(2=2 "Somewhat agree") (1=3 "Strongly agree"), pre(r_) lab (agree_recode)

		// LOCUS OF CONTROL INDEX (GREATER CONTROL IS HIGHER VALUE)
				recode r_locus1 r_locus2 r_locus4 r_locus5 r_locus8 (0=0), pre(rank_)
				recode r_locus3 r_locus6 r_locus7 (3=0)(2=1)(1=2)(0=3), pre(rank_)
					egen locuscontrol =rowtotal(rank_r_locus*), m
					lab var locuscontrol "Additive locus of control index, 0-24(more control)"

		// SELF ESTEEM INDEX (GREATER ESTEEM IS HIGHER VALUE)
				recode r_esteem1 r_esteem5 r_esteem7 (0=0), pre(rank_)
				recode r_esteem2 r_esteem3 r_esteem4 r_esteem6 r_esteem8 ///
				 (3=0)(2=1)(1=2)(0=3), pre(rank_)
					egen selfesteem =rowtotal(rank_r_esteem*), m
					lab var selfesteem "Additive self esteem index, 0-24(higher self esteem)"

		// PLANNING & ORGANIZATION INDEX (GREATER PLANNING IS HIGHER VALUE)
				recode r_planning3 r_planning4 r_planning5 r_planning6 r_planning8 (0=0), pre(rank_)
				recode r_planning1 r_planning2 r_planning7 (3=0)(2=1)(1=2)(0=3), pre(rank_)
					egen planning =rowtotal(rank_r_plan*), m
					lab var planning "Additive planning index, 0-24(better planning)"

				drop rank_r_lo* rank_r_est* rank_r_pl* 

		/* Create overall mental health index */
			foreach x in phqtotal gadtotal selfesteem {
				qui sum `x'
				gen `x'_std = (`x'-r(mean))/r(sd)
			}
			egen mentalhealth_index = rowmean (phqtotal_std gadtotal_std selfesteem_std)
				qui sum mentalhealth_index
				qui replace mentalhealth_index = (mentalhealth_index-r(mean))/r(sd)
				la var mentalhealth_index "Index of mental health - depression, anxiety, and self esteem (higher = more health)"
			drop phqtotal_std gadtotal_std selfesteem_std

// 13. TIME AND RISK (Section 13) //

		*X* Fix the coding here (not all of the vars are yes/no)

		// RECODE: RECODING VARIABLES TO YES/NO (GENERATES NEW VARIABLE ENDING WITH "X")
				foreach var of varlist time1-control8  {
					recode `var' (2=0), gen(`var'x) lab(yesno)
				}

		// TIME PREFERENCE INDEX (HIGHER VALUE: MORE PATIENT)

				recode time2x  (0=0), pre(rank_)
				recode time1x time3x time4x time5x time6x ///
				time7x time8x(0=1)(1=0), pre(rank_)

				egen patience = rowtotal(rank_time*), m
				lab var patience "Additive patience (discount rate) index, 0-16(more patient)"

				lab var time1x     "1000 Birr now over 100 Birr a week for 10 weeks"
				lab var time2x     "Save some of 500 Birr earned for future problems"
				lab var time3x     "1000 Birr 1 week from now over 100 Birr a week for 15 weeks"
				lab var time4x     "1000 Birr now over 100 Birr a week for 12 weeks"
				lab var time5x     "Option A: do easy task first over Option B: do hard task first"
				lab var time6x     "If get money, do you spend it too quickly?"
				lab var time7x     "Often postpone tasks to do it later"
				lab var time8x     "1000 Birr job-end anytime over 700 Birr job-can keep forever"

		// RISK AVERSION INDEX (HIGHER VALUE: MORE AVERSE)
				
				recode risk1x risk2x risk3x risk5x risk7x (0=0), pre(rank_)
				recode risk4x risk6x risk8x (0=1)(1=0), pre(rank_)

				egen riskaversion = rowtotal(rank_ris*), m
				lab var riskaversion "Additive risk aversion index, 0-24(more averse)"

				lab var risk1x     "Like to find out risks before doing something"
				lab var risk2x     "400 Birr for sure over flip a coin for 1000 Birr"
				lab var risk3x     "If uncertain about risks of job/business, gets very anxious"
				lab var risk4x     "Two choices: high profits but risky over low profits but safe"
				lab var risk5x     "Disturbed by uncertainty of effects of decisions one makes"
				lab var risk6x     "Willing to take risks in your life, relative to one's friends"
				lab var risk7x     "A: reduce leg pain, but not cure over B: cure leg pain, but chance of death"
				lab var risk8x     "Sometimes do dangerous things for fun"

		// SELF-CONTROL INDEX (HIGHER VALUE: MORE CONTROL)

				recode control3x control7x (0=0), pre(rank_) 
				recode control1x control2x control4x control5x ///
				control6x control8x (0=1)(1=0), pre(rank_) 

				egen selfcontrol = rowtotal(rank_contr*), m
				lab var selfcontrol "Additive self control index, 0-24(more control)"
				
				lab var control1x  "Regret spending money on some things"
				lab var control2x  "Wishes had more self-discipline"
				lab var control3x  "When something becomes difficult, will you continue doing it?"
				lab var control4x  "Put money in to safe place so not spend in quickly"
				lab var control5x  "Buy something right away or wait how feel about it later"
				lab var control6x  "Have trouble starting a task"
				lab var control7x  "Good at resisting temptation"
				lab var control8x  "Often speaks before thinking"

				drop rank_co* rank_ri* rank_ti* 
		// IBM Games
			/* Patience */
			egen patience0_ibm = rowtotal(money1_tp money3_tp money4_tp), m
				replace patience0_ibm = patience0_ibm - 3
				replace patience0_ibm = 0 if patience0_ibm < 0
				la var patience0_ibm  "Patience from today to 1 week from now (0-3)"
			egen patience1_ibm = rowtotal(money2_tp money5_tp money6_tp), m
				replace patience1_ibm = patience1_ibm - 3
				replace patience1_ibm = 0 if patience1_ibm < 0
				la var patience1_ibm  "Patience from 2 weeks from now to 3 weeks from now (0-3)"	
			qui gen patience_ibm = patience0_ibm + patience1_ibm
				la var patience_ibm  "Patience measure from the IBM games (0-6)"
			qui gen timeinc_ibm = patience1_ibm - patience0_ibm + 3
				la var timeinc_ibm "Time inconsistency from IBM games (0-6)"
			/* Overall patience measure */
			foreach x in patience_ibm timeinc_ibm patience selfcontrol {
				qui egen `x'_std = std(`x')
			}
			qui replace timeinc_ibm_std = - timeinc_ibm
			qui egen patience_all = rowtotal(patience_ibm_std timeinc_ibm_std selfcontrol_std patience_std), m
				qui sum patience_all
				qui replace patience_all = (patience_all-r(mean))/r(sd)
				la var patience_all "Standardized index of declared patience, declared self-control, patience and time consistency in IBM games"
			drop patience_ibm_std timeinc_ibm_std selfcontrol_std patience_std
			/* Risk Aversion */
			egen riskaversion_ibm = rowtotal(money7_rg money8_rg money9_rg money10_rg), m
				qui replace riskaversion_ibm = - riskaversion_ibm + 8
				la var riskaversion_ibm "Risk aversion measure from IBM games (0-4)"
			/* Overall risk aversion */
			foreach x in riskaversion_ibm riskaversion {
				qui egen `x'_std = std(`x')
			}
			qui egen riskaversion_all = rowtotal(riskaversion_ibm_std riskaversion_std), m
				qui sum riskaversion_all
				qui replace riskaversion_all = (riskaversion_all - r(mean))/r(sd)
				la var riskaversion_all "Standardized index of risk aversion from survey and IBM games"
			qui drop riskaversion_ibm_std riskaversion_std

// 14. AGRESSION & ABUSE (Section 14) //	
		
		// ABUSE/HARASSMENT RECEIVED
				recode threat humiliate beat kick accuse limitfamily knowalltimes (4=0) (3=1) (2=2) (1=3), pre(rank_)
				foreach x in threat humiliate beat kick accuse limitfamily knowalltimes {
				replace rank_`x'=. if rank_`x'==5
				}
				egen abusein= rowtotal(rank_threat rank_humiliate rank_beat rank_kick ///
				rank_accuse rank_limitfamily rank_knowalltimes), m
				label var abusein "Frequency of abuse received 0-21: more abuse"
				replace abusein=. if projid==101 | projid==102
				
		// EMPOWERMENT
				recode expressopinion holdmoney allowedmarket (4=0) (3=1) (2=2) (1=3), pre(rank_)
				egen empowered= rowtotal(rank_expressopinion rank_holdmoney rank_allowedmarket), m
				label var empowered "Freedom in money/market access 0-12: more free"
		
		// AGRESSIVE BEHAVIOR VARIABLES *F*
/*				// NEGATIVE
				recode agg_insult agg_arguehh agg_argueout agg_argueviolence agg_frustration agg_fight ///
				agg_threat agg_arguepolice (1=0) (2=1) (3=2) (4=3), pre(r_)
				// POSITIVE
				recode agg_anger (1=3) (2=2) (3=1) (4=0), pre(r_)
				egen agression= rowtotal (r_agg*), m
				label var agression "Aggressive behavior 0-27 (27: More Aggressive)"
			
				replace agression=. if projid==101

*/				
		// AGRESSIVE BEHAVIOR VARIABLES *F*
				// NEGATIVE
				*foreach x in agg_insult agg_arguehh agg_argueout agg_argueviolence agg_frustration agg_fight {
				*drop if `x'==.
				*}
				recode agg_insult agg_arguehh agg_argueout agg_argueviolence agg_frustration agg_fight ///
				agg_threat agg_arguepolice (1=3) (2=2) (3=1) (4=0), pre(r_)
				// POSITIVE
				recode agg_anger (1=0) (2=1) (3=2) (4=3), pre(r_)
				egen agression= rowtotal (r_agg*), m
				label var agression "Aggressive behavior 27-0 (0: More Aggressive)"
	

// 15. INCOME RISK (Section 15) //

		// SIMPLE DIFFERENCES BETWEEN HIGHEST POSSIBLE INCOME TO LOWEST POSSIBLE INCOME
				gen incdiff30=high30days-low30days
				lab var incdiff30 "Diff btw highest lowest possible income in next 30 days"
				gen incdiff12=high12months-low12months
				lab var incdiff12 "Diff btw highest lowest possible income in next 12 mon"

		// 	DIFF BETWEEN HIGHEST AND LOWEST INCOME PER MONTH FOR THE NEXT TWELVE MONTHS
				gen incdiff12_permon = incdiff12/ 12
				lab var incdiff12_permon "Highest - lowest earnings per month"
				
		// Turn 1-10 likelihoods into probabilities
				gen prob_betterjob = likely_betterjob/10
					la var prob_betterjob "Probability (0-1) that respondent will find a better job in 30 days"
				gen prob_regwork = likely_regwork/10
					la var prob_regwork "Probability (0-1) that respondent will find regular work in 30 days"
					
		// OVERALL OPTIMISM INDEX
			egen optimism_index = rowmean(prob_betterjob prob_regwork)
				la var optimism_index "Average of probablity that respondent will find regular work and a better job in next month"

// 16. IBM //

		// CONVERTING TIME TO MINUTES: MAZE, FROG AND ARROW 
			foreach var of varlist timetouch_m1 totaltime_m1 timetouch_m2 totaltime_m2 timetouch_m3 totaltime_m3 totaltime_ra ///
			totime_oa totime_da time_fg1 time_fg2 time_fg3 time_fg4 time_fg5 {
			split `var', p(:)
			} 

			foreach var of varlist timetouch_m11 timetouch_m12 timetouch_m13 timetouch_m21 timetouch_m22 timetouch_m23 ///
			timetouch_m31 timetouch_m32 timetouch_m33 totaltime_m11 totaltime_m12 totaltime_m13 totaltime_m21 totaltime_m22 ///
			totaltime_m23 totaltime_m31 totaltime_m32 totaltime_m33 totaltime_ra1 totaltime_ra2 totaltime_ra3 totime_oa1 ///
			totime_oa2 totime_oa3 totime_da1 totime_da2 totime_da3 time_fg11 time_fg12 time_fg13 time_fg21 time_fg22 time_fg23 ///
			time_fg31 time_fg32 time_fg33 time_fg41 time_fg42 time_fg43 time_fg51 time_fg52 time_fg53 {
			destring `var', replace
			}

			gen timetouchmin_m1=timetouch_m11+timetouch_m12/60+timetouch_m13/60000
			lab var timetouchmin_m1 "Time respondent first touched Maze 1 (minutes)"
			gen timetouchmin_m2=timetouch_m21+timetouch_m22/60+timetouch_m23/60000
			lab var timetouchmin_m2 "Time respondent first touched Maze 2 (minutes)"
			gen timetouchmin_m3=timetouch_m31+timetouch_m32/60+timetouch_m33/60000
			lab var timetouchmin_m3 "Time respondent first touched Maze 3 (minutes)"

			gen totaltimemin_m1=totaltime_m11+totaltime_m12/60+totaltime_m13/60000
			lab var totaltimemin_m1 "Time taken to finish Maze 1 (minutes)"
			gen totaltimemin_m2=totaltime_m21+totaltime_m22/60+totaltime_m23/60000
			lab var totaltimemin_m2 "Time taken to finish Maze 2 (minutes)"
			gen totaltimemin_m3=totaltime_m31+totaltime_m32/60+totaltime_m33/60000
			lab var totaltimemin_m3 "Time taken to finish Maze 3 (minutes)"

			gen totaltimemin_ra=totaltime_ra1+totaltime_ra2/60+totaltime_ra3/60000
			lab var totaltimemin_ra "Total time taken to complete regular arrow game (minutes)"
			gen totaltimemin_oa=totime_oa1+totime_oa2/60+totime_oa3/60000
			lab var totaltimemin_oa "Total time taken to complete opposite arrow game (minutes)"
			gen totaltimemin_da=totime_da1+totime_da2/60+totime_da3/60000
			lab var totaltimemin_da "Total time taken to complete different arrow arrow game (minutes)"

			gen timemin_fg1=time_fg11+time_fg12/60+time_fg13/60000
			lab var timemin_fg1 "Frog Game 1 total time taken (minutes)"
			gen timemin_fg2=time_fg21+time_fg22/60+time_fg23/60000
			lab var timemin_fg2 "Frog Game 2 total time taken (minutes)"

			gen timemin_fg3=time_fg31+time_fg32/60+time_fg33/60000
			lab var timemin_fg3 "Frog Game 3 total time taken (minutes)"
			gen timemin_fg4=time_fg41+time_fg42/60+time_fg43/60000
			lab var timemin_fg4 "Frog Game 4 total time taken (minutes)"
			gen timemin_fg5=time_fg51+time_fg52/60+time_fg53/60000
			lab var timemin_fg5 "Frog Game 5 total time taken (minutes)"

			foreach var of varlist timetouch_m11 timetouch_m12 timetouch_m13 timetouch_m21 timetouch_m22 timetouch_m23 ///
			timetouch_m31 timetouch_m32 timetouch_m33 totaltime_m11 totaltime_m12 totaltime_m13 totaltime_m21 totaltime_m22 ///
			totaltime_m23 totaltime_m31 totaltime_m32 totaltime_m33 totaltime_ra1 totaltime_ra2 totaltime_ra3 totime_oa1 ///
			totime_oa2 totime_oa3 totime_da1 totime_da2 totime_da3 time_fg11 time_fg12 time_fg13 time_fg21 time_fg22 time_fg23 ///
			time_fg31 time_fg32 time_fg33 time_fg41 time_fg42 time_fg43 time_fg51 time_fg52 time_fg53 {
			drop `var'
			}
	
	// 17. Misc administrative variables
			replace translator = 0 if missing(translator)
			
******************************************
saveold "$ILEdata\ILE.bl_constructed.dta", replace 
******************************************
			
exit
