*******************************************************************************************************************
* ILE: ENDLINE VARIABLE CONSTRUCTION CODE
*******************************************************************************************************************
*******************************************************************************************************************

/* CONTENT **********************************************

I. Directory information

II. Individual survey 

	1. Skills and education 
	2. Household and community
	3. Children roster
	4. Firms and labor attitudes
	5. Cash and savings
	6. Employment / Income generating activities
	7. Full time regular employment
	8. Health: physical and psychosocial
	9. Consumption
	10. Workplace condition
	11. Income risk
	12. Empowerment
	13. Time-use
	14. Aggression and abuse
	15. Non-cognitive skills
	16. Informal network
	17. Social network (random names)
	18. Time and risk
	19. Socio-political attitudes

III. Household survey

	1. Household roster
	2. Economic activities
	3. Compensation and transfers
	4. Consumption and expenditures
	5. Food security
	6. Dwelling and wealth
	7. Household time-use
	8. Perception of individual 

*********************************************************/

clear
clear matrix
set mem 500m
set more off
tempfile tempdata
set matsize 800

// I. DIRECTORY INFORMATION //
***********************************

********************************************************
** 1. MERGING ENDLINE DATA FILES
*********************************************************
		
// Wave: baseline, endline (1Y) and endline (2Y)
// Round: 1=11m 2=12m 3=13m 4=23m 5=25m

	// Temp Files
		tempfile temp_ei11 temp_ei12 temp_ei13 temp_ei23 temp_ei25 temp_eh11 temp_eh12 temp_eh23 temp_e11 temp_e12 temp_e23	
	
	// ENDLINE INDIVIDUAL (11 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1123m_clean.dta", clear
	
		keep if wave=="11m"

		* Check Duplicates
			duplicates tag appid, gen (dup)
			drop if appid==.
			assert dup ==0
			drop dup
		
		drop wave
		gen round_i=1
		gen wave_i=1
		
		sort appid
		save "`temp_ei11'", replace
	
	// ENDLINE INDIVIDUAL (12 MONTH)-- ONLY for P101
	
		use "$ILEdata/raw/ILE.ind.12m_clean.dta", clear
		
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
		
		gen round_i=2
		gen wave_i=1
		
		sort appid
		save "`temp_ei12'", replace
		
	// ENDLINE INDIVIDUAL (13 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1325m_clean.dta", clear

		keep if wave=="13m"
		
		* Check Duplicates
			duplicates tag appid, gen (dup)
			drop if dup == 1 & timestamp01 == "9/5/2014 7:48:31"
			drop dup
		
		gen round_i=3
		gen wave_i=1
		
		replace c2_helpoutsum="150" if c2_helpoutsum=="$150.00" // 
		replace c2_helpoutsum="200" if c2_helpoutsum=="$200.00"
		replace c2_helpoutsum="25" if c2_helpoutsum=="$25.00"
		destring c2_helpoutsum, replace
	 
		sort appid
		save "`temp_ei13'", replace
	
	// ENDLINE INDIVIDUAL (23 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1123m_clean.dta", clear
		
		keep if wave=="23m"
	
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
	
		gen round_i=4
		gen wave_i=2
		
		sort appid
		save "`temp_ei23'", replace
	
	// ENDLINE INDIVIDUAL (25 MONTH)
		
		use "$ILEdata/raw/ILE.ind.1325m_clean.dta", clear
		
		keep if wave=="25m"
		
		* Check Duplicates
			duplicates tag appid, gen (dup)
			assert dup ==0
			drop dup
		
		drop wave
		gen round_i=5
		gen wave_i=2
		destring c2_helpoutsum, replace

		sort appid
		save "`temp_ei25'", replace
		
	// ENDLINE HOUSEHOLD
		
		// 11 month HH survey
		
			use "$ILEdata/raw/ILE.hh_clean.dta", clear
			
			keep if wave=="11m"
			
			* Check Duplicates
				duplicates tag appid, gen (dup)
				assert dup ==0
				drop dup
			
			drop wave
			gen round_h=1
			gen wave_h=1
			
			sort appid
			save "`temp_eh11'", replace
			
			use "$ILEdata/raw/ILE.hh_clean.dta", clear
		
		// 12 month HH survey
		
			keep if wave=="12m"
			
			* Check Duplicates
				duplicates tag appid, gen (dup)
				assert dup ==0
				drop dup
			
			drop wave
			gen round_h=2
			gen wave_h=1
			
			sort appid
			save "`temp_eh12'", replace
			
			use "$ILEdata/raw/ILE.hh_clean.dta", clear
		
		// 23 month HH survey
		
			keep if wave=="23m"
		
			* Check Duplicates
				duplicates tag appid, gen (dup)
				assert dup ==0
				drop dup
			
			drop wave
			gen round_h=4
			gen wave_h=2
			
			sort appid
			save "`temp_eh23'", replace

	// COMBINING ENDLINE DATABASES
		
		// Merging individual and HH surveys (11m, 12m and 23m)

		foreach x in 11 12 23 {
			use "`temp_ei`x''", clear
			merge appid using "`temp_eh`x''", _merge(_merge_e`x')
			tostring translator, replace
			save "`temp_e`x''", replace
		}
		clear
				
	// Appending all endline databases
		
		foreach x in e12 ei13 ei25 {
			use "`temp_`x''", clear
			tostring c2_helpoutsum, replace
			save "`temp_`x''", replace
			}
		
		use "`temp_e11'", clear
		append using "`temp_e12'" "`temp_ei13'" "`temp_e23'" "`temp_ei25'"
		so appid
		destring c2_helpoutsum, replace
		save "$ILEdata/ILE.el_clean.dta", replace


// II.  INDIVIDUAL SURVEY VARIABLES
*************************************

// unique surveyid
		
		egen surveyid_end=concat(appid round_i round_h), format(%12.0g)
		
		duplicates tag surveyid_end, gen (dup)
				assert dup ==0
				drop dup
		
		destring surveyid_end, replace

// 1. SKILLS AND EDUCATION

	// Distinguish 0 from missing if indicator says none, prevent gen command from assuming 0 is dropped
	
		replace techtraining2 = 0 if techtraining1 == 0
		replace university2 = 0 if university1 == 0
		
		foreach x in techlength1 techlengthunit1 techdaysweek1 techhoursday1 technow1 {
		replace `x' = 0 if techtraining1 == 0
		}
		
		foreach x in techlength2 techlengthunit2 techdaysweek2 techhoursday2 technow2 {
		replace `x' = 0 if techtraining2 == 0
		replace `x' = 0 if techtraining1 == 0
		}
		
		foreach x in unilength1 unilengthunit1 unidaysweek1 unihoursday1 uninow1 {
		replace `x' = 0 if university1 == 0
		}

		foreach x in unilength2 unilengthunit2 unidaysweek2 unihoursday2 uninow2 {
		replace `x' = 0 if university2 == 0
		replace `x' = 0 if university1 == 0
		}
		
		foreach x in trainlength trainlengthunit traindaysweek trainhoursday trainnow {
		replace `x' = 0 if othertraining == 0
		}

	// GENERATE: DAYS/WEEKS/MONTHS/YEARS OF TRAINING FOR TECH AND UNIVERSITY TRAINING 1 & 2
	
		foreach y in tech uni {
		foreach x in 1 2 {
		gen `y'`x'_days = .						// prevent generate command from coverting 0 to missing
		replace `y'`x'_days=`y'length`x' if `y'lengthunit`x'==0
		replace `y'`x'_days=`y'length`x' if `y'lengthunit`x'==1
		replace `y'`x'_days=`y'length`x' *7 if `y'lengthunit`x'==2
		replace `y'`x'_days=`y'length`x' *30 if `y'lengthunit`x'==3
		replace `y'`x'_days=`y'length`x' *365 if `y'lengthunit`x'==4
		lab var `y'`x'_days "Total days training since bl: `y' `x'"
		
		gen `y'`x'_mo=.
		replace `y'`x'_mo= `y'length`x' if `y'lengthunit`x'==3
		replace `y'`x'_mo= `y'length`x' *12 if `y'lengthunit`x'==4
		replace `y'`x'_mo= `y'length`x' *.24 if `y'lengthunit`x'==2
		replace `y'`x'_mo= `y'length`x'/30 if `y'lengthunit`x'==1
		replace `y'`x'_mo= `y'length`x'/30 if `y'lengthunit`x'==0
		lab var `y'`x'_mo "Total months training since bl: `y' `x'"
		
		gen `y'`x'_yr=`y'`x'_mo/12
		replace `y'`x'_yr=0 if `y'`x'_mo == 0 
		lab var `y'`x'_yr "Total yrs of training since bl: `y' `x'"
		
		gen `y'`x'_wks=.
		replace `y'`x'_wks=`y'length1 if `y'lengthunit`x'==2
		replace `y'`x'_wks=`y'length1 if `y'lengthunit`x'==0
		replace `y'`x'_wks=`y'length1 /7 if `y'lengthunit`x'==1
		replace `y'`x'_wks=`y'length1 *4 if `y'lengthunit`x'==3
		replace `y'`x'_wks=`y'length1 *52 if `y'lengthunit`x'==4
		lab var `y'`x'_wks "Total wks training since bl: `y' `x'"
		}
		}
		/* Generate dummies for courselengths */
		foreach x in 1 2 {
			gen tech`x'_3m = cond(techtraining`x'==1 & tech`x'_wks>=12,1,0)
			gen uni`x'_3m = cond(university`x'==1 & uni`x'_wks>=12,1,0)
			gen tech`x'_1y = cond(techtraining`x'==1 & tech`x'_wks>=52,1,0)
			gen uni`x'_1y = cond(university`x'==1 & uni`x'_wks>=52,1,0)
			la var tech`x'_3m "Did a >3 month technical training course in last year (`x')"
			la var uni`x'_3m "Did a >3 month university program in last year (`x')"
			la var tech`x'_1y "Did a >year technical training course in last year (`x')"
			la var uni`x'_1y "Did a >year university program in last year (`x')"
		}
		

	// GENERATE: DAYS/WEEKS/MONTHS/YEARS OF TRAINING FOR ANY OTHER TRAINING
	
		gen train_days=.
		replace train_days=trainlength if trainlengthunit==1
		replace train_days=0 if trainlengthunit==0
		lab var train_days "Total days of training since baseline: other training"
		
		replace train_days=techlength1 *7 if trainlengthunit==2
		replace train_days=techlength1 *30 if trainlengthunit==3
		replace train_days=techlength1 *365 if trainlengthunit==4

		gen train_mo=.
		replace train_mo= trainlength if trainlengthunit==3
		replace train_mo= 0 if trainlengthunit==0
		lab var train_mo "Total months of training since baseline: other training"
		
		replace train_mo= trainlength *12 if trainlengthunit==4
		replace train_mo= trainlength *.24 if trainlengthunit==2
		replace train_mo= trainlength/30 if trainlengthunit==1

		gen train_yr=train_mo/12
		replace train_yr = 0 if train_mo == 0
		replace train_yr = 0 if train_yr == 4| train_yr == 3 | train_yr == 2		// Assumption
		lab var train_yr "Total years of training since baseline: other training"
		
		gen train_wks=.
		replace train_wks=trainlength if trainlengthunit==2
		replace train_wks=trainlength /7 if trainlengthunit==1
		replace train_wks=trainlength *4 if trainlengthunit==3
		replace train_wks=trainlength *52 if trainlengthunit==4
		replace train_wks=0 if trainlengthunit==0
		lab var train_wks "Total weeks of training since baseline: other training"

	/* Generate dummies for courselengths */
			gen tech_3m = cond((techtraining1==1 & tech1_wks>=12)|(techtraining2==1 & tech2_wks>=12)|(othertraining==1 & train_wks>=12),1,0)
			gen uni_3m = cond((university1==1 & uni1_wks>=12)|(university2==1 & uni2_wks>=12),1,0)
			gen tech_1y = cond((techtraining1==1 & tech1_wks>=52)|(techtraining2==1 & tech2_wks>=52)|(othertraining==1 & train_wks>=52),1,0)
			gen uni_1y = cond((university1==1 & uni1_wks>=52)|(university2==1 & uni2_wks>=52),1,0)
			la var tech_3m "Did a >3 month technical training course in last year"
			la var uni_3m "Did a >3 month university program in last year"
			la var tech_1y "Did a >year technical training course in last year"
			la var uni_1y "Did a >year university program in last year"
			
	/* Generate dummy for currently in any sort of training or school */
		gen schooltrainnow =  (tech_3m == 1 | uni_3m == 1 | currentschool == 1)
			la var schooltrainnow "Currently in school or enrolled in >3m uni or training program in past year"

	// GENERATE: TOTAL DAYS OF TRAINING & DUMMY FOR ANY TRAINING

			egen daystraining=rowtotal(tech1_days tech2_days uni1_days uni2_days train_days), m
			lab var daystraining "Total training/educ  since baseline mentioned in days"
			
			gen byte daytraining=cond(daystraining,1,0,.) 
			lab var daytraining "Indicator: training/educ since bl (days)"

	// GENERATE: DUMMIES FOR TRAINING: (1) ANY TECHNICAL (2) ANY UNIVERSITY AND (3) ANY OTHER 

			gen tech_any= 1 if tech1_yr > 0 & tech1_yr !=. 
			replace tech_any = 1 if tech2_yr > 0 & tech2_yr !=.
			replace tech_any = 0 if tech1_yr == 0 | tech2_yr == 0
			lab var tech_any "Indicator for receiving any technical/vocational training since baseline"
			
			gen uni_any=1 if uni1_yr>0 & uni1_yr !=.
			replace uni_any=1 if uni2_yr>0 & uni2_yr !=.
			replace uni_any=0 if uni1_yr == 0 & uni2_yr == 0
			lab var uni_any "Indicator for receiving any university/college education since baseline"
			
			gen train_any = 1 if train_yr >0 & train_yr !=.
			replace train_any = 0 if train_yr == 0
			lab var train_any "Indicator for receiving any 'other' training since baseline"

	// GENERATE: TOTAL YEARS OF EDUCATION/TRAINING (ASSUMPTION: 12 MONTHS= 1 YEAR)
	
				replace tech1_yr = 0 if techtraining1 == 0
				replace tech2_yr = 0 if techtraining2 == 0 
				replace uni1_yr = 0 if university1 == 0 
				replace uni2_yr = 0 if university2 == 0 
				replace train_yr =0 if othertraining == 0
				
			egen educ=rowtotal(tech1_yr tech2_yr uni1_yr uni2_yr train_yr), m
			lab var educ "Total years of training since baseline"

			
	// GENERATE: HOURS OF TRAINING (ACCOUNTS FOR TRAINING INTENSITY)
				gen tech1hours= tech1_wks*techdaysweek1*techhoursday1
					replace tech1hours = 0 if tech1_wks == 0 | techdaysweek1 == 0 | techhoursday1 == 0
				gen tech2hours= tech2_wks*techdaysweek2*techhoursday2
					replace tech1hours = 0 if tech2_wks == 0 | techdaysweek2 == 0 | techhoursday2 == 0
				gen uni1hours= uni1_wks*unidaysweek1*unihoursday1
					replace tech1hours = 0 if uni1_wks == 0 | unidaysweek1 == 0 | unihoursday1 == 0				
				gen uni2hours= uni2_wks*unidaysweek2*unihoursday2
					replace tech1hours = 0 if uni2_wks == 0 | unidaysweek2 == 0 | unihoursday2 == 0
				gen trainhours= train_wks*traindaysweek*trainhoursday
					replace tech1hours = 0 if train_wks == 0 | traindaysweek == 0 | trainhoursday == 0
		// By category 
				egen unihours = rowtotal(uni1hours uni1hours), m
				egen techhours = rowtotal(tech2hours tech2hours), m
				egen hourstraining= rowtotal (tech1hours tech2hours uni1hours uni2hours trainhours), m
				lab var hourstraining "Total hours training received since bl"
				*drop tech1hours tech2hours uni1hours uni2hours trainhours

	// RECODE & RELABEL "YES/NO" FOR SKILLS/EDUC VARIABLES
			recode technow1 technow2 uninow1 uninow2 trainnow (2=0)
			foreach x of varlist daytraining tech_any uni_any tech_any ///
				technow1 technow2 uninow1 uninow2 trainnow {
				lab val `x' yesno
				}
			
// 2. HOUSEHOLD AND COMMUNITY

	// RECODE "OFTEN" SCALE VARIABLES: (A NEW VAR IS GENERATED WITH PREFIX "r_")
			recode famcaring famadvice famhelp famquarrel ///    
			famvalued friendcaring friendadvice ///  
			friendhelp friendquarrel commvalued ///    
			(4=0 "Never")  (3=1 "Rarely")  (2=2 "Sometimes")  (1=3 "Often"), pre(r_) lab (often_recode)

	// RECODE "AGREE" SCALE VARIABLES: (A NEW VAR IS GENERATED WITH PREFIX "r_")
			recode honest trusted trustofficials watchhome ///
			(4=0 "Strongly disagree") (3=1 "Somewhat disagree") ///
			(2=2 "Somewhat agree") (1=3 "Strongly agree"), pre(r_) lab (agree_recode)

	// NUMBER OF DEPENDENTS, DEPENDENTS RATIO AND HOUSEHOLD SIZE
			egen dependents=rowtotal(dep15 depold)
			lab var dependents "Total household dependents (aged, disabled, ill, or under 15 years)"
			gen dep_worker=dependents/ablework   
			lab var dep_worker "Household ratio: dependents to able-bodied workers"

	// BINARY VARIABLES FOR CIVIL STATUS (SINGLE, MARRIED, PARTNER)
			ren married civil
			gen byte single=cond(civil==1,1,0)
			lab var single "Civil status: single"
			gen byte married=cond(civil==2,1,0)
			lab var married "Civil status: married"
			gen byte partner=cond(civil==3,1,0)
			lab var partner "Civil status: lives with unmarried partner"

	// RECODE: "YES/NO" LABELING FOR GROUP VARIABLES
			foreach x in g_equb g_iddir g_mfi g_coop g_workgroup g_commcouncil /// 
				g_cultural g_churchgroup g_commcomm g_political g_youth g_sports g_womens {
				replace `x'=0 if `x'==.
				lab val `x' yesno
			}

	// ADDITIVE INDEX ON QUALITY OF FAMILY RELATIONS *F*
			gen r_revfamquarrel=r_famquarrel
			lab var r_revfamquarrel "How often do you have angry quarrels with people in your family?"
			recode r_revfamquarrel (0=3) (1=2) (2=1) (3=0)
			egen famsupport=rowtotal(r_famcaring r_famadvice r_famhelp r_famvalued r_revfamquarrel)
			lab var famsupport "Family Support: Additive Index 0-15 (15=better relations)"

	// ADDITIVE INDEX ON QUALITY OF COMMUNITY RELATIONS *F*
			gen r_revfriendquarrel=r_friendquarrel
			lab var r_revfriendquarrel "How often do you have angry quarrels with your friends and neighbors?"
			recode r_revfriendquarrel (0=3) (1=2) (2=1) (3=0)
			egen commsupport=rowtotal(r_friendcaring r_friendadvice ///  
			r_friendhelp r_revfriendquarrel r_commvalued)   
			lab var commsupport "Community Support: Additive Index 0-15 (15=better relations)"

	// ADDITIVE TRUST INDEX *F*
			egen trust=rowtotal (r_honest r_trusted r_trustofficials r_watchhome)
			lab var trust "Trust: Additive Index"

	// TOTAL NUMBER OF GROUPS RESPONDENT BELONGS TO
			foreach var of varlist othgroup* {
				replace `var'= "" if `var' =="."
			}
			
			gen othgroup1temp=cond(missing(othgroup1),"", cond(othgroup1 !="","1","0")) 
			gen othgroup2temp=cond(missing(othgroup2),"", cond(othgroup2 !="","1","0")) 
			gen othgroup3temp=cond(missing(othgroup3),"", cond(othgroup3 !="","1","0")) 
	
			foreach var of varlist othgroup* {
			destring `var', replace
			}	
			
			egen groups=rowtotal(g_equb g_iddir g_mfi g_coop g_workgroup g_commcouncil ///
				g_cultural g_churchgroup g_commcomm g_political g_youth ///       
				g_sports g_womens othgroup1temp othgroup2temp othgroup3temp), m
			drop othgroup1temp othgroup2temp othgroup3temp
			lab var groups "Number of community groups belong to"

	// LEADERSHIP POSITION- LEADS ANY GROUP OR KEBELE
			gen lead_any=cond(kebelelead==1|grouplead==1, 1, 0)
			lab var lead_any "Holds leadership position in any group or Kebele"

	// ADDITIVE INDEX ON DEGREE OF COMMUNITY PARTICIPATION (SAME BL MEASURE) *F*
			egen comminvolved=rowtotal(kebelelead grouplead giveadvice speakup commpart vote vote2010 churchreg)
			lab var comminvolved "Degree of community participation: (BL) Additive Index 0-8 (8=more involved)"
			
	// ADDITIVE INDEX ON DEGREE OF COMMUNITY PARTICIPATION (FULL EL MEASURE) *F*
			egen comminvolved2=rowtotal(kebelelead grouplead giveadvice speakup commpart vote ///
			vote2010 churchreg familyleaders politicalparty enjoynews)
			lab var comminvolved2 "EL ONLY: Degree of comm participation: Additive Index 0-11 (11=more involved)"
			
	// ADDITIVE INDEX ON KNOWLEDGE OF POLITICAL FIGURES *F*
			egen knowheads=rowtotal(namepm namepres namestatehead)
			lab var knowheads "Number of correct answers to names of political heads (0-3)"
			
	// RELABEL YES/NO HH & COMMUNITY VARIABLES
			foreach x of varlist single married partner headlive lead_any { 
			lab val `x' yesno
			}


// 3. CHILDREN ROSTER

	// OWNKIDSHH: NUMBER OF CHILDREN LIVING WITH RESPONDENT
			foreach var of varlist *_livewith {
			gen `var'_temp=cond(`var'==1,1,0)
			}
			egen ownkidshh=rowtotal(*_livewith_temp)
			drop *_livewith_temp
			lab var ownkidshh "number of children born to individual, living with individual"
			
	// ENROLLRATE: NUMBER OF CHILDREN BETWEEN 5-16 CURRENTLY ENROLLED IN SCHOOL
			egen schoolagekids= anycount (*_ageyrs), values (16 15 14 13 12 11 10 9 8 7 6)	
			egen kidsinschool= rowtotal (*_schoolnow), m
			gen enrollrate1= kidsinschool / schoolagekids
			lab var enrollrate1 "kids in school divided by number of kids (5-16): children roster"
			
	// AVEHEALTHNOW: AVERAGE CURRENT HEALTH STATUS OF CHILDREN (BORN TO INDIVIDUAL)
			egen avehealthnow=rowmean(*_healthnow)
			lab var avehealthnow "average current health status of children (born to ind)"

	// AVEHEALTHLASTYR: AVERAGE HEALTH STATUS OF CHILDREN ONE YEAR AGO (BORN TO INDIVIDUAL)
			egen avehealthlastyr=rowmean(*_healthlastyear)
			lab var avehealthlastyr "average health status of children (born to ind) 1 year ago"
			
	// AVEHEALTHDIFF: AVERAGE HEALTH STATUS OF CHILDREN ONE YEAR AGO (BORN TO INDIVIDUAL)
			gen kidshealthdiff= avehealthnow - avehealthlastyr
			lab var kidshealthdiff "difference between averages: kids health now vs. 1 year ago"
			
// 4.  FIRMS & LABOR ATTITUDES

	// ATTITUDES TOWARDS LABOR UNIONS (HIGHER VALUE: PREFERENCE FOR LABOR UNIONS) *F*
			// NEGATIVE QUESTIONS
				recode unions1 unions3 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode unions2 unions4 unions5 unions6 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)
			
			egen unions_att = rowtotal(rank_unions*), m
			lab var unions_att "Attitudes towards unions additive index (0-24 Prefer Unions)"

	// ATTITUDES TOWARDS LARGE FIRMS/FARMS (HIGHER VALUE: PREFERENCE FOR LARGE FIRMS/FARMS) *F*
			// NEGATIVE QUESTIONS
				recode firms1 firms4 firms6 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode firms2 firms3 firms5 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)
			
			egen firms_att = rowtotal(rank_firms*), m
			lab var firms_att "Attitudes towards large firms additive index (0-24 Prefer Large Firms)"
			
	// PERCEPTION TOWARDS WORKER RIGHTS (HIGHER VALUE: WORKERS TREATED WELL IN ETHIOPIA) *F*
			// POSITIVE QUESTIONS
				recode workerrights* (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)
			
			egen workrights_per = rowtotal(rank_workerrights*), m
			lab var workrights_per "Perception on state of worker rights in Ethiopia (0-24 Positive View)"
			
	// ATTITUDES TOWARDS FOREIGN FIRMS/PRESENCE (HIGHER VALUE: PREFERENCE FOR FOREIGN FIRMS) *F*
			// NEGATIVE QUESTIONS
				recode foreignfirms1 foreignfirms3 foreignfirms4 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode foreignfirms2 foreignfirms5 foreignfirms6 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)
			
			egen foreign_att = rowtotal(rank_foreignfirms*), m
			lab var foreign_att "Attitudes towards large firms additive index (0-24 Preference for Foreign)"
		

// 5. CASH AND SAVINGS
	
	// RECODE: PERCEIVED HOUSEHOLD STATUS VARIABLE (CONVERT TO ASCENDING ORDER OF SCALE) 
			recode hhstatus (7=0 "Destitute") (6=1 "Poor") (5=2 "Never Have Enough") (4=3 "Can Manage to Get By") ///
			(3=4 "Comfortable") (2=5 "Rich") (1=6 "Very Rich"), pre (r_) lab(status2)
			lab var r_hhstatus "Perceived HH Status; 0=Destitute-6=Very Rich"

	// STATUS YEAR AGO VS. STATUS TODAY
			gen status=laddnow
			lab var status "Subjective: Status today"

	// STATUS YEAR AGO VS. STATUS TODAY
			gen stat_change1= laddnow-laddyearago
			lab var stat_change1 "Subjective: Status today minus status last year (10 point ladder)"

	// STATUS NEXT YEAR VS. STATUS TODAY (OPTIMISM)
			gen stat_change2= laddnxtyear-laddnow
			lab var stat_change2 "Subjective: Status next year minus status today (10 point ladder)" 

	// STATUS IN 5 YEARS VS. STATUS TODAY (OPTIMISM)
			gen stat_change3= ladd5years-laddnow
			lab var stat_change3 "Subjective: Status in five years minus status today (10 point ladder)"

	// REPLACE: BLANKS WITH 0'S FOR VARIABLES ON WHO OWE MONEY TO
		foreach var of varlist owebank-oweiddir {
			replace `var'=0 if `var'==.
		}
	
	// TOTAL DEBT
			replace debttotal = 0 if owe100birr == 0
			
// 6. GENERAL EMPLOYMENT / INCOME GENERATING ACTIVITIES //

	/* OUTLINE
	
	a. Days worked (total)
	b. Hours worked (each IGA and total)
		* past 12 months
		* past 4 weeks
		* past 7 days
		* past 7 days before last 7 days
	c. Hours worked: by work for self or other; 4 weeks, 12 months
	d. Hours worked: by regularity of payment; 4 weeks, 12 months
	e. Hours worked: by certainty of employment; 4 weeks, 12 months
	f. Hours worked: by size of IGA organization; 4 weeks, 12 months
	g. Cash and Profit
		* Cash earned: 7 days and 7 days before last 7 days
		* Profit earned: 7 days and 7 days before last 7 days
		* Cash per hour: 7 days and 7 days before last 7 days
		* Cash per day: By activity and total
	h. Factory work 
	i. Any income-generating activities

	ASSUMPTIONS: we assume that hours (the smallest unit of time measurement) do not overlap across
	activities so that we can aggregate them into indicators/categories and not double count hours. 		
	
	*/ 
	
	global igacateg psnp farm share animal farmwage food shop trade voc tailor crafts fac casual ///
	mining driver sec soldier dom clerical famwork wait teach othwork1 othwork2 othwork3

	// Correct categories
	// Create program that switches categories
	cap prog drop switchcat
	program switchcat
		syntax namelist(min=2 max=2) [if]
		tempvar temp1 temp2
		foreach cat in 12months workfor payment length ///
			size daysmonth hoursday 4weeks 7days 7hours ///
			cash7d prof7d wage incperiod increport 14days ///
			14hours 14cash 14prof {
				qui gen `temp1' = `1'`cat' `if'
				qui gen `temp2' = `2'`cat' `if'
				qui replace `1'`cat' = `temp2' `if'
				qui replace `2'`cat' = `temp1' `if'
				drop `temp1' `temp2'
		}
	end
	switchcat share farmwage if appid == 10341 & round_i == 1
	switchcat othwork1 farmwage if (appid == 10403 | appid == 10638 | appid == 10414)& round_i == 1
	switchcat tailor fac if (appid == 10479 | appid == 10560) & round_i == 1
	switchcat voc fac if (appid == 10598 | appid == 10591) & round_i == 1
	switchcat casual fac if (appid == 11713 | appid == 11737 | appid == 10713) & round_i == 1

	// Correct firm sizes
	replace facsize = 5 if (appid == 10683 | appid == 10713) & round_i == 1
	
	// Correct duration
	replace faclength = 2 if appid == 10713 & round_i == 1
	replace farmwage = 2 if appid == 11328 & round_i == 1
	
	// Correct workfor
	replace farmwageworkfor = 2 if (appid == 10203 | appid == 10204 | ///
		appid == 10206 | appid == 10219 | appid == 10220 | appid == 10224 | appid == 10238 | 	///
		appid == 10240 | appid == 10243 | appid == 10246 | appid == 10252 | appid == 10253 |  ///
		appid == 10258 | appid == 10261 | appid == 10263 | appid == 10264 | appid == 10268 |  ///
		appid == 10273 | appid == 10275 | appid == 10276 | appid == 10341 | appid == 10620 | ///
		appid == 10323) & round_i == 1
	replace facworkfor = 2 if (appid == 10432 | appid == 10560 | appid == 11607 | appid == 10713) & round_i == 1
	// Make sure missing is not being imputed as zero and vice versa

		foreach var in $igacateg {
		
		replace `var'daysmonth = 0 if `var'12months == 0
		replace `var'hoursday = 0 if `var'12months == 0				
		
		replace `var'payment = 0 if `var'12months == 0
		replace `var'length = 0 if `var'12months == 0
		replace `var'wage = 0 if `var'12months == 0
		replace `var'increport = 0 if `var'12months == 0

		replace `var'4weeks = 0 if `var'12months == 0
		replace `var'7days = 0 if `var'12months == 0
		replace `var'7hours = 0 if `var'12months == 0
		replace `var'cash7d = 0 if `var'12months == 0
		replace `var'prof7d = 0 if `var'12months == 0

		replace `var'14days = 0 if `var'12months == 0
		replace `var'14hours = 0 if `var'12months == 0
		replace `var'14cash = 0 if `var'12months == 0
		replace `var'14prof = 0 if `var'12months == 0
		}
	
	// Generate indicator for work in the past 12 months 
	
		foreach x in $igacateg {
		gen `x'12monthind = 1 if `x'12months < 13 & `x'12months > 0
		replace `x'12monthind = 0 if `x'12months == 0
		lab var `x'12monthind "Indicator for any `x' work in the past 12 months"
		}
					
	// RECODE DUMMIES FOR WORK IN THE PAST 12 MONTHS AND 4 WEEKS 
	
		// Recode farm, animal and share variables based on 1) work for other, 2) size > 10 employees, 3) longer, uncertain or certain 
			
		// Create indicator for longer time or size greater than 10 employees
		
		foreach x in $igacateg {
		gen `x'size_temp = cond((`x'size > 1 & `x'size < 6),1,0) 
		replace `x'size_temp =. if `x'size==.
		gen `x'length_temp = cond((`x'length ==2 |`x'length == 4),1,0)
		replace `x'length_temp =. if `x'length ==.
		}

		list appid surveyid if farm12monthind == 1 & farmworkfor == 2 & farmsize_temp ==1 & farmlength_temp == 1 
		list appid surveyid if animal12monthind == 1 & animalworkfor == 2 & animalsize_temp ==1 & animallength_temp ==1 
		list appid surveyid if share12monthind == 1 & shareworkfor == 2 & sharesize_temp ==1 & sharelength_temp ==1 
		list appid surveyid if farmwage12monthind == 1 & (farmwagesize_temp ==0 & farmwagelength_temp == 0) 
		
	// Check
		list appid surveyid if farmwage12monthind == 1 & (farmwagesize_temp ==0 & farmwagelength_temp == 0) 
		list appid surveyid if farmwage12monthind == 1 & farmwagesize_temp ==0 
		list appid surveyid if farmwage12monthind == 1 & (farmwagelength_temp == 0) 
		list appid surveyid if farm12monthind == 1 & farmworkfor == 2 & farmsize_temp ==1 & farmlength_temp == 1 
		
		list appid survey farm12months farmlength farmsize if farm12months == 1 & farmlength_temp == 1
		list appid survey animal12months animallength animalsize if animal12months == 1 & animallength_temp == 1
		list appid survey share12months sharelength sharesize if share12months == 1 & sharelength_temp == 1
		
		
	// DAYS WORKED 
	
		// TOTAL DAYS WORKED (not using *7days because will include Cash and savings section vars. Rename C&S vars later)
		
			egen dayswork_7day=rowtotal(psnp7days farm7days share7days animal7days farmwage7days food7days shop7days trade7days voc7days tailor7days crafts7days fac7days casual7days mining7days driver7days sec7days soldier7days dom7days clerical7days famwork7days wait7days teach7days othwork17days othwork27days othwork37days), m
				lab var dayswork_7day "Total days worked in the past 7 days"
				
			egen dayswork_7day7=rowtotal(psnp14days farm14days share14days animal14days farmwage14days food14days shop14days trade14days voc14days tailor14days crafts14days fac14days casual14days mining14days driver14days sec14days soldier14days dom14days clerical14days famwork14days wait14days teach14days othwork114days othwork214days othwork314days), m
				lab var dayswork_7day7 "Total days worked in the 7 days before the past 7 days"
			
			egen dayswork_2wk=rowtotal(dayswork_7day dayswork_7day7), m
				lab var dayswork_2wk "Total days worked in the past 2 weeks"
				
			egen dayswork_4wk=rowtotal(psnp4weeks farm4weeks share4weeks animal4weeks farmwage4weeks food4weeks shop4weeks trade4weeks voc4weeks tailor4weeks crafts4weeks fac4weeks casual4weeks mining4weeks driver4weeks sec4weeks soldier4weeks dom4weeks clerical4weeks famwork4weeks wait4weeks teach4weeks othwork14weeks othwork24weeks othwork34weeks), m
				lab var dayswork_4wk "Total days worked in the past 4 weeks"

	// 6.a. HOURS WORKED

		// HOURS WORKED PAST 12 MONTHS FOR EACH ACTIVITY
			// using average days worked per month/hours worked per day
			
			foreach x in $igacateg {
				gen `x'hours= `x'12months * `x'daysmonth * `x'hoursday
				label var `x'hours "Hours worked in the past 12 months: `x'"
				replace `x'hours=0 if `x'12months==0
				replace `x'hours=0 if `x'daysmonth==0
				replace `x'hours=0 if `x'hoursday==0
				qui sum `x'hours, d
				replace `x'hours=r(p99) if inrange(`x'hours,r(p99),.)
				
				gen `x'h_m = `x'hours/12
				replace `x'h_m=0 if `x'12months==0
				qui sum `x'h_m, d
				replace `x'h_m=r(p99) if inrange(`x'h_m,r(p99),.)
				label var `x'h_m "Total hours per month in past 12 months: `x'"
			}
		
				
		// TOTAL HOURS WORKED PAST 12 MONTHS
				
				egen hourswork=rowtotal(farmhours sharehours animalhours ///
				farmwagehours foodhours shophours tradehours vochours ///
				tailorhours craftshours fachours casualhours mininghours ///
				driverhours sechours soldierhours domhours clericalhours ///
				famworkhours waithours teachhours othwork1hours othwork2hours ///
				othwork3hours), m 
				qui sum hourswork, d
				qui replace hourswork = r(p99) if inrange(hourswork,r(p99),.)
				lab var hourswork "Total hours worked in the past 12 months"
			
				gen hourswork_yw = hourswork/52
				la var hourswork_yw "Average weekly hours in the past 12 months"
				

		// TOTAL HOURS WORKED IN AVERAGE MONTH IN PAST MONTH						
				egen hourswork_m=rowtotal(farmh_m shareh_m animalh_m ///
				farmwageh_m foodh_m shoph_m tradeh_m voch_m ///
				tailorh_m craftsh_m fach_m casualh_m miningh_m ///
				driverh_m sech_m soldierh_m domh_m clericalh_m ///
				famworkh_m waith_m teachh_m othwork1h_m othwork2h_m ///
				othwork3h_m), m 
				qui sum hourswork_m, d
				qui replace hourswork_m = r(p99) if inrange(hourswork_m,r(p99),.)
				lab var hourswork_m "Total hours worked in the past month, over 12 months"
				
				foreach h in 100 120 140 160 180 200 {
					gen month`h' = 0 if hourswork_m!=. & hourswork_m<`h'
					replace month`h' = 1 if hourswork_m >= `h'
					la var month`h' "Worked > `h' hours per month for year" 
				}
				
		
		// BY OCCUPATIONAL CATEGORY 
		
			egen aghoursoth = rowtotal(animalhours sharehours farmhours), m
				lab var aghoursoth "Hours worked in the past year: Agriculture other"
				
			gen aghourscom = farmwagehours
				lab var aghourscom "Hours worked in the past year: Commercial farm"
				
			egen cashours = rowtotal(casualhours psnphours), m
				lab var cashours "Hours worked in the past year: Casual work"
								
			gen facthours = fachours
				lab var facthours "Hours worked in the past year: Factory labor"
							
			egen pettybusnhours = rowtotal(famworkhours shophours foodhours tradehours), m
				lab var pettybusnhours "Hours worked in the past year: Petty business"
								
			egen skilledhours = rowtotal(craftshours tailorhours  vochours), m
				lab var skilledhours "Hours worked in the past year: Skilled trade"
								
			egen wagelowhours = rowtotal(mininghours waithours domhours sechours), m
				lab var wagelowhours "Hours worked in the past year: Wage labor - Low skill"
								
			egen wagemedhours = rowtotal(clericalhours soldierhours driverhours teachhours), m
				lab var wagemedhours "Hours worked in the past year: Wage labor - medium skill"

			egen othhours = rowtotal (othwork1hours othwork2hours othwork3hours), m
				lab var othhours "Hours worked in the past year: Other"			

					
		// HOURS worked in the past 4 WEEKS for each activity
			// using days worked in 4 weeks and  average hours worked per day
			
			foreach x in $igacateg {
				gen `x'hours_4w= `x'4weeks * `x'hoursday
				label var `x'hours_4w "Hours worked in the past 4 weeks: `x'"
				replace `x'hours_4w=0 if `x'4weeks == 0
				replace `x'hours_4w=0 if `x'hoursday == 0 
			}
				
		// TOTAL HOURS worked in the past 4 WEEKS 
			
				egen hourswork_4wk=rowtotal(*_4w), m
				lab var hourswork_4wk "Total hours worked in the past 4 weeks"

		// HOURS worked in the past 7 DAYS for each activity, average hours per day
			
			foreach x in $igacateg {
				gen `x'hours_7d= `x'7days * `x'7hours
				lab var `x'hours_7d "Hours worked in the past 7 days: `x'"
				replace `x'hours_7d=0 if `x'7days== 0
				replace `x'hours_7d=0 if `x'7hours== 0
			}
			
		// TOTAL HOURS worked in the past 7 DAYS 
		
				egen hourswork_7d=rowtotal(*_7d), m
				lab var hourswork_7d "Total hours worked in the past 7 days"	
	
		// HOURS worked in the past 7 DAYS BEFORE THE LAST 7 DAYS for each activity, average hours per day
					
					foreach x in $igacateg {
						gen `x'hours_7d7= `x'14days * `x'14hours
						lab var `x'hours_7d7 "Hours worked in the past 7 days before the last 7 days: `x'"
						*replace `x'hours_7d7=0 if `x'hours_7d7==.
					}
				
		// TOTAL HOURS worked in the past 7 DAYS BEFORE THE LAST 7 DAYS, average hours per day

				egen hourswork_7d7=rowtotal(*_7d7), m
				lab var hourswork_7d7 "Total hours worked in the past 7 days before the last 7 days"

		// AVG HOURS worked in the past 7 DAYS BY EACH ACTIVITY
			// use days worked in past 4 weeks and avg hours worked per day divided by 4 
					
				foreach x in $igacateg {
				gen `x'hours_1w = (`x'hours_4w / 4)
				lab var `x'hours_1w "Average weekly hours of work: `x'"
				}
							
		// AVG HOURS worked in the past week by category
		
		gl categories aghours_1w casualhours_1w facthours_1w pettybusnhours_1w skilledhours_1w wagelowhours_1w wagemedhours_1w othhours_1w
			
			egen aghoursoth_1w = rowtotal(animalhours_1w sharehours_1w farmhours_1w), m
				lab var aghoursoth_1w "Hours worked in the past week: Agriculture other"
				
			gen aghourscom_1w = farmwagehours_1w
				lab var aghourscom_1w "Hours worked in the past week: Commercial farm"
				
			egen cashours_1w = rowtotal(casualhours_1w psnphours_1w), m
				lab var cashours_1w "Hours worked in the past week: Casual work"
								
			gen facthours_1w = fachours_1w
				lab var facthours_1w "Hours worked in the past week: Factory labor"
							
			egen pettybusnhours_1w = rowtotal(famworkhours_1w shophours_1w foodhours_1w tradehours_1w), m
				lab var pettybusnhours_1w "Hours worked in the past week: Petty business"
								
			egen skilledhours_1w = rowtotal(craftshours_1w tailorhours_1w  vochours_1w), m
				lab var skilledhours_1w "Hours worked in the past week: Skilled trade"
								
			egen wagelowhours_1w = rowtotal(mininghours_1w waithours_1w domhours_1w sechours_1w), m
				lab var wagelowhours_1w "Hours worked in the past week: Wage labor - Low skill"
								
			egen wagemedhours_1w = rowtotal(clericalhours_1w soldierhours_1w driverhours_1w teachhours_1w), m
				lab var wagemedhours_1w "Hours worked in the past week: Wage labor - medium skill"

			egen othhours_1w = rowtotal (othwork1hours_1w othwork2hours_1w othwork3hours_1w), m
				lab var othhours_1w "Hours worked in the past week: Other"
		
		// TOTAL HOURS of work in the past 7 days (by category)
					
					egen hourswork_1w = rowtotal(aghoursoth_1w aghourscom_1w cashours_1w facthours_1w pettybusnhours_1w skilledhours_1w wagelowhours_1w wagemedhours_1w othhours_1w), m
					lab var hourswork_1w "Average weekly hours of work (over past month)"		
			
		// DUMMY FOR ANY WORK IN EACH CATEGORY
			foreach cat in hourswork facthours aghourscom aghoursoth pettybusnhours skilledhours cashours wagelowhours wagemedhours othhours {
				gen `cat'_dum = (`cat'_1w > 0 & `cat'_1w != .)
				la var `cat'_dum "Dummy: `:var lab `cat'_1w'"
			}
			gen formalwork_dum = (facthours_dum | aghourscom_dum | wagelowhours_dum | wagemedhours_dum)
				la var formalwork_dum "Positive workhours in factories, commercial farms, low wage work, or medium wage work"
				
			/* Unemployment */
			gen nowork_dum = hourswork_dum == 0 if !missing(hourswork_1w) 
				la var nowork_dum "Dummy: Reports no work hours in past 4 weeks" 
			egen iga_num = rowtotal (facthours_dum aghourscom_dum aghoursoth_dum pettybusnhours_dum skilledhours_dum cashours_dum wagelowhours_dum wagemedhours_dum othhours_dum), m
				la var iga_num "Number of categories in which respondent reports positive hours"
			foreach cat in hourswork facthours aghourscom aghoursoth pettybusnhours skilledhours cashours wagelowhours wagemedhours othhours {
				gen `cat'_4h_dum = (`cat'_1w > 4 & `cat'_1w != .)
				la var `cat'_4h_dum "Over 4 hours: `:var lab `cat'_1w'"
			}
			/* Less than 4 hours of work */
			gen nowork_4h_dum = hourswork_4h_dum == 0
				la var nowork_4h_dum "Dummy: Reports no work for more than 4 hours per week in past 4 weeks" 
			/* Generate variables that lists the main income generating activitiy in past month*/
			gen main_iga = ""
			gen main_iga_hrs = 0
			foreach cat in facthours aghourscom aghoursoth pettybusnhours skilledhours cashours wagelowhours wagemedhours othhours {
				replace main_iga = "`cat'" if `cat'_1w > main_iga_hrs & !missing(`cat'_1w)
				replace main_iga_hrs = `cat'_1w  if `cat'_1w > main_iga_hrs & !missing(`cat'_1w)
			}
			drop main_iga_hrs
				replace main_iga = "Factory labor" if main_iga == "facthours"
				replace main_iga = "Farm wage labor" if main_iga == "aghourscom"
				replace main_iga = "Smallholder farming" if main_iga == "aghoursoth"
				replace main_iga = "Petty business" if main_iga == "pettybusnhours"
				replace main_iga = "Skilled trades" if main_iga == "skilledhours"
				replace main_iga = "Casual non-farm labor" if main_iga == "cashours"
				replace main_iga = "Low skill salaried labor" if main_iga == "wagelowhours"
				replace main_iga = "Medium skill salaried labor" if main_iga == "wagemedhours"
				replace main_iga = "Other" if main_iga == "othhours"
			la var main_iga "Main income generating activity over past month"

			/* Number of activities >4 hours */
			egen iga_4h_num = rowtotal (facthours_4h_dum aghourscom_4h_dum aghoursoth_4h_dum pettybusnhours_4h_dum skilledhours_4h_dum cashours_4h_dum wagelowhours_4h_dum wagemedhours_4h_dum othhours_4h_dum), m
				la var iga_4h_num "Number of categories in which respondent reports more than 4 hours"
				
		// HOURS WORKED EACH WEEK BY CATEGORY
		
		foreach x in 7d 7d7 {
			
			egen aghoursoth_`x' = rowtotal(animalhours_`x' sharehours_`x' farmhours_`x'), m
				lab var aghoursoth_`x' "Hours worked in the past week: Agriculture other"
				if ("`x'" == "7d7") lab var aghoursoth_`x' "Hours worked in the week before the past week: Agriculture other"
				
			gen aghourscom_`x'  = farmwagehours_`x' 
				lab var aghourscom_`x'  "Hours worked in the past week: Commercial farm"
				if ("`x'" == "7d7") lab var aghourscom_`x'  "Hours worked in the week before the past week: Commercial farm"
				
			egen cashours_`x' = rowtotal(casualhours_`x'  psnphours_`x' ), m
				lab var cashours_`x' "Hours worked in the past week: Casual work"
				if ("`x'" == "7d7") lab var cashours_`x' "Hours worked in the week before the past week: Casual work"
								
			gen facthours_`x'  = fachours_`x' 
				lab var facthours_`x'  "Hours worked in the past week: Factory labor"
				if ("`x'" == "7d7") lab var facthours_`x'  "Hours worked in the week before the past week: Factory labor"
							
			egen pettybusnhours_`x' = rowtotal(famworkhours_`x'  shophours_`x'  foodhours_`x'  tradehours_`x'), m
				lab var pettybusnhours_`x' "Hours worked in the past week: Petty business"
				if ("`x'" == "7d7") lab var pettybusnhours_`x'  "Hours worked in the week before the past week: Petty business"
								
			egen skilledhours_`x' = rowtotal(craftshours_`x' tailorhours_`x'  vochours_`x'), m
				lab var skilledhours_`x' "Hours worked in the past week: Skilled trade"
				if ("`x'" == "7d7") lab var skilledhours_`x' "Hours worked in the week before the past week: Skilled trade"
								
			egen wagelowhours_`x' = rowtotal(mininghours_`x' waithours_`x' domhours_`x' sechours_`x'), m
				lab var wagelowhours_`x' "Hours worked in the past week: Wage labor - Low skill"
				if ("`x'" == "7d7") lab var wagelowhours_`x' "Hours worked in the week before the past week: Wage labor - Low skill"
								
			egen wagemedhours_`x' = rowtotal(clericalhours_`x' soldierhours_`x' driverhours_`x' teachhours_`x'), m
				lab var wagemedhours_`x' "Hours worked in the past week: Wage labor - medium skill"
				if ("`x'" == "7d7") lab var wagemedhours_`x' "Hours worked in the week before the past week: Wage labor - medium skill"

			egen othhours_`x' = rowtotal (othwork1hours_`x' othwork2hours_`x' othwork3hours_`x'), m
				lab var othhours_`x' "Hours worked in the past week: Other"
				if ("`x'" == "7d7") lab var othhours_`x' "Hours worked in the week before the past week: Other"
				
	}

		// TOTAL HOURS worked in the past 2 weeks
		
				gen hourswork_2wk = (hourswork_7d7) + (hourswork_7d)
				lab var hourswork_2wk "Total hours worked in the past two weeks"				

		// AVERAGE HOURS worked in the past week, average hours per week 
		
				egen hourswork_wk = rowmean(hourswork_7d7 hourswork_7d)
				lab var hourswork_wk "Average weekly hours of work (over past 2 weeks)"	
				
			foreach x in aghoursoth aghourscom cashours facthours pettybusnhours skilledhours wagelowhours wagemedhours othhours {
				egen `x'_wk=rowmean(`x'_7d7 `x'_7d)
				lab var `x'_wk "Average weekly work hours (over past 2 weeks) :`=substr("`:var la `x'_7d'",strpos("`:var la `x'_7d'",":")+2,.)'"
			}
	
		// MAIN IGA in past 2 weeks*/
			gen main_iga_2wk = ""
			gen main_iga_hrs_2wk = 0
			foreach cat in facthours aghourscom aghoursoth pettybusnhours skilledhours cashours wagelowhours wagemedhours othhours {
				replace main_iga_2wk = "`cat'" if `cat'_wk > main_iga_hrs & !missing(`cat'_wk)
				replace main_iga_hrs_2wk = `cat'_wk  if `cat'_wk > main_iga_hrs & !missing(`cat'_wk)
			}
			drop main_iga_hrs_2wk
				replace main_iga_2wk = "Factory labor" if main_iga_2wk == "facthours"
				replace main_iga_2wk = "Farm wage labor" if main_iga_2wk == "aghourscom"
				replace main_iga_2wk = "Smallholder farming" if main_iga_2wk == "aghoursoth"
				replace main_iga_2wk = "Petty business" if main_iga_2wk == "pettybusnhours"
				replace main_iga_2wk = "Skilled trades" if main_iga_2wk == "skilledhours"
				replace main_iga_2wk = "Casual non-farm labor" if main_iga_2wk == "cashours"
				replace main_iga_2wk = "Low skill salaried labor" if main_iga_2wk == "wagelowhours"
				replace main_iga_2wk = "Medium skill salaried labor" if main_iga_2wk == "wagemedhours"
				replace main_iga_2wk = "Other" if main_iga_2wk == "othhours"
			la var main_iga_2wk "Main income generating activity over 2 weeks"
				
	// 6.b. BY EMPLOYMENT TYPE (WORK FOR SELF, OTHER OR BOTH)
		
		// BY EMPLOYMENT TYPE-- 4 WEEKS
		
			// TOTAL HOURS worked PAST 4 WEEKS (SELF EMPLOYED), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_self= `x'hours_4w if `x'workfor==1
				}
				egen hourswork4_self=rowtotal(*_4w_self), m
				lab var hourswork4_self "Self-Employed: Total hours worked in past 4 weeks"
				drop *_4w_self 
					
			// TOTAL HOURS worked PAST 4 WEEKS (WORK FOR OTHER), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_other= `x'hours_4w if `x'workfor==2
				}
				egen hourswork4_other=rowtotal(*_4w_other), m
				lab var hourswork4_other "Work for other: Total hours worked in past 4 weeks"
				drop *_4w_other
				
			// TOTAL HOURS worked PAST 4 WEEKS (SELF & OTHER), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_both = `x'hours_4w if `x'workfor==3
				}
				egen hourswork4_both=rowtotal(*_4w_both), m
				lab var hourswork4_both "Work for self & other: Total hours worked in past 4 weeks"
				drop *_4w_both
			
		// BY EMPLOYMENT TYPE-- 12 MONTHS
		
			// TOTAL HOURS worked PAST 12 MONTHS (SELF EMPLOYED), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_self= `x'hours if `x'workfor==1
				}
				egen hourswork_self=rowtotal(*_12m_self), m
				lab var hourswork_self "Self-Employed: Total hours worked in past 12 months"
				
				drop *_12m_self 
					
			// TOTAL HOURS worked PAST 12 MONTHS (WORK FOR OTHER), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_other= `x'hours if `x'workfor==2
				}
				egen hourswork_other=rowtotal(*_12m_other), m
				lab var hourswork_other "Work for other: Total hours worked in past 12 months"
				drop *_12m_other
				
			// TOTAL HOURS worked PAST 12 MONTHS (SELF & OTHER), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_both = `x'hours if `x'workfor==3
				}
				egen hourswork_both=rowtotal(*_12m_both), m
				lab var hourswork_both "Work for self & other: Total hours worked in past 12 months"
				drop *_12m_both			
		
	// 6.c. BY INTERVAL OF PAYMENT (IRREGULAR VS. REGULAR)

		// BY REGULARITY OF PAYMENT-- 4 WEEKS
		
			// TOTAL HOURS worked PAST 4 WEEKS (IRREGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_irreg= `x'hours_4w if `x'payment==1 | `x'payment==2
				}
				egen hourswork4_irreg=rowtotal(*_4w_irreg), m
				lab var hourswork4_irreg "Payment effected irregularly: total hours worked in past 4 weeks"
				drop *_4w_irreg 
					
			// TOTAL HOURS worked PAST 4 WEEKS (REGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_reg= `x'hours_4w if `x'payment==3 | `x'payment==4 | `x'payment==5 
				}
				egen hourswork4_reg=rowtotal(*_4w_reg), m
				lab var hourswork4_reg "Payment effected regularly: total hours worked in past 4 weeks"
				drop *_4w_reg 
			
		// BY REGULARITY OF PAYMENT-- 12 MONTHS
		
			// TOTAL HOURS worked PAST 12 MONTHS (IRREGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_irreg= `x'hours if `x'payment==1 | `x'payment==2
				}
				egen hourswork_irreg=rowtotal(*_12m_irreg), m
				lab var hourswork_irreg "Payment effected irregularly: total hours worked in past 12 months"
				drop *_12m_irreg 
					
			// TOTAL HOURS worked PAST 12 MONTHS (REGULAR PAYMENT), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_reg= `x'hours if `x'payment==3 | `x'payment==4 | `x'payment==5 
				}
				egen hourswork_reg=rowtotal(*_12m_reg), m
				lab var hourswork_reg "Payment effected regularly: total hours worked in past 12 months"
				drop *_12m_reg 

	// 6.d. BY CERTAINTY/LENGTH OF EMPLOYMENT (UNCERTAINTY and LENGTH)
	
		// BY CERTAINTY/LENGTH OF EMPLOYMENT-- 4 WEEKS
		
			// TOTAL HOURS worked PAST 4 WEEKS (Certain & shorter), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_cershort= `x'hours_4w if `x'length==1
				}
				egen hourswork4_cershort=rowtotal(*_4w_cershort), m
				lab var hourswork4_cershort "Certain & short: total hours worked in past 4 weeks"
				drop *_4w_cershort 
					
			// TOTAL HOURS worked PAST 4 WEEKS (Certain & longer), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_cerlong= `x'hours_4w if `x'length==2
				}
				egen hourswork4_cerlong=rowtotal(*_4w_cerlong), m
				lab var hourswork4_cerlong "Certain & longer: total hours worked in past 4 weeks"
				drop *_4w_cerlong
				
			// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & shorter), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_uncshort= `x'hours_4w if `x'length==3
				}
				egen hourswork4_uncshort=rowtotal(*_4w_uncshort), m
				lab var hourswork4_uncshort "Uncertain & shorter: total hours worked in past 4 weeks"
				drop *_4w_uncshort
				
			// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & longer), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_unclong= `x'hours_4w if `x'length==4
				}
				egen hourswork4_unclong=rowtotal(*_4w_unclong), m
				lab var hourswork4_unclong "Uncertain & longer: total hours worked in past 4 weeks"
				drop *_4w_unclong
			
		// BY CERTAINTY/LENGTH OF EMPLOYMENT-- 12 MONTHS
		
			// TOTAL HOURS worked PAST 12 MONTHS (Certain & shorter), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_cershort= `x'hours if `x'length==1
				}
				egen hourswork_cershort=rowtotal(*_12m_cershort), m
				lab var hourswork_cershort "Certain & short: total hours worked in past 12 months"
				drop *_12m_cershort 
					
			// TOTAL HOURS worked PAST 4 WEEKS (Certain & longer), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_cerlong= `x'hours if `x'length==2
				}
				egen hourswork_cerlong=rowtotal(*_12m_cerlong), m
				lab var hourswork_cerlong "Certain & longer: total hours worked in past 4 weeks"	
				drop *_12m_cerlong
				
			// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & shorter), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_uncshort= `x'hours if `x'length==3
				}
				egen hourswork_uncshort=rowtotal(*_12m_uncshort), m
				lab var hourswork_uncshort "Uncertain & shorter: total hours worked in past 12 months"
				drop *_12m_uncshort
				
			// TOTAL HOURS worked PAST 4 WEEKS (Uncertain & longer), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_unclong= `x'hours if `x'length==4
				}
				egen hourswork_unclong=rowtotal(*_12m_unclong), m
				lab var hourswork_unclong "Uncertain & longer: total hours worked in past 4 weeks"
				drop *_12m_unclong				
			
	// 6.e. BY SIZE OF IGA ORGANIZATION (MICRO, SMALL, MEDIUM, LARGE)

		// BY SIZE OF IGA-- 4 WEEKS
		
			// TOTAL HOURS worked PAST 4 WEEKS (MICRO), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_micro= `x'hours_4w if `x'size==1
				}
				egen hourswork4_micro=rowtotal(*_4w_micro), m
				lab var hourswork4_micro "Micro Firm 0-10 workers: total hours worked in past 4 weeks"
				drop *_4w_micro
					
			// TOTAL HOURS worked PAST 4 WEEKS (SMALL), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_small= `x'hours_4w if `x'size==2
				}
				egen hourswork4_small=rowtotal(*_4w_small), m
				lab var hourswork4_small "Small Firm 11-50 workers: total hours worked in past 4 weeks"
				drop *_4w_small
				
			// TOTAL HOURS worked PAST 4 WEEKS (MEDIUM), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_med= `x'hours_4w if `x'size==3 | `x'size==4
				}
				egen hourswork4_med=rowtotal(*_4w_med), m
				lab var hourswork4_med "Medium Firm 51-200 workers: total hours worked in past 4 weeks"
				drop *_4w_med
				
			// TOTAL HOURS worked PAST 4 WEEKS (LARGE), average hours per day
				foreach x in $igacateg {
				gen `x'hours_4w_large= `x'hours_4w if `x'size==5
				}
				egen hourswork4_large=rowtotal(*_4w_large), m
				lab var hourswork4_large "Large Firm 200+ workers: total hours worked in past 4 weeks"
				drop *_4w_large
	
		// BY SIZE OF IGA-- 12 MONTHS
		
			// TOTAL HOURS worked PAST 12 MONTHS (MICRO), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_micro= `x'hours if `x'size==1
				}
				egen hourswork_micro=rowtotal(*_12m_micro), m
				lab var hourswork_micro "Micro Firm 0-10 workers: total hours worked in past 12 months"
				drop *_12m_micro
					
			// TOTAL HOURS worked PAST 12 MONTHS (SMALL), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_small= `x'hours if `x'size==2
				}
				egen hourswork_small=rowtotal(*_12m_small), m
				lab var hourswork_small "Small Firm 11-50 workers: total hours worked in past 12 months"
				drop *_12m_small
				
			// TOTAL HOURS worked PAST 12 MONTHS (MEDIUM), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_med= `x'hours if `x'size==3 | `x'size==4
				}
				egen hourswork_med=rowtotal(*_12m_med), m
				lab var hourswork_med "Medium Firm 51-200 workers: total hours worked in past 12 months"
				drop *_12m_med
				
			// TOTAL HOURS worked PAST 12 MONTHS (LARGE), average hours per day
				foreach x in $igacateg {
				gen `x'hours_12m_large= `x'hours if `x'size==5
				}
				egen hourswork_large=rowtotal(*_12m_large), m
				lab var hourswork_large "Large Firm 200+ workers: total hours worked in past 12 months"
				drop *_12m_large
	
			// Total Months Worked in Large Factory or Farm in Past Year
				qui gen monthsworked_sec7 = 0
				foreach x in farmwage fac {
					qui replace monthsworked_sec7 = monthsworked_sec7 + `x'12months if `x'size>1 & !missing(`x'size) & `x'workfor==2 & !missing(`x'12months)
				}			
				qui replace monthsworked_sec7 = 12 if monthsworked_sec7 > 12 & !missing(monthsworked_sec7)
				la var monthsworked_sec7 "Total Months Worked In Large, Full Time, Factory or Farm from Section 7"

			// Total Months Worked in a "good" job
				qui gen monthsworked_good_sec7 = 0
				foreach x in psnp voc tailor crafts driver sec soldier clerical teach {
					qui replace monthsworked_good_sec7 = monthsworked_good_sec7 + `x'12months if `x'size>1 & !missing(`x'size) & `x'workfor==2 & !missing(`x'12months)
				}			
				qui replace monthsworked_good_sec7 = 12 if monthsworked_good_sec7 > 12 & !missing(monthsworked_good_sec7)
					la var monthsworked_good_sec7 `"Total Months Worked In Large, "Good" profession from Section 7"'
				gen worked_good_sec7 = monthsworked_good_sec7>0 if !missing(monthsworked_good_sec7)
					la var worked_good_sec7 `"Worked In Large, "Good" profession from Section 7"'
					
				// Total Months Worked in a "good" full-time job
				qui gen monthsworked_goodft_sec7 = 0
				foreach x in psnp voc tailor crafts driver sec soldier clerical teach {
					qui replace monthsworked_goodft_sec7 = monthsworked_goodft_sec7 + `x'12months if `x'size>1 & !missing(`x'size) & `x'workfor==2 & !missing(`x'12months) & `x'length == 2
				}			
				qui replace monthsworked_goodft_sec7 = 12 if monthsworked_goodft_sec7 > 12 & !missing(monthsworked_goodft_sec7)
					la var monthsworked_goodft_sec7 `"Total Months Worked In Large, Full Time, "Good" profession from Section 7"'
				gen worked_goodft_sec7 = monthsworked_goodft_sec7>0 if !missing(monthsworked_goodft_sec7)
					la var worked_goodft_sec7 `"Worked In Large, Full-Time, "Good" profession from Section 7"'
				
			// Total Months Worked	
				qui gen monthsworked_sec7_anyfirm = 0
				foreach x in $igacateg {
					qui replace monthsworked_sec7_anyfirm = monthsworked_sec7_anyfirm + `x'12months if `x'size>1 & !missing(`x'size) & `x'workfor==2 & !missing(`x'12months)
				}			
				qui replace monthsworked_sec7_anyfirm = 12 if monthsworked_sec7 > 12 & !missing(monthsworked_sec7)
				la var monthsworked_sec7_anyfirm "Total Months Worked In Large, Full Time Firm from Section 7"			
			
			// Total Months Worked in Any Size Factory or Farm in Past Year
				qui gen monthsworked_sec7_anysize = 0
				foreach x in farmwage fac {
					qui replace monthsworked_sec7_anysize = monthsworked_sec7_anysize + `x'12months if `x'workfor==2 & !missing(`x'12months)
				}			
				qui replace monthsworked_sec7_anysize = 12 if monthsworked_sec7_anysize > 12 & !missing(monthsworked_sec7_anysize)
				la var monthsworked_sec7_anysize "Total Months Worked In Full Time, Factory or Farm from Section 7, any size"
	
	// 6.f. CASH & PROFIT
			
		// TOTAL CASH EARNED IN PAST 7 DAYS
				egen totalcash_7d= rowtotal(*cash7d), m
				label var totalcash_7d "Total cash earned from act in past 7 days"

		// TOTAL PROFIT EARNED IN PAST 7 DAYS
				egen totalprofit_7d= rowtotal(*prof7d), m
				label var totalprofit_7d "Total profit earned from act in past 7 days"
			
		// TOTAL CASH EARNED IN PAST 7 DAYS (BEFORE PAST 7 DAYS)
				egen totalcash_7d7= rowtotal(*14cash), m
				label var totalcash_7d7 "Total cash earned act (past 7 days before past 7)"

		// TOTAL PROFIT EARNED IN PAST 7 DAYS (BEFORE PAST 7 DAYS)
				egen totalprofit_7d7= rowtotal(*14prof), m
				label var totalprofit_7d7 "Total profit earned act (past 7 days before past 7)"		
		
		// TOTAL CASH EARNED (AVERAGE: PAST 7 DAYS and 7 DAYS BEFORE PAST 7 DAYS)
				egen totalcash7_av= rowmean(totalcash_7d totalcash_7d7)
				label var totalcash7_av "Gross earnings avg of past two weeks"

		// TOTAL PROFIT EARNED (AVERAGE: PAST 7 DAYS and 7 DAYS BEFORE PAST 7 DAYS)
				egen totalprofit7_av= rowmean(totalprofit_7d totalprofit_7d7)
				label var totalprofit7_av "Weekly cash earnings"

		// TOTAL PROFIT EARNED IN PAST 2 WEEKS
				egen totalprofit_2w = rowtotal(totalprofit_7d totalprofit_7d7), m
				label var totalprofit_2w "Cash earnings in last two weeks"
				
		// AVERAGE WEEKLY CASH EARNINGS IN PAST MONTH
				gen cash_1w = cash4weeks/4
				la var cash_1w "Average weekly cash earnings over the past month"
				
		// Dummy for no cash in past 2 weeks
				gen zeroprofit2w = totalprofit7_av == 0 if !missing(totalprofit7_av)
				la var zeroprofit2w "Zero profit in past 2 weeks"
				
		// Dummy for no cash in past month
				gen zerocash4w = cash4weeks == 0 if !missing(cash4weeks)
				la var zerocash4w "Zero cash earnings in past 4 weeks"
				
		// ESTIMATED CASH EARNED PER HOUR PER ACTIVITY IN PAST 7 DAYS
			
			// PAST 7 DAYS
				foreach x in $igacateg {
				gen `x'_cashhour7= `x'cash7d/`x'hours_7d
				lab var `x'_cashhour7 "Cash earned per hour (past 7 days): `x'"
				}
				egen cashhour7=rowtotal(*_cashhour7), m
				lab var cashhour7 "Total cash earned per hour (past 7 days)"	
				
			// PAST 7 DAYS (BEFORE LAST 7 DAYS)
				foreach x in $igacateg {
					gen `x'_cashhour77= `x'14cash/`x'hours_7d7
					lab var `x'_cashhour77 "Cash earned per hour (past 7 days before last 7 days): `x'"
				}
				egen cashhour77=rowtotal(*_cashhour77), m
				lab var cashhour77 "Total cash earned per hour (past 7 days before last 7 days)"
		
		* total profit
		
				// PAST 7 DAYS
				foreach x in $igacateg {
					gen `x'_profithour7= `x'prof7d/`x'hours_7d
					lab var `x'_profithour7 "Profit earned per hour (past 7 days): `x'"
				}
				egen profithour7=rowtotal(*_profithour7), m
				lab var profithour7 "Total profit earned per hour (past 7 days)"	
				
			// PAST 7 DAYS (BEFORE LAST 7 DAYS)
				foreach x in $igacateg {
					gen `x'_profithour77= `x'14prof/`x'hours_7d7
					lab var `x'_profithour77 "Profit earned per hour (past 7 days before last 7 days): `x'"
				}
				egen profithour77=rowtotal(*_profithour77), m
				lab var profithour77 "Total profit earned per hour (past 7 days before last 7 days)"
		
			// Average over last 14 days
				foreach x in $igacateg {
					egen `x'_cashhour= rowmean(`x'_cashhour7 `x'_cashhour77)
					lab var `x'_cashhour "Average cash earned per hour: `x'"
				}
				
			// Average over last 14 days
				foreach x in $igacateg {
					egen `x'_profithour= rowmean(`x'_profithour7 `x'_profithour77)
					lab var `x'_profithour "Average profit earned per hour: `x'"
				}
			
			
			// CASH PER DAY (CONVERTED): Assuming 5 work days per week
				foreach x in $igacateg {
					gen `x'_cashday=`x'increport if `x'incperiod==1
					replace `x'_cashday=`x'increport/5 if `x'incperiod==2
					replace `x'_cashday=`x'increport/10 if `x'incperiod==3
					replace `x'_cashday=`x'increport/20 if `x'incperiod==4
					replace `x'_cashday=`x'increport/60 if `x'incperiod==6
					replace `x'_cashday=`x'increport/120 if `x'incperiod==7
					replace `x'_cashday=`x'increport/240 if `x'incperiod==8
					label var `x'_cashday "Cash per day (assuming 5 work days a week)"
				}
					egen totcashday=rowtotal(*_cashday), m
					lab var totcashday "Total cash per day across IGAs (assuming 5 work days a week)"

		// 6.g. FACTORY & COMMERCIAL FARM
		
			// WORKED AT LEAST ONE DAY IN IGA IN PAST 4 WEEKS
			
			foreach x in $igacateg {
				gen `x'_pastmonth = cond(`x'4weeks,1,0,.)
				replace `x'_pastmonth = 0 if `x'length==0 | `x'length==0 | `x'size==1
				lab var `x'_pastmonth "Worked in `x' at least one day in the past 4 weeks"
			}
			// WORKED AT LEAST ONE DAY IN A FACTORY OR COMMERCIAL FARM 
			foreach x in fac farmwage {
				gen big`x'_pastmonth = cond(`x'_pastmonth==1 & (`x'length==2 | `x'length==4) & `x'size>1,1,0,.)
					replace big`x'_pastmonth = . if missing(`x'_pastmonth)
					la var big`x'_pastmonth "Worked in `x' with >10 employees, long term, in past month"
			}
			gen facfarm = cond(bigfac_pastmonth == 1 | bigfarmwage_pastmonth == 1,1,0,.)
			replace facfarm =. if bigfac_pastmonth ==. & bigfarmwage_pastmonth ==.
			la var facfarm "Worked in factory or commercial farm in past month"
			replace facfarm = 1 if appid == 10723 & round_i == 1 /* This observation is still working at endline according to sec 8 */

			// WORKED AT LEAST ONE MONTH IN FACTORY IN 12 MONTHS
			gen fac_pastyear= cond(fac12months, 1, 0, .)
			lab var fac_pastyear "Worked in factory at least one month in past year"
			
			// WORKED AT LEAST SIX MONTHS IN FACTORY IN 12 MONTHS
			gen fac_halfyear = cond(missing(fac12months),., cond(fac12months>5,1,0)) 
			lab var fac_halfyear "Worked in factory at least six months in past year"
			
			// WORKED AT LEAST 1 MONTH In FACTORY OR COMMERCIAL FARM WITH >10 EMPLOYEES
			gen facfarm_30d = ((fac12months>1 & fac12months!= . & facsize>1 & facsize!=.)|(farmwage12months>1 & farmwage12months!= . & farmwagesize>1 & farmwagesize!=.))
			

		// 6.h. ANY IGA
			
			// DID ANY INCOME-GENERATING ACTIVITY IN PAST 4 WEEKS
			gen work_4weeks=cond(hourswork_4wk, 1, 0, .)
			lab var work_4weeks "Did any type of work IGA in the past 4 weeks (formal & informal)"
		

// 7. FULL TIME REGULAR EMPLOYMENT //
	
	
	foreach x in 1 2 3 4 5 6 {
	ren regwork`x' reg`x'work
	} 

	/* Correct some data to be consistent with section 7 */
	replace reg1workers = 5 if appid == 10224 & round_i == 1
	
	
	global reg reg1 reg2 reg3 reg4 reg5 reg6
	
	// NUMBER OF MONTHS ENGAGED IN FULL TIME REGULAR EMPLOYMENT IN THE LAST 12 MONTHS		
		forvalues x = 1/6 {
			gen reg`x'work_capped = reg`x'work
			replace reg`x'work_capped = 12 if reg`x'work_capped >=12 & !missing(reg`x'work_capped)
			local lab: var label reg`x'work
			la var reg`x'work_capped "`lab' (capped at 12m)"
		}
		egen fulltimereg=rowtotal(reg1work-reg6work), m
		replace fulltimereg=12 if 52>= fulltimereg & fulltimereg >= 13									// ASSUMPTION
		lab var fulltimereg "Number of months of regular full time work"

	//	TOTAL NUMBER OF HOURS SPENT ON FULL TIME REGULAR ACTIVITY IN THE LAST 12 MONTHS	
		foreach x in $reg {
		gen `x'_wks=`x'work * 4
		gen `x'_hrs=`x'_wks * `x'weekhrs
		la var `x'_hrs "Hours worked in past 12 months: full time `x'"
		drop `x'_wks
		}
			
		egen regworkhrs_12m = rowtotal (reg1_hrs reg2_hrs reg3_hrs reg4_hrs reg5_hrs reg6_hrs), m
		la var regworkhrs_12m "Hours spent on full time regular activity: 12months"
		
	//	BY ORGANIZATION SIZE: TOTAL NUMBER OF HOURS SPENT ON FULL TIME REGULAR ACTIVITY IN THE LAST 12 MONTHS	 
		
		// TOTAL HOURS worked past 12 months (MICRO)
			foreach x in $reg {
			gen `x'_hrs_micro= `x'_hrs if `x'workers==1
			}
			egen reghrs_micro=rowtotal (*_hrs_micro), m
			lab var reghrs_micro "Full time regular work hours past 12 months: micro org"
			drop *_hrs_micro
			
		// TOTAL HOURS worked past 12 months (SMALL)
			foreach x in $reg {
			gen `x'_hrs_small= `x'_hrs if `x'workers==2
			}
			egen reghrs_small=rowtotal (*_hrs_small), m
			lab var reghrs_small "Full time regular work hours past 12 months: small org"
			drop *_hrs_small
			
		// TOTAL HOURS worked past 12 months (MEDIUM)
			foreach x in $reg {
			gen `x'_hrs_medium= `x'_hrs if `x'workers==3 | `x'workers==4
			}
			egen reghrs_medium=rowtotal (*_hrs_medium), m
			lab var reghrs_medium "Full time regular work hours past 12 months: medium org"
			drop *_hrs_medium

		// TOTAL HOURS worked past 12 months (LARGE)
			foreach x in $reg {
			gen `x'_hrs_large= `x'_hrs if `x'workers==5
			}
			egen reghrs_large=rowtotal (*_hrs_large), m
			lab var reghrs_large "Full time regular work hours past 12 months: large org"
			drop *_hrs_large
			
		// NUMBER OF MONTHS WORKING IN "GOOD" JOB
			gen reggoodwork_mo = 0
			foreach x in $reg {
				replace reggoodwork_mo= reggoodwork_mo + `x'work if (`x'workers==3 | `x'workers==4 | `x'workers == 5) & ///
					(`x'worktype == 5 | `x'worktype == 6 | `x'worktype == 7 | `x'worktype == 9 | `x'worktype == 10) ///
					& !missing(`x'work)
			}
			replace reggoodwork_mo = 12 if reggoodwork_mo>12
				lab var reggoodwork_mo `"Full time regular work months in "good" roles"'
			gen reggoodwork = reggoodwork_mo>0
				lab var reggoodwork `"Any full time regular work in "good" roles"'			
		
		
	/* At the moment, the vast majority of the "days worked" calculated below are at odds with the months worked. */
	local start101 = "04/05/2010"
	local start102 = "03/31/2011"
	local start103 = "10/03/2011"
	local start104 = "11/02/2011"
	local start105 = "05/21/2012"
	local start106 = "01/28/2013"
	local start107 = "05/11/2013"
	local start108 = "06/24/2013"
	local end101 = "04/15/2011"
	local end102 = "10/27/2011"
	local end103 = "08/28/2012"
	local end104 = "10/11/2012"
	local end105 = "04/20/2013"
	local end106 = "12/02/2013"
	local end107 = "04/10/2014"
	local end108 = "06/10/2014"	
	/* Manually correct some dates */
	replace reg1begin = "3/11/2003 0:00:00" if appid == 10135 & round_i == 1
		// Get days worked from start and end dates
			foreach x in $reg {
				foreach y in begin end {
					qui gen `x'_`y'month = substr(`x'`y',1,strpos(`x'`y',"/")-1)
						qui replace `x'_`y'month = "0" + `x'_`y'month if strlen(`x'_`y'month)<2 & !missing(`x'_`y'month)
					qui gen `x'_`y'day = substr(`x'`y',strpos(`x'`y',"/")+1,strpos(substr(`x'`y',strpos(`x'`y',"/")+1,.),"/")-1)
						qui replace `x'_`y'day = "0" + `x'_`y'day if strlen(`x'_`y'day)<2 & !missing(`x'_`y'day)
					qui gen `x'_`y'year = substr(`x'`y',strpos(`x'`y',"/")+strpos(substr(`x'`y',strpos(`x'`y',"/")+1,.),"/")+1,4)
					qui gen `x'`y'_td = date(`x'_`y'month+"/" + `x'_`y'day+"/" + `x'_`y'year,"MDY") if !missing(`x'_`y'month)
					format %td `x'`y'_td
				}
				/* One observation has end date 3/31/2003" which is not a date in the ethiopian calendar */
				replace `x'end_td = date("03/30/2003","MDY") if `x'end_td == date("03/31/2003","MDY")
				replace `x'end_td = date("05/30/2004","MDY") if `x'end_td == date("05/31/2004","MDY")
				replace `x'end_td = date("08/30/2004","MDY") if `x'end_td == date("08/31/2004","MDY")
				replace `x'end_td = date("12/30/2004","MDY") if `x'end_td == date("12/31/2004","MDY")
				replace `x'end_td = date("12/30/2004","MDY") if `x'end_td == date("12/31/2004","MDY")
				replace `x'begin_td = date("07/02/2002","MDY") if `x'begin_td == date("07/02/2028","MDY")
				replace `x'begin_td = date("09/04/2004","MDY") if `x'begin_td == date("9/4/2012","MDY")
				replace `x'begin_td = date("08/03/2011","MDY") if `x'begin_td == date("8/3/2020","MDY")
				replace `x'end_td = date("10/03/2011","MDY") if `x'end_td == date("10/3/2020","MDY")
				/* Set max number of days to be the number of days since baseline */
				foreach cohort in 101 102 103 104 105 106 107 108 {
					qui gen `x'ethio = (`x'end_td < date("`start`cohort''","MDY") & year(`x'end_td)<2009) if projid == `cohort'
					qui replace `x'ethio = 1 if missing(`x'end_td) & year(`x'begin_td)<2009 & projid == `cohort'
					foreach y in begin end {
						ethiocal `x'`y'_td if `x'ethio == 1 & projid == `cohort', gen(`y'_greg)
						qui replace  `x'`y'_td = `y'_greg if `x'ethio == 1 & projid == `cohort'
						drop `y'_greg
					}
					drop `x'ethio
					qui replace `x'begin_td = date("`start`cohort''","MDY") if projid == `cohort' & `x'begin_td < date("`start`cohort''","MDY")
					qui replace `x'end_td = date("`end`cohort''","MDY") if projid == `cohort' & `x'end_td > date("`end`cohort''","MDY")	& !missing(`x'end_td)			
				}
				qui gen `x'days = `x'end_td - `x'begin_td if round_i<=2
				/* Replace with the monthly value if the start and end dates don't work out */
				replace `x'days =  `x'work*30 if `x'days == . & `x'work!=. & `x'work!=0 & round_i<=2
				replace `x'days = `x'days * -1 if `x'days < 0 & round_i<=2
				replace `x'days = 0 if missing(`x'days) & round_i<=2
				replace `x'days = 0 if `x'days > 365 & round_i <= 2
			}

// 8. HEALTH: PHYSICAL/PSYCHOLOGICAL //

		// RECODE: LEVEL OF DIFFICULTY IN CONDUCTING PHYSICAL TASKS (GENERATES NEW VAR WITH PREFIX "H_")
			recode  walk2km carry20liters dayactiv workout workbench ///
			(1=3 "Easily") (2=2 "Slight difficulty") (3=1 "Great difficulty") (4=0 "Unable"), pre(h_) lab(difficulty2)
			lab var h_walk2km	"Ability to walk 2 kilometers: 4=Easily,1=Unable"
			lab var h_carry20liters	"Ability to carry 20 litres of water for 20 meters: 3=Easily,0=Unable"
			lab var h_dayactiv "Ability to carry out usual daily activities: 3=Easily,0=Unable" 
			lab var h_workout "Ability to work on feet outdoors for full day: 3=Easily,0=Unable"
			lab var h_workbench "Ability to stand at workbench/assembly line for 6-8 hrs: 3=Easily,0=Unable"
			
		// ADDITIVE HEALTH INDEX *F*
			egen healthproblems=rowtotal(h_walk2km h_carry20liters h_dayactiv h_workout h_workbench), m
			lab var healthproblems "Additive health: 0=worst 15=no problems"
		
		// DUMMY FOR HAVING ANY HEALTH PROBLEM
			sum healthproblems, d
			gen anyhealthproblem=cond(healthproblems<=r(p10),1,0) if !missing(healthproblems)
			replace anyhealthproblem=. if healthproblems==.
			lab var anyhealthproblem "Bottom 10% of health"
			
		// DUMMY FOR HAVING 1 or MORE SERIOS HEALTH PROBLEMS
			qui gen temp = 0
			qui gen temp2 = 0
			foreach x in walk2km carry20liters dayactiv workout workbench {
				replace temp = temp + 1 if `x'==3 | `x' == 4
				replace temp2 = temp2 + 1 if `x'==2 | `x'==3 | `x' == 4				
			}
			qui gen disabled1 = cond(temp>=1,1,0) if !missing(healthproblems)
			la var disabled1 "Has great difficulty doing one or more daily activities"
			qui gen disabled2 = cond(temp2>=1,1,0) if !missing(healthproblems)
			la var disabled2 "Has at least some difficulty doing one or more daily activities"
			drop temp temp2
					
		// DUMMY FOR HAVING 2 or MORE SERIOS HEALTH PROBLEMS
			qui gen temp = 0
			qui gen temp2 = 0
			foreach x in walk2km carry20liters dayactiv workout workbench {
				replace temp = temp + 1 if `x'==3 | `x' == 4
				replace temp2 = temp2 + 1 if `x'==2 | `x'==3 | `x' == 4				
			}
			qui gen disabled = cond(temp>=2,1,0) if !missing(healthproblems)
			la var disabled "Has great difficulty doing two or more daily activities"
			qui gen disabled3 = cond(temp2>=2,1,0) if !missing(healthproblems)
			la var disabled3 "Has at least some difficulty doing two or more daily activities"
			drop temp temp2
			
			qui gen temp = 0
			foreach x in walk2km carry20liters dayactiv workout {
				replace temp = temp + 1 if `x'==3 | `x' == 4			
			}
			qui gen disabled4 = cond(temp>=2,1,0) if !missing(healthproblems)
			la var disabled4 "Has great difficulty doing two or more daily activities (excluding workbench)"
			drop temp
			
			foreach x in walk2km carry20liters dayactiv workout workbench {
				gen seriousdif_`x' = (`x'==3 | `x' == 4)
				la var seriousdif_`x' "Has serious difficulty doing `x'"
				gen somedif_`x' = (`x'==2 | `x'==3 | `x' == 4)
				la var somedif_`x' "Has some difficulty doing `x'"
			}
			
		gen healthchange_lastyear = health_laddnow - health_laddyearago
			la var healthchange_lastyear "Change in self-assessment of health from 1 year ago to now"
		gen healthchange_5years = health_5years - health_laddnow
			la var healthchange_5years "Expected change in self-assessment of health from now to 5 years from now"

	// 8.b. PSYCHOLOGICAL HEALTH VARIABLES

		// PATIENT HEALTH QUESTIONNAIRE (PHQ-9): USES STANDARD PHQ CALCULATION *F* // Flipped on 8/28 so higher is better CH
			recode  phq* (1=3) (2=2) (3=1) (4=0), pre(r_) 
			egen phqtotal=rowtotal(r_phq*), m
			gen phqscore=0 if phqtotal<=7 // most depressed
			replace phqscore=1 if phqtotal==8 | phqtotal==9 | phqtotal==10 | phqtotal==11 | phqtotal==12
			replace phqscore=2 if phqtotal==13 | phqtotal==14 | phqtotal==15 | phqtotal==16 | phqtotal==17
			replace phqscore=3 if phqtotal==18 | phqtotal==19 | phqtotal==20 | phqtotal==21 | phqtotal==22
			replace phqscore=4 if phqtotal>=23
			label define phqscore 4 "None" 3 "Mild Depression" 2 "Moderate Depression" ///
			1 "Moderate Severe Depression" 0 "Severe Depression"
			label val phqscore phqscore
			label var phqscore "Degree of Depression: using PHQ scale categories"
			label var phqtotal "Total points on PHQ 0-27 (0: More Depressed)"
			gen phqtotal_r = 27 - phqtotal
			label var phqtotal_r "Total points on PHQ 0-27 (27: More Depressed)"
			
		// GENERALIZED ANXIETY DISORDER ASSESSMENT (GAD-7): USES STANDARD GAD CALCULATION *F*
			recode  gad* (1=3) (2=2) (3=1) (4=0), pre(r_) 
			egen gadtotal=rowtotal(r_gad*), m
			gen gadscore=0 if gadtotal<=4
			replace gadscore=1 if gadtotal==6 | gadtotal==7 | gadtotal==8 | gadtotal==9 | gadtotal==5
			replace gadscore=2 if gadtotal==11 | gadtotal==12 | gadtotal==13 | gadtotal==14 | gadtotal==10
			replace gadscore=3 if gadtotal>=15
			label define gadscore 3 "Mild Anxiety" 2 "Moderate Anxiety" 1 "Moderate Sever Anxiety" 0 "Severe Anxiety"
			label val gadscore gadscore
			label var gadscore "Degree of Anxiety Disorder: using GAD scale categories"	
			label var gadtotal "Anxiety index (lower is worse 0-21)"
			gen gadtotal_r = 21 - gadtotal
			label var gadtotal_r "Anxiety index (higher is worse 0-21)"

			
		// AGRESSIVE BEHAVIOR VARIABLES *F*
			// NEGATIVE
			recode agg_insult agg_arguehh agg_argueout agg_argueviolence agg_frustration agg_fight ///
			agg_threat agg_arguepolice (1=3) (2=2) (3=1) (4=0), pre(r_)
			// POSITIVE
			recode agg_anger (1=0) (2=1) (3=2) (4=3), pre(r_)
			egen agression= rowtotal (r_agg*), m
			label var agression "Aggressive behavior 27-0 (0: More Aggressive)"

	
// 9. CONSUMPTION //

	// PURCHASES CONSUMED OUTSIDE HOME (FOOD/DRINKS)
		egen spendout=rowtotal (eatout tea alcoout)
		label var spendout "Amount spend on items consumed outside home, last 7 days"
		
	// PERSONAL EXPENDITURES IN LAST MONTH (SMALL ITEMS)
		egen ownconsume=rowtotal (mobile transpo cigs chat cosmetics luxury)
		label var ownconsume "Amount spent on small expenditures for self in last month"	

	// DUMMY ON HUNGER (FOOD SECURITY)
			recode hungry (1/7=1)(0=0)(else=.), gen(bed_hungry) lab(yesno)
			lab var bed_hungry "Went to bed hungry at least once in past week"   


// 10. WORKPLACE CONDITION //

	// RECODING SO THAT ALL POSITIVE (RANK) *F*
			// POSITIVE
			recode comfort temperature controlhours timeoff learnskills (4=0) (3=1) (2=2) (1=3), pre(rank_)
			// NEGATIVE
			recode space shortbreaks boring (4=3) (3=2) (2=1) (1=0), pre(rank_)
			
			// DUMMIES
			foreach x in comfort temperature controlhours timeoff learnskills space shortbreaks boring {
				gen `x'_dum = (rank_`x' == 2 | rank_`x' == 3) if !missing(rank_`x')
				la var `x'_dum "(0,1;Positive) `:var la `x''"
			}
			
			gen activityhome = activitylocation == 1 if !missing(activitylocation)
				la var activityhome "Primary daily activity is at home"
				
			egen workcond=rowtotal(comfort_dum temperature_dum controlhours_dum timeoff_dum learnskills_dum space_dum shortbreaks_dum boring_dum), m
			label var workcond "Workplace Conditions (0-8: Better)"				
				
				
	// AIR PROBLEMS IN WORKPLACE *F*
			egen airprob= rowtotal(badsmell dust smokefire smokemachine badair)
			label var airprob "Air quality problem in workplace (0-5: 5=Worse)"
			
	// RELATIONS WITH WORKERS FROM WORKPLACE *F*
			// POSITIVE
			recode interactinwork interactout (4=0) (3=1) (2=2) (1=3), pre(rank_)
			// NEGATIVE
			recode argueinwork argueoutwork (4=3) (3=2) (2=1) (1=0), pre(rank_)
		
			egen workinteract=rowtotal(rank_interact* rank_argue*), m
			label var workinteract "Workplace Conditions: Relations with Co-Workers (0-12: Better)"
			
	// GENDER-BASED/SEXUAL ABUSE IN WORKPLACE
			recode workplacebacins workplacebacattem workplacebackick workplacesexverb workplacesexattem workplacesex (4=0) (3=1) (2=2) (1=3), pre(rank_)
			egen workabusebac = rowtotal(rank_workplacebac*), m
			la var workabusebac "Workplace abuse based on background (0-9: Better)"
			
			egen workabusesex = rowtotal(rank_workplacesex*), m
			la var workabusesex "Workplace sexual abuse or abuse based on gender (0-9: Better)"			
			
	// INCOME YEAR AGO VS. INCOME TODAY
			gen income_change1= income_laddnow-income_laddyearago
			lab var income_change1 "Subjective: income today minus income last year (10 point ladder)"

	// INCOME NEXT YEAR VS. INCOME TODAY (OPTIMISM)
			gen income_change2= income_laddnxtyear-income_laddnow
			lab var income_change2 "Subjective: income next year minus income today (10 point ladder)" 

	// INCOME IN 5 YEARS VS. INCOME TODAY (OPTIMISM)
			gen income_change3= income_ladd5years-income_laddnow
			lab var income_change3 "Subjective: income in five years minus income today (10 point ladder)"
	 
	 
// 11. INCOME RISK //
	
	// SIMPLE DIFFERENCES BETWEEN HIGHEST POSSIBLE INCOME TO LOWEST POSSIBLE INCOME
		gen incdiff30 =.
			replace incdiff30=high30days-low30days
			lab var incdiff30 "Diff btw highest lowest possible income in next 30 days"
		
		gen incdiff12 =.
			replace incdiff12=high12months-low12months
			lab var incdiff12 "Diff btw highest lowest income in next 12 mon"		
	
	// 	DIFF BETWEEN HIGHEST AND LOWEST INCOME PER MONTH FOR THE NEXT TWELVE MONTHS
		
		gen incdiff12_permon =.	
			replace incdiff12_permon = incdiff12/ 12
			replace incdiff12_permon = 0 if incdiff12 == 0
			lab var incdiff12_permon "Highest - lowest earnings per month"
			
	// LIKELIHOOD OF RECEIVING PREDICTED AMOUNT IN THE NEXT 30 DAYS

		gen risk_mid30 = .
			replace risk_mid30 = likelymid30/ 10
			replace risk_mid30 = 0 if likelymid30 == 0
			replace risk_mid30 = 0 if likelymid30 == 0
			lab var risk_mid30 "Likelihood of receiving predicted earnings in the next month"
			
	// LIKELIHOOD OF RECEIVING PREDICTED AMOUNT IN THE NEXT 12 MONTHS

		gen risk_mid12 = .
			replace risk_mid12  = likelymid12/ 10
			replace risk_mid12  = 0 if likelymid12 == 0
			replace risk_mid12  = 0 if incdiff12 == 0
			lab var risk_mid12  "Likelihood of receiving predicted amount in the next year"
			
	// LIKELIHOOD OF BECOMING ILL IN THE NEXT 30 DAYS

		gen risk_ill = .
			replace risk_ill = becomeill/ 10
			replace risk_ill = 0 if becomeill == 0
			lab var risk_ill "Likelihood of illness that affects work in the next month"

	// LIKELIHOOD OF FINDING A BETTER JOB IN THE NEXT 30 DAYS
		
		gen risk_betterjob = .
			replace risk_betterjob = likely_betterjob / 10
			replace risk_betterjob = 0 if likely_betterjob == 0
			lab var risk_betterjob "Likelihood of finding a better job in the next month"
		
		gen risk_regwork = .
			replace risk_regwork = likely_regwork / 10
			replace risk_regwork = 0 if likely_regwork == 0
			lab var risk_regwork "Likelihood of full-time regular work in the next month"

// 12. EMPOWERMENT //

	// RECODE SPENDING DECISION VARIABLES	
			recode schoolfees_decide smallitems1_decide smallitems2_decide expensiveitems1_decide expensiveitems2_decide ///
			(1=2) (2=1) (3=0), pre (rank_)

	// DECISION VARIABLE (ADDITIVE INDEX 0-10)	
			egen decision= rowtotal(rank_schoolfees_decide rank_smallitems1_decide rank_smallitems2_decide ///
			rank_expensiveitems1_decide rank_expensiveitems2_decide), m
			label var decision "Additive Index: involvement in decisions on spending (0-10: More Empowered)"

	// RECODE FEMALE EMPOWERMENT ATTITUDES VARIABLES *F*
		// POSITIVE
			recode empowerment1 empowerment3 empowerment5 empowerment7 ///
			empowerwork1 empowerwork4 (1=3) (2=2) (3=1) (4=0), pre(rank_)
		// NEGATIVE
			recode empowerment2 empowerment4 empowerment6 empowerment8 ///
			empowerwork2 empowerwork3 (1=0) (2=1) (3=2) (4=3), pre(rank_)

	// FEMALE EMPOWERMENT ATTITUDES INDEX
			egen femaleempower= rowtotal(rank_empower*), m
			label var femaleempower "Additive Index: attitudes towards female empowerment (0-36: Empower)"


// 13. TIME-USE //
	
	// RATIO OF PAID WORK TO TOTAL REPORTED ACTIVITIES (HOURS PER WEEK)
			egen allreporttime= rowtotal (timeuse_domestic timeuse_caring timeuse_hhwork ///
			timeuse_work timeuse_school timeuse_leisure)
			gen worktimeratio= timeuse_work / allreporttime
			label var worktimeratio "Ratio of time spent in paid work on total hours per week reported"
			drop allreporttime
		
	// DUMMY FOR ANY PAID WORK
			gen paidwork= cond(timeuse_work>0 & timeuse_work!=., 1, 0)
			label var paidwork "Any Paid Work (Using Time-Use Data)"
			label val paidwork yesno
	
 
// 14. AGGRESSION & ABUSE //
	
	// ABUSE/HARASSMENT RECEIVED
			foreach x in threat humiliate beat kick accuse limitfamily knowalltimes {
				recode `x' (4=0) (3=1) (2=2) (1=3), pre(rank_)
				replace rank_`x'=. if rank_`x'==5
			}
			egen abusein= rowtotal(rank_threat rank_humiliate rank_beat rank_kick ///
				rank_accuse rank_limitfamily rank_knowalltimes), m
			label var abusein "Frequency of abuse received 0-21: more abuse"
			
	// ABUSE/HARASSMENT GIVEN
			foreach x in threat_p humiliate_p beat_p kick_p accuse_p limitfamily_p knowalltimes_p {
				recode `x' (4=0) (3=1) (2=2) (1=3), pre(rank_)
				replace rank_`x'=. if rank_`x'==5
			}
			egen abuseout= rowtotal(rank_threat_p rank_humiliate_p rank_beat_p rank_kick_p ///
			rank_accuse_p rank_limitfamily_p rank_knowalltimes_p)
			label var abuseout "Frequency of abuse given 0-21: more abuse"
			
	// EMPOWERMENT
			recode expressopinion holdmoney allowedmarket (4=0) (3=1) (2=2) (1=3), pre(rank_)
				egen empowered= rowtotal(rank_expressopinion rank_holdmoney rank_allowedmarket)
				label var empowered "Freedom in money/market access 0-12: more free"

				
// 15. NON-COGNITIVE //

	// RECODE "AGREE" SCALE VARIABLES: (a new var is generated with prefix "r_")
			recode locus1-locus8 ///
			(4=0 "Strongly disagree") (3=1 "Somewhat disagree") ///
			(2=2 "Somewhat agree") (1=3 "Strongly agree"), pre(r_) lab (agree_recode)

	// LOCUS OF CONTROL INDEX (GREATER CONTROL IS HIGHER VALUE)
			recode r_locus1 r_locus2 r_locus4 r_locus5 r_locus8 (0=0), pre(rank_)
			recode r_locus3 r_locus6 r_locus7 (3=0)(2=1)(1=2)(0=3), pre(rank_)
				egen locuscontrol =rowtotal(rank_r_locus*), m
				lab var locuscontrol "Additive locus of control index, 0-24(more control)"

	// SELF ESTEEM INDEX (GREATER ESTEEM IS HIGHER VALUE)
			recode r_esteem1 r_esteem5 r_esteem7 (0=0), pre(rank_)
			recode r_esteem2 r_esteem3 r_esteem4 r_esteem6 r_esteem8 ///
			 (3=0)(2=1)(1=2)(0=3), pre(rank_)
				egen selfesteem =rowtotal(rank_r_esteem*), m
				lab var selfesteem "Additive self esteem index, 0-24(higher self esteem)"

			drop rank_r_lo* rank_r_est*		
		
// 16. INFORMAL NETWORK //
		
	// NUMBER OF PEOPLE CAN RELY ON FOR FINANCIAL HELP (HAS AT LEAST 5 / HAS NONE)
			tab financialhelp, mi  
			recode financialhelp (5/200=1)(0/4=0), gen(finhelp_5plus) lab(yesno)
			lab var finhelp_5plus "Has at least 5 people who could be relied on for financial or in-kind support"
			recode financialhelp (0=1)(1/200=0), gen(finhelp_none) lab(yesno)
			lab var finhelp_none "Has no one who could be relied on for financial or in-kind support"

	// NUMBER OF *WEALTHIER* PEOPLE CAN RELY ON FOR FINANCIAL HELP (HAS AT LEAST 5 / HAS NONE)
			tab finwealthier, mi 
			recode finwealthier (5/200=1)(0/4=0), gen(finwealth_5plus) lab(yesno)
			lab var finwealth_5plus "Has at least 5 people wealthier than him/her who could be relied on"
			recode finwealthier (0=1)(1/200=0), gen(finwealth_none) lab(yesno)
			lab var finwealth_none "Has no one wealthier than him/her who could be relied on"
				replace finwealthier =0 if financialhelp==0
				replace finwealth_5plus =0 if financialhelp==0
				replace finwealth_none =0 if financialhelp==0 
			
	// NUMBER OF NEIGHBORS CAN RELY ON FOR FINANCIAL HELP (HAS AT LEAST 1)
			tab finneighbor, mi      
			recode finneighbor(1/200=1)(0=0), gen(finneigh_1plus) lab(yesno)
			lab var finneigh_1plus "Has at least 1 neighbor who could be relied on"
			replace finneigh_1plus =0 if financialhelp==0

	// NUMBER OF PEOPLE CAN DISCUSS AG/BUSINESS MATTERS WITH (HAS AT LEAST 5 / HAS NONE)
			tab agmatters, mi        
			recode agmatters (5/200=1)(0/4=0), gen(agmatters_5plus) lab(yesno)
			lab var agmatters_5plus "Has at least 5 people to comfortably discuss agri/business matters with"
			recode agmatters (0=1)(1/200=0), gen(agmatters_none) lab(yesno)
			lab var agmatters_none "Has no one to comfortably discuss agri/business matters with"

	// NUMBER OF *WEALTHIER* PEOPLE CAN DISCUSS AG/BUSINESS MATTERS WITH (HAS AT LEAST 5 / HAS NONE)
			tab agwealthier, mi
			recode agwealthier (5/200=1)(0/4=0), gen(agwealth_5plus) lab(yesno)
			lab var agwealth_5plus "Has at least 5 people wealthier to comfortably discuss agri/business matters with"
			recode agwealthier (0=1)(1/200=0), gen(agwealth_none) lab(yesno)
			lab var agwealth_none "Has no one wealthier than him/her to comfortably discuss agri/business matters with"
				replace agwealthier =0 if agmatters==0
				replace agwealth_5plus =0 if agmatters ==0
				replace agwealth_none =0 if agmatters ==0 
		 
	// NUMBER OF NEIGHBORS CAN DISCUSS AG/BUSINESS MATTERS WITH (HAS AT LEAST 1)
			tab agneighbors, mi   
			recode agneighbors (1/200=1)(0=0), gen(agneigh_1plus) lab(yesno)
			lab var agneigh_1plus "Has at least 1 neighbor to comfortably discuss agri/business matters with"
			replace agneigh_1plus =0 if agmatters ==0
			
		
// 17. SOCIAL NETWORK (RANDOM NAMES) //

	/*
	
	Note: 5 random names for 101 vs. 4 random names for all other projects. (For consistency, we drop the 5th random name for 101)
	Legend: t= jobs treatment; n= ngo treatment; c= pure control group
	
	*/
	
	replace c2_helpoutsum= "20" if c2_helpoutsum=="$20.00"
	destring c2_helpoutsum, replace

	foreach x in c t n {
	
	// NUMBER OF PEOPLE, AMOUNT OF CASH
		
		foreach y in know neighbor friends agmatters conversation iddir church helpin helpinsum helpinpast helpinsumpast helpout helpoutsum helpoutpast helpoutpastsum {
	
		// General loop: NUMBER OF PEOPLE, AMOUNT OF CASH
			egen `y'_`x'=rowtotal(`x'1_`y' `x'2_`y' `x'3_`y' `x'4_`y')
		
		}
		
	// Number of people RELATED
			recode `x'*_related (3=0) (1=1) (2=1), pre(drop_)
			egen related_`x'=rowtotal (drop_*)
			drop drop_*
			
	// Number of people UNFAIR
			recode `x'*_fair (2=0) (1=1), pre(drop_)
			egen unfair_`x'=rowtotal (drop_*)
			drop drop_*
	
	// LABELING SOCIAL NETWORK

		label var know_`x' "No. of people known from `x' group"
		label var neighbor_`x' "No. of people that are neighbors from `x' group"	
		label var friends_`x' "No. of people consider friends from `x' group"	
		label var related_`x' "No. of people that are related (blood or marriage) from `x' group"
		label var agmatters_`x' "No. of people discuss ag/business matters with from `x' group"
		label var conversation_`x' "No. of people had more than 5 min. conversation with from `x' group"
		label var iddir_`x' "No. of people in same iddir or mutual support grp from `x' group"
		label var church_`x' "No. of people in same church or religious grp from `x' group"
		
		label var helpin_`x' "No. of people could ask for help if needed cash from `x' group"
		label var helpinsum_`x' "Amount of cash could raise in one week from `x' group"
		label var helpinpast_`x' "No. of people received help from in past from `x' group"
		label var helpinsumpast_`x' "Amount of cash received in past 12 months from `x' group"
		
		label var helpout_`x' "No. of people you would help if needed cash from `x' group"
		label var helpoutsum_`x' "Amount of cash you would provide in one week for `x' group"
		label var helpoutpast_`x' "No. of people given help to in past from `x' group"
		label var helpoutpastsum_`x' "Amount of cash given in past 12 months to `x' group"
		
		label var unfair_`x' "No. of people take advantage of you from `x' group"

	
	// AT LEAST ONE PERSON (DUMMIES)
		
		foreach z in know neighbor friends related agmatters conversation iddir church helpin ///
		helpinsum helpinpast helpinsumpast helpout helpoutsum helpoutpast helpoutpastsum unfair {
		
			gen `z'_`x'_dm=1 if `z'_`x'!=0 | `z'_`x'!=.
			replace `z'_`x'_dm=0 if `z'_`x'==.
		}
	
	//LABELING SOCIAL NETWORK: DUMMIES

		label var know_`x'_dm "Knows at least 1 person from `x' group"
		label var neighbor_`x'_dm "At least 1 neighbor from `x' group"	
		label var friends_`x'_dm "At least 1 person considered friend from `x' group"	
		label var related_`x'_dm "At least 1 person related (blood or marriage) from `x' group"
		label var agmatters_`x'_dm "At least 1 per discuss ag/business matters with from `x' group"
		label var conversation_`x'_dm "At least 1 person, had more than 5 min. conversation w/ from `x' group"
		label var iddir_`x'_dm "At least 1 person in same iddir or mutual support grp from `x' group"
		label var church_`x'_dm "At least 1 person in same church or religious grp from `x' group"
		
		label var helpin_`x'_dm "At least 1 person could ask for help if needed cash from `x' group"
		label var helpinsum_`x'_dm "Could raise money in one week from `x' group"
		label var helpinpast_`x'_dm "Received help from at least 1 person in past from `x' group"
		label var helpinsumpast_`x'_dm "Received money in past 12 months from `x' group"
		
		label var helpout_`x'_dm "At least 1 person you would help if needed cash from `x' group"
		label var helpoutsum_`x'_dm "Would provide cash in one week for `x' group"
		label var helpoutpast_`x'_dm "Given help to at least 1 person in past from `x' group"
		label var helpoutpastsum_`x'_dm "Given money in past 12 months to `x' group"
		
		label var unfair_`x'_dm "At least 1 person take advantage of you from `x' group"
	}

// 18. TIME & RISK //

	// TIME PREFERENCE INDEX (HIGHER VALUE: MORE PATIENT) *F*

		// POSITIVE VARS
			recode time2 (2=0), pre(rank_)
		// NEGATIVE VARS
			recode time1 time3 time4 time5 time6 time7 time8 (1=0)(2=1), pre(rank_)

			egen patience = rowtotal(rank_time*)
			lab var patience "Additive patience (discount rate) index, 0-16(more patient)"

	// RISK AVERSION INDEX (HIGHER VALUE: MORE AVERSE) *F*
			
		// POSITIVE VARS
			recode risk1 risk2 risk3 risk5 risk7 (2=0), pre(rank_)
		// NEGATIVE VARS
			recode risk4 risk6 risk8 (1=0)(2=1), pre(rank_)

			egen riskaversion = rowtotal(rank_risk*)
			lab var riskaversion "Additive risk aversion index, 0-24(more averse)"

	// SELF-CONTROL INDEX (HIGHER VALUE: MORE CONTROL) *F*

		// POSITIVE VARS
			recode control3 control7 (2=0), pre(rank_) 
		// NEGATIVE VARS
			recode control1 control2 control4 control5 control6 control8 (2=1)(1=0), pre(rank_) 

			egen selfcontrol = rowtotal(rank_contr*)
			lab var selfcontrol "Additive self control index, 0-24(more control)"
			
	// PUNCTUALITY (HIGHER VALUE: MORE CONTROL) *F*
			recode punctual3 (1=4) (2=3) (3=2) (4=1) (5=0), pre(rank_)
			recode punctual4 punctual5 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			
			egen punctual=rowtotal(punctual3 punctual4 punctual5)
			lab var punctual "Punctuality and time consciousness, 0-15(more punctual)"
			
// 19. SOCIO-POLITICAL ATTITUDES //

	// ATTITUDES TOWARDS GOVERNMENT: POLICIES & PROGRAMS (HIGHER VALUE: FAVOR GOVT) *F*
			// NEGATIVE QUESTIONS
				recode  government2 government3 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode  government1 government4 government5 government6 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)
			
			egen govt_att = rowtotal(rank_government*), m
			lab var govt_att "Attitudes towards government (policies) additive index (0-24 Favor Govt)"		
		
	// ATTITUDES TOWARDS LAND RIGHTS (HIGHER VALUE: WANT MORE RIGHTS) *F*
			// NEGATIVE QUESTIONS
				recode landrights2 landrights3 landrights4 landrights6 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode landrights1 landrights5 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)
			
			egen land_att = rowtotal(rank_landright*), m
			lab var land_att "Attitudes towards land rights additive index (0-24 Want More Rights)"	
		
	// ATTITUDES TOWARDS DEMOCRACY (HIGHER VALUE: PREFER DEMOCRATIC) *F*
			// NEGATIVE QUESTIONS
				recode democracy1 democracy2 democracy5 democracy6 democracy8 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode democracy3 democracy4 democracy7 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)  
			
			egen democ_att = rowtotal(rank_democ*), m
			lab var democ_att "Attitudes/perceptions on democracy; additive index (0-32 More Vocal/Democracy)"	
		
	// COLLECTIVE ACTION: INVOLVED (HIGHER VALUE: MORE INVOLVED) *F*
			// NEGATIVE QUESTIONS
				recode collectiveaction2 collectiveaction3 collectiveaction4 (1=0) (2=1) (3=2) (4=3) (5=4), pre(rank_)
			// POSITIVE QUESTIONS
				recode collectiveaction1 collectiveaction5 collectiveaction6 (5=0) (4=1) (3=2) (2=3) (1=4), pre(rank_)  
			
			egen collective_att = rowtotal(rank_democ*), m
			lab var collective_att "Collective Action: Involvement Additive Index (0-24 More Involved)"	
			
			foreach x in 1 2 3 4 5 6 {
				gen collective`x'_dum = rank_collectiveaction`x' > 2 if !missing(rank_collectiveaction`x')
				la var collective`x'_dum "`: var lab rank_collectiveaction`x''"
			}
			foreach x in 2 3 4 {
				la var collective`x'_dum "(resc)`: var lab rank_collectiveaction`x''"
			}
			
	// PRIORITIES
		
		// TOP PRIORITY
		
		gen work_pri1=1 if normpriorities1==5
			replace work_pri1=0 if work_pri1==.
			lab var work_pri1 "Top priority: work"
		gen famfriend_pri1=1 if normpriorities1==1 | normpriorities1==2 | normpriorities1==3 
			replace famfriend_pri1=0 if famfriend_pri1==.
			lab var famfriend_pri1 "Top priority: family and friends"
		gen religion_pri1=1 if normpriorities1==6
			replace religion_pri1=0 if religion_pri1==.
			lab var religion_pri1 "Top priority: religion"
		gen politics_pri1=1 if normpriorities1==7
			replace politics_pri1=0 if politics_pri1==.
			lab var politics_pri1 "Top priority: politics"
		
		// BOTTOM PRIORITY
		
		gen work_prib=1 if normpriorities7==5
			replace work_prib=0 if work_prib==.
			lab var work_prib "Bottom priority: work"
		gen famfriend_prib=1 if normpriorities7==1 | normpriorities7==2 | normpriorities7==3 
			replace famfriend_prib=0 if famfriend_prib==.
			lab var famfriend_prib "Bottom priority: family and friends"
		gen religion_prib=1 if normpriorities7==6
			replace religion_prib=0 if religion_prib==.
			lab var religion_prib "Bottom priority: religion"
		gen politics_prib=1 if normpriorities7==7
			replace politics_prib=0 if politics_prib==.
			lab var politics_prib "Bottom priority: politics"
		
	// WILLING TO ANSWER POLITICAL QUESTIONS
			recode answerpolitics (2=0) (1=1), pre(rank_)
			
	// POLITCAL PRIORITIES
		recode normauthority normreligion normtech (4=0) (3=1) (2=2) (1=3), pre (r_)
		recode normfamily (4=3) (3=2) (2=1) (1=0), pre (r_)
		egen polnorms = rowtotal(r_normauthority r_normfamily r_normreligion r_normtech), m
			la var polnorms "Intensity of political priorities"
			
	// PARTISAN POLITICAL ACTION
	
		egen partisanact=rowtotal(rally_pa moneyrally_pa polmeeting_pa polmember_pa ///
		moneyreg_pa partytshirty_pa moneytshirt_pa votepersuade_pa workelect_pa)
		label var partisanact "Partisan political action index (0-9: more partisan action)
		
		egen partisanship=rowtotal(votepersuade_pa workelect_pa rally_pa  ///
		polmeeting_pa polmember_pa moneyreg_pa partytshirty_pa moneytshirt_pa close_p), m
		label var partisanship "Partisan political affiliation index (0-9: more partisan action and opinion)"

		
	// OPINION ON RULING PARTY
	
		gen voteEPRDF = voteparty_p == 9 if !missing(voteparty_p)
			la var voteEPRDF "Would vote for EPRDF (ruling party) if election was today"
		
	// NON-PARTISAN POLITICAL ACTION
	
	// INTEREST IN POLITICS
		recode intnextparelec_npa intnextregelec_npa intnextlocelec_npa intpubaffairs_npa (4=0) (3=1) (2=2) (1=3), pre (r_)
		egen election_int= rowtotal (intnextparelec_npa intnextregelec_npa intnextlocelec_npa)
		la var election_int "Interest in different type of future elections (0-12: more interested)"
		
		foreach x in nextparelec nextregelec nextlocelec pubaffairs {
			gen int`x'_dum  = (r_int`x'_npa>=2) if !missing(r_int`x'_npa)
		}
		la var intnextparelec_dum "Interested in next parliamentary election"
		la var intnextregelec_dum "Interested in next regional council election"
		la var intnextlocelec_dum "Interested in next local election"
		la var intpubaffairs_dum "Interested in public affairs"
		
		recode polknowhow_npa (3=0) (2=1) (1=2), pre (r_)
		gen polknowhow_dum = r_polknowhow_npa>=1 if !missing(polknowhow_npa)
		la var polknowhow_dum "Equally or more knowledgeable than peers about politics"
		
		egen nonpartisaninterest = rowtotal(intnextparelec_dum intnextregelec_dum intnextlocelec_dum ///
		intpubaffairs_dum dispolt_npa diswhotovote_npa polknowhow_dum polposition_npa attendvoteeduc_npa malpractice_npa), m
		la var nonpartisaninterest "Interest in politics (non-partisan) (0-10: more interested)"
		
	// OVERALL POLITICAL INTEREST AND INVOLVEMENT
	
		egen politicalaction = rowtotal(votepersuade_pa workelect_pa rally_pa polmeeting_pa polmember_pa ///
		moneyreg_pa partytshirty_pa moneytshirt_pa close_p intnextparelec_dum intnextregelec_dum ///
		intnextlocelec_dum intpubaffairs_dum dispolt_npa diswhotovote_npa polknowhow_dum polposition_npa ///
		attendvoteeduc_npa malpractice_npa collective1_dum collective2_dum collective3_dum collective4_dum ///
		collective5_dum collective6_dum), m
		la var politicalaction "Index of political interest and activity (0-25: more political)"
 
	
// III. HOUSEHOLD SURVEY VARIABLES
******************************************************************************************************************************************************

// 1. HOUSEHOLD ROSTER (HH Section 2) //
	
	global hhmem hhmem1 hhmem2 hhmem3 hhmem4 hhmem5 hhmem6 hhmem7 hhmem8 hhmem9 hhmem10 hhmem11 hhmem12
	
	// Generating year variable
	
		foreach var of varlist *_agems {
		replace `var' = 0 if `var'==.
		gen `var'_yr = `var'/12
		}
		
		foreach x in $hhmem {
		egen `x'_yr = rowtotal(`x'_ageyrs `x'_agems_yr)
		la var `x'_yr "age in years for each HH member"
		replace `x'_yr=. if `x'_yr==0
		}
		drop *_agems_yr
		
	// Generate dummy for HH of 1
	
		gen singlehh = hhsize == 1 if !missing(hhsize)
		la var singlehh "Household consists of only the respondent"

	// DEPENDENCY RATIO

		foreach var of varlist *_ageyrs{
		gen `var'_temp=cond(`var'>65 & `var'!=. | `var'<15 & `var'!=. , 1, 0)
		}
		egen dependent=rowtotal(*_ageyrs_temp)
		la var dependent "Number of dependents: greater than 65 or less than 15 years of age"
		drop *_ageyrs_temp
		replace hhsize = 2 if appid == 10040 /* Enumerator erronously entred 0 */
		gen depratio=dependent/hhsize
		la var depratio "Dependency ratio"

	// GENDER RATIO (male/hhsize and female/hhsize; also number of males and females in the household)

		foreach var of varlist *_sex {
		gen `var'_male = cond(`var'==0,1,0)
		gen `var'_female = cond(`var' ==1,1,0)
		}
		egen nummale = rowtotal(*_sex_male)
		egen numfemale = rowtotal(*_sex_female)
		gen maleratio = nummale/hhsize
		gen femratio = numfemale/hhsize
		la var maleratio "gender ratio: male to hh size"
		la var femratio "gender ratio: female to hh size"
		la var nummale "number of males in the hh"
		la var numfemale "number of females in the hh"
		
		drop *_sex_male *_sex_female

	//	ENROLLMENT RATE : NUMBER OF CHILDREN BETWEEN THE AGE OF 5-16 ENROLLED IN SCHOOL

		foreach var of varlist *_yr {
		gen `var'_temp = cond(`var'<=16 & `var'>=5,1,0)
		}
		
		egen schoolagekidshh = rowtotal(*_yr_temp)
		
		foreach x in $hhmem {
		gen `x'_inschool = cond(`x'_schoolnow == 1 & `x'_yr<=16 & `x'_yr>=5,1,0)
		}
		
		egen kidsinschoolhh = rowtotal (*_inschool) 
		gen enrollrate2 = kidsinschoolhh/schoolagekidshh
		la var enrollrate2 "kids in school divided by schoolage kids (5-16 yrs old): household roster"
		drop schoolagekidshh kidsinschoolhh *_inschool *_yr_temp
		
	// EDUCATION OF THE MOST EDUCATED
	
		foreach x in $hhmem {
		gen `x'_educ_temp = `x'_educ
		replace `x'_educ_temp=. if `x'_educ_temp==20 | `x'_educ_temp==21 | `x'_educ_temp==23			// ASSUMPTION
		replace `x'_educ_temp=. if `x'_educ_temp==24
		}
		egen highesteduc_hh = rowmax(*_educ_temp)
		la var highesteduc_hh "Education level of the most educated person in HH"

		drop *_educ_temp
			
		gen higheduc_hh=0
		foreach x in 13 14 15 16 17 18 19 {
		replace higheduc_hh=1 if highesteduc_hh==`x'
		replace higheduc_hh=. if highesteduc_hh==.
		}
		la var higheduc_hh "At least one HH member with some university or technical education"	

	// ANY NEW ENTRANT 
		
		egen newentrant=anymatch(*_new), values(1)
		la var newentrant "indicator for any new entrant to the household, last 12 months"


// 2. ECONOMIC ACTIVITIES (HH Section 3) //

	/*
		OUTLINE
		
		Collects hours on: work, school work, farming and unpaid domestic work
		Defining economic active individuals as those over 15 years of age (not exactly similar to dependency ratio)
		
		1. Ratio of individuals in certain activity to total individuals (time most spent on)
		2. Number of hours across all hh members by activity: work, school, farm or unpaid domestic work
			a. Ratio of these hours against total hours reported
			b. Ratio of these hours against total econ active hh members
		3. Number of work or farm hours across all hh members for each employment type: self, casual, regular day wage, salaried
			a. Ratio of these hours against total hours reported
			b. Ratio of these hours against total econ active hh members
		4. Anyone doing PSNP work in hh
		5. Factory work: number of hh members doing factory work and dummy for any member doing factory work
		6. Paid farm work (not self employed): number of hh members doing farm work and dummy for any member doing farm work
		
	*/
	
	global hhmem hhmem1 hhmem2 hhmem3 hhmem4 hhmem5 hhmem6 hhmem7 hhmem8 hhmem9 hhmem10
	
	// PER ACTIVITY: RATIO OF INDIVIDUALS DOING ACTIVITY to TOTAL INIDIVIDUALS (using activity time most spent on)

		foreach var of varlist *_yr{
		gen `var'_temp = cond(`var'>=15,1,0)
		}
		egen econactive=rowtotal(*_yr_temp), m
		la var econactive "number of people in the hh greater or equal to the age of 15"
		drop *_yr_temp

		****
		egen numwork1=anycount(*_activity1), values(1)
		egen numschoolwork1=anycount(*_activity1), values(2)
		egen numfarming1=anycount(*_activity1), values(3)
		egen numunpaidwork1=anycount(*_activity1), values(4)
		egen numnoactivity1=anycount(*_activity1), values(5)
		
		gen rworker1 = numwork1/econactive
		gen rschoolwork1 = numschoolwork1/econactive
		gen rfarming1 = numfarming1/econactive
		gen runpaidwork1 = numunpaidwork1/econactive
		gen rnoactivity1 = numnoactivity1/econactive
		
		
		la var numwork1 "# of individuals spending most time on work"
		la var numschoolwork1 "# of individuals spending most time on school work"
		la var numfarming1 "# of individuals spending most time on farm work"
		la var numunpaidwork1 "# of individuals spending most time on farm work"
		la var numnoactivity1 "# of individuals spending most time no activity"
		
		
		la var rworker1 "Ratio: # of working individuals to econ active hh members (time most spent on)"
		la var rschoolwork1 "Ratio: of # of school individuals to econ active hh members (time most spent on)"
		la var rfarming1 "Ratio: # of farming individuals to econ active hh members (time most spent on)"
		la var runpaidwork1 "Ratio: # of unpaid domestic workers to econ active hh members (time most spent on)"
		la var rnoactivity1 "Ratio: # of no primary activity to econ active hh members (time most spent on)"

	// NUMBER OF HOURS: BY ACTIVITY
	// Sum across (i) household members and (ii) primary, secondary and tertiary activities
		
		foreach y in 1 2 3 {
			foreach x in $hhmem {
			gen `x'_work`y'_hrs = `x'_daysmonth`y' * `x'_hoursday`y' if `x'_activity`y'==1
			}
			
			foreach x in $hhmem {
			gen `x'_school`y'_hrs = `x'_daysmonth`y' * `x'_hoursday`y' if `x'_activity`y'==2
			}
			
			foreach x in $hhmem {
			gen `x'_farm`y'_hrs = `x'_daysmonth`y' * `x'_hoursday`y' if `x'_activity`y'==3
			}
			
			foreach x in $hhmem {
			gen `x'_dom`y'_hrs = `x'_daysmonth`y' * `x'_hoursday`y' if `x'_activity`y'==4
			}
		}
		
		foreach x in work school farm dom {
		egen `x'_hours=rowtotal(*_`x'*_hrs), m
		la var `x'_hours "`x': total hours (past month) across all hh members" 
		}
		egen total_hours=rowtotal(work_hours school_hours farm_hours dom_hours), m
		la var total_hours "Total hours reported for work, school, farm work and unpaid domestic work (all hh members)" 
		
		foreach x in work school farm dom {
			gen rhrs1_`x'= `x'_hours/total_hours
			la var rhrs1_`x' "Ratio of hours spent for `x' to total hours reported (all hh members)"
			
			gen rhrs2_`x'= `x'_hours/econactive
			la var rhrs2_`x' "Ratio of hours spent for `x' to total hh members over age 15 (all hh members)"
		}
		
	// NUMBER OF WORK/FARM (IGA) HOURS: BY TYPE OF WORK (self, casual, regular day wage, salaried)
	// Sum across (i) household members and (ii) primary, secondary and tertiary activities
		
		foreach y in 1 2 3 {
			foreach x in $hhmem {
			gen `x'_self`y'_hrs = `x'_work`y'_hrs if `x'_workfor`y'==1
			}
			foreach x in $hhmem {
			replace `x'_self`y'_hrs = `x'_farm`y'_hrs if `x'_workfor`y'==1
			}
			
			foreach x in $hhmem {
			gen `x'_casual`y'_hrs = `x'_work`y'_hrs if `x'_workfor`y'==2
			}
			foreach x in $hhmem {
			replace `x'_casual`y'_hrs = `x'_farm`y'_hrs if `x'_workfor`y'==2
			}
			
			foreach x in $hhmem {
			gen `x'_reg`y'_hrs = `x'_work`y'_hrs if `x'_workfor`y'==3
			}
			foreach x in $hhmem {
			replace `x'_reg`y'_hrs = `x'_farm`y'_hrs if `x'_workfor`y'==3
			}
			
			foreach x in $hhmem {
			gen `x'_salary`y'_hrs = `x'_work`y'_hrs if `x'_workfor`y'==4
			}
			foreach x in $hhmem {
			replace `x'_salary`y'_hrs = `x'_farm`y'_hrs if `x'_workfor`y'==4
			}
		}
		
		foreach x in self casual reg salary {
		egen `x'_hours=rowtotal(*_`x'*_hrs), m
		la var `x'_hours "`x': total hours (past month) across all hh members" 
		}
		egen total_hours_iga=rowtotal(work_hours farm_hours), m
		la var total_hours_iga "Total hours reported for work and farm work (all hh members)" 
		
		foreach x in self casual reg salary {
			gen rhrs1_`x'= `x'_hours/total_hours_iga
			la var rhrs1_`x' "Ratio of hours spent for `x' to total IGA hours reported (all hh members)"
			
			gen rhrs2_`x'= `x'_hours/econactive
			la var rhrs2_`x' "Ratio of hours spent for `x' to total hh members over age 15 (all hh members)"
		}
	
	// ANYONE IN HH DOING PSNP WORK
		egen psnp_any=anymatch(*_psnp*), values(1)
		la var psnp_any "At least one person in hh doing some PSNP work"
		
	// FACTORY WORK
		// Number of people: assuming one person cannot have two factory jobs
		egen facworkers_hh=anycount(*_worktype*), values(1)
		la var facworkers_hh "Number of people in hh doing factory work"
		
		// At least one person in HH with factory job
		gen facworkers_any=cond(facworkers_hh!=0, 1, 0)
		la var facworkers_any "At least 1 person in hh doing factory work"
		
	// FARM WORK
		// Number of people in household doing paid farm work- not for self
		// assuming one person cannot have two paid farm jobs

		foreach y in 1 2 3 {
			foreach x in $hhmem {
			gen `x'_activity`y'_temp = `x'_activity`y' if `x'_workfor`y'!=1
			}
			}
		
		egen farmworkers_hh=anycount(*_activity*_temp), values(3)
		la var farmworkers_hh "Number of people in hh doing farm work not for self"
		
		// At least one person in HH with farm job (not farming for self)
		gen farmworkers_any=cond(farmworkers_hh!=0, 1, 0)
		la var farmworkers_any "At least 1 person in hh doing farm work not for self"
		
	drop *_temp
	drop *_hrs
		

// 3. COMPENSATION AND TRANSFERS (HH Section 4) //

	// TRANSFERS FROM GOV'T & NGO

		foreach x in govngotrans_cash govngotrans_value {
		replace `x' = 0 if govngotrans == 0
		}
			
		egen transngogov=rowtotal(govngotrans_cash govngotrans_value), m
		la var transngogov "Total transfer from Government and NGO (cash or in-kind)"

	// TOTAL TRANSFERS RECEIVED
	
		replace psnpcash = 0 if psnp == 0		
		foreach x in transngogov transin_educ transin_health transin_cerem transin_gen transin_other {
		replace `x' = 0 if transin == 0
		}
		
		egen total_transin=rowtotal(transngogov psnpcash transin_educ transin_health transin_cerem transin_gen transin_other), m
		la var total_transin "Total value of transfers to the household"

	// TOTAL TRANSFERS SENT
	
		foreach x in transout_educ transout_health transout_cerem transout_gen transout_other {
		replace `x' = 0 if transout == 0
		}
		
		egen total_transout=rowtotal(transout_educ transout_health transout_cerem transout_gen transout_other), m
		la var total_transout "Total value of transfers from the household to outside HH"

	// NET TRANSFERS RECEIVED
	
		gen net_trans=total_transin-total_transout
		la var net_trans "Net transfers received over transfers sent"

// 4. CONSUMPTION AND EXPENDITURE (HH Section 5) //

	// FOOD CATEGORIES
		egen cereals_week = rowtotal(birr_teff birr_barley birr_wheat birr_maize birr_sorghum birr_sorghum birr_millet birr_othcereal), m
		
		egen pulses_week = rowtotal(birr_lentils birr_bakela birr_ater birr_shimbra birr_boloke birr_othbeans), m
		egen dairymeat_week= rowtotal(birr_milk birr_butter birr_beef birr_goat birr_chicken birr_eggs birr_othmilkmeat), m  
		egen alcohol_week= rowtotal(birr_tej birr_birra birr_araqi alcoout_birr), m 
		egen drinks_week= rowtotal(birr_soda birr_coffee birr_tea birr_othdrink), m 
		gen chat_week=birr_chat
		egen oil_spices_week= rowtotal(birr_sugar birr_salt birr_oil birr_spices), m 
		egen breadpastarice_week= rowtotal(birr_bread birr_pasta birr_rice), m 
		egen root_week= rowtotal(birr_potato birr_enset1 birr_enset2 birr_sweetpot), m  
		egen vegfruit_week= rowtotal(birr_onion birr_garlic birr_tomato birr_guaya birr_cabbage birr_abish birr_othveg birr_fruit), m   
		gen othfood_week= birr_othfood
		egen eatdrinkout_week= rowtotal(eatout_birr teaout_birr), m

	// NON-FOOD CATEGORIES
		gen cigs_month=cigs
		gen chat_month=chat
		gen mobilecards_month=mobilecards 
		
		egen household_month= rowtotal(matches batteries candles laundrysoap handsoap cosmetics transport charcoal firewood kerosene othfuel), m 
		egen meds_4months= rowtotal(modernmeds traditionalmeds), m 
		egen educ_4months= rowtotal(schoolfees otheduc), m
		egen clothes_4months= rowtotal(clothesadultmen clothesadultwomen clothesboys clothesgirls), m 
		egen ceremony_4months= rowtotal(iddir ceremonial church), m 
		egen utilities_4months= rowtotal(electricity watercharge), m 
		gen servants_4months=servants
		gen repairs_4months=repairs

		summ cereals_week pulses_week dairymeat_week alcohol_week drinks_week chat_week oil_spices_week ///
		breadpastarice_week root_week  vegfruit_week othfood_week eatdrinkout_week cigs_month chat_month ///
		mobilecards_month household_month meds_4months educ_4months clothes_4months ceremony_4months ///
		utilities_4months servants_4months repairs_4months

	// FOOD CONSUMPTION VARIABLE (MONTH)
		*X* leaving chat_week out as otherwise double counting
		
		egen food_month= rowtotal(cereals_week pulses_week dairymeat_week drinks_week oil_spices_week breadpastarice_week root_week vegfruit_week othfood_week eatdrinkout_week), m
		replace food_month = food_month*4.28

	// NON-FOOD CONSUMPTION VARIABLE (MONTH)
		egen nonfood_month1= rowtotal(cigs_month chat_month mobilecards_month household_month), m
		gen alcohol_week_temp = alcohol_week*4.28
		egen nonfood_month2= rowtotal(nonfood_month1 alcohol_week_temp), m

		egen nonfood_month3 = rowtotal(meds_4months educ_4months clothes_4months utilities_4months servants_4months ceremony_4months repairs_4months), m
		gen nonfood_month4 = nonfood_month3*.25

		egen nonfood_month = rowtotal(nonfood_month2 nonfood_month4), m

	// TOTAL CONSUMPTION VARIABLE (MONTH)
		egen cons_month= rowtotal(food_month nonfood_month), m
		summ food_month nonfood_month cons_month if wave != "23m"

	// PER CAPITA CONSUMPTION VARIABLES
		gen nonfoodpc=nonfood_month/hhsize
		gen foodpc=food_month/hhsize
		gen conspc=cons_month/hhsize

		summ conspc foodpc nonfoodpc
		bys foodsituation2: summ conspc foodpc nonfoodpc

	// LABELING CONSUMTPION VARIABLES
			label var conspc "consumption per month per capita"
			label var foodpc "food per month per capita"
			label var nonfoodpc "nonfood consumption per month per capita"

			label var cons_month "consumption per month"
			label var food_month "food per month"
			label var nonfood_month "nonfood consumption per month"

			label var  cereals_week "birr_teff+birr_barley+birr_wheat+birr_maize+birr_sorghum+birr_sorghum+birr_millet+birr_othcereal"
			label var  pulses_week "birr_lentils+birr_bakela+birr_ater+birr_shimbra+birr_boloke+birr_othbeans"
			label var dairymeat_week "birr_milk+birr_butter+birr_beef+birr_goat+birr_chicken+birr_eggs+birr_othmilkmeat"  
			label var  alcohol_week "birr_tej+birr_birra+birr_araqi+alcoout_birr" 
			label var  drinks_week  "birr_soda+birr_coffee+birr_tea +birr_othdrink" 
			label var  chat_week   "birr_chat" 
			label var  oil_spices_week   "birr_sugar+birr_salt+birr_oil+birr_spices" 
			label var  breadpastarice_week  "birr_bread+birr_pasta+birr_rice" 
			label var  root_week   "birr_potato+birr_enset1+birr_enset2+birr_sweetpot"  
			label var  vegfruit_week  "birr_onion+birr_garlic+birr_tomato+birr_guaya+birr_cabbage+birr_abish+birr_othveg +birr_fruit"  
			label var  othfood_week  "birr_othfood"
			label var  eatdrinkout_week   "eatout_birr+teaout_birr"
			label var  cigs_month   "cigs" 
			label var  chat_month   "chat" 
			label var  mobilecards_month    "mobilecards" 
			label var  household_month    "matches+batteries+candles+laundrysoap+handsoap+cosmetics+transport+charcoal+firewood+kerosene+othfuel" 
			label var  meds_4months   "modernmeds+traditionalmeds" 
			label var  educ_4months   "schoolfees+otheduc"
			label var  clothes_4months   "clothesadultmen+clothesadultwomen+clothesboys+clothesgirls" 
			label var  ceremony_4months  "iddir+ceremonial+church" 
			label var  utilities_4months  "electricity+watercharge" 
			label var  servants_4months  "servants"
			label var  repairs_4months  "repairs"
		
// 5. FOOD SECURITY (Section 6) //

	// CHILD FOOD SECURITY

		recode childfood1 childfood2 childfood3 childfood4 childfood5 (4=3) (3=2) (2=1) (1=0),  pre(rank_) 
		egen childfood_security=rowtotal(rank_childfood*)
		la var childfood_security "Additive index of child food security, 0-15 (higher food security)"

	// ADULT FOOD SECURITY
		
		recode adultfood2 adultfood3 adultfood4 adultfood5 (4=3) (3=2) (2=1) (1=0), pre(rank_)
		recode adultfood1 (4=0) (3=1) (2=2) (1=3), pre(rank_) 
		egen adultfood_security=rowtotal(rank_adultfood* )
		la var adultfood_security "Additive index of adult food security, 0-15 (higher food security)"

	// OTHER SPENDING ANXIETY
		
		recode educ_anxiety health_anxiety othessentials_anxiety other_anxiety (4=0) (3=1) (2=2) (1=3), pre(rank_)
		egen anxiety=rowtotal(rank_*_anxiety)
		la var anxiety "Additive index of education, health, and other anxiety, 0-12 (higher anxiety)"


// 6. DWELLING AND WEALTH (HH Section 7) //

	// OWN HOME

		recode hometen (1=1)(2/7=0)(else=.), gen (home_own) lab(yesno)
		la var home_own "Owns home"
		
	// ROOM PER PERSON

		gen roompc=rooms/hhsize
		la var roompc "room per person"

	// RENT HOME FROM A PRIVATE PERSON

		recode hometen (4=1)(1/3 5/7=0)(else=.), gen(home_rentpr) lab(yesno)
		lab var home_rentpr "Rents home, private person"

	// WALLS CONSTRUCTED FROM IMPROED MATERIALS

		recode walls (1/4=1) (5/8=0)(else=.), gen(impr_walls) lab(yesno)
		lab var impr_walls "Walls constructed of improved materials (brick, concrete)"
		
	// ROOF CONSTRUCTED FROM IMROVED MATERIALS

		recode roof (1 2=1) (3/6=0)(else=.), gen(impr_roof) lab(yesno)
		lab var impr_roof "Roof constructed of improved materials (iron, concrete)"

	// FLOOR CONSTRUCTED FROM IMPROVED MATERIAL
		
		recode floor (2/5=1) (1 6=0)(else=.), gen(impr_floor) lab(yesno)
		lab var impr_floor "Floor constructed of improved materials (tiles, concrete)"
		
	// WATER SOURCE (TAP, COMPOUND, PROTECTED, UNPROTECTED 

		recode water (1=1)(2/8=0)(else=.), gen(water_taphouse) lab(yesno)
		lab var water_taphouse "Tap inside house"
		recode water (2=1)(1 3/8=0)(else=.), gen(water_tapcompound) lab(yesno)
		lab var water_tapcompound "Tap inside compound"
		recode water (3/5 7=1)(1 2 6 8=0)(else=.), gen(water_protect) lab(yesno)
		lab var water_protect "Tap or other protected source outside compound"
		recode water (6 8=1)(1/5 7=0)(else=.), gen(water_unprotect) lab(yesno)
		lab var water_unprotect "Unprotected source"
		
	// TOILET (FLUSH, PIT PRIVATE, PIT SHARED)

		recode toilet (1 2=1)(3/5=0)(else=.), gen(toil_flush) lab(yesno)
		lab var toil_flush "Flush toilet"                 
		recode toilet (3=1)(1 2 4 5=0)(else=.), gen(toil_pitprivate) lab(yesno)
		lab var toil_pitprivate "Private pit latrine"                
		recode toilet (4=1)(1 2 3 5=0)(else=.), gen(toil_pitshare) lab(yesno)
		lab var toil_pitshare "Shared pit latrine"                
		
	// KITCHEN (DUMMY FOR MODERN, SEMI-MODERN,PRIVATE TRADITIONAL, AND SHARED TRADITIONAL) 

		recode kitchen (1 2=1)(3/7=0)(else=.), gen(kitch_modern) lab(yesno)
		lab var kitch_modern "Modern kitchen, private or shared"   
		recode kitchen (3 4=1)(1 2 5/7=0)(else=.), gen(kitch_semimodern) lab(yesno)
		lab var kitch_semimodern "Semi-modern kitchen, private or shared"   
		recode kitchen (5=1)(1/4 6 7=0)(else=.), gen(kitch_trad_priv) lab(yesno)
		lab var kitch_trad_priv "Private traditional kitchen"                 
		recode kitchen (6=1)(1/5 7=0)(else=.), gen(kitch_trad_share) lab(yesno)
		lab var kitch_trad_share "Shared traditional kitchen"                
		recode kitchen (7=1)(1/6=0)(else=.), gen(kitch_none) lab(yesno)
		lab var kitch_none "No kitchen"   

	// COOKING (DUMMY FOR WOOD & CHARCOAL, GAS & ELECTRICITY)

		recode cooking (4/7=1)(1/3 8 9=0)(else=.), gen(cook_woodchar) lab(yesno)
		lab var cook_woodchar "Use wood, charcoal for cooking"
		recode cooking (1/3=1)(4/9=0)(else=.), gen(cook_gaselect) lab(yesno)
		lab var cook_gaselect "Use gas, electricity for cooking"
		
	// BATHING (DUMMY FOR USE OF PAID FACILITY, NO BATHING FACILITY, PRIVATE OR SHARED SHOWER OR TUB)

		recode bathing (7=1)(1/6 8=0)(else=.), gen(bath_pay) lab(yesno)
		lab var bath_pay "Bathe in paid facility" 
		recode bathing (8=1)(1/7=0)(else=.), gen(bath_none) lab(yesno)
		lab var bath_none "No bathing facility" 
		recode bathing (1/6=1)(7 8=0)(else=.), gen(bath_tubshower) lab(yesno)
		lab var bath_tubshower "Private or shared shower or tub"   

	// LAND (DUMMY FOR ACCESS TO LAND)

		gen haslandbus=cond(landbus>0 & landbus!=.,1,0)
		lab var haslandbus "Has access to land for business use"
		replace haslandbus=. if landbus==.
		gen haslandrent=cond(landrent>0 & landrent!=.,1,0)
		lab var haslandrent "Has access to land that is rented out"
		replace haslandrent=. if landrent==.
		gen haslandcult=cond(landcult>0 & landcult!=.,1,0)
		lab var haslandcult "Has access to land that is being cultivated"
		replace haslandcult=. if landcult==.
		gen haslandfallow=cond(landfallow>0 & landfallow!=.,1,0)
		replace haslandfallow=. if landfallow==.	
		lab var haslandfallow "Has access to land that is left fallow"
		
		egen hasland=rowtotal(haslandbus haslandrent haslandcult haslandfallow), m
		recode hasland (1 2 3 4=1)
		lab var hasland "Has access to land"

	// GENERATE WEALTH INDEX	
		
			desc home_own home_rentpr rooms roompc impr_walls impr_roof impr_floor water_taphouse ///
			water_tapcompound water_protect water_unprotect toil_flush toil_pitprivate toil_pitshare kitch_trad_priv ///
			kitch_trad_share kitch_modern kitch_semimodern kitch_none cook_woodchar cook_gaselect bath_pay bath_none ///
			bath_tubshower fanos radio bike watch jewelry phone tv videocasette satellite refrigerator ///
			mitad stove sewing cattle goats donkeys poultry hasland hungry
			
			*X* haslandfallow haslandcult haslandrent haslandbus  replaced with hasland // bsm 2012.03.26
			*X* water_taphouse toil_flush bike donkeys haslandrent impr_roof : Dropped because of Zero variance
			
			factor home_own home_rentpr rooms roompc impr_walls impr_floor  ///
			water_tapcompound water_protect toil_pitprivate toil_pitshare kitch_trad_priv ///
			kitch_trad_share kitch_semimodern kitch_none cook_woodchar cook_gaselect bath_pay bath_none ///
			bath_tubshower fanos radio  watch jewelry phone tv videocasette satellite refrigerator ///
			mitad stove water_unprotect kitch_modern

			predict consdur
				qui sum consdur
				qui replace consdur = (consdur-r(mean))/r(sd)
			lab var consdur "Wealth index: Consumption Durables"
			
			factor sewing cattle goats poultry hasland 
			predict proddur
				qui sum proddur
				qui replace proddur = (proddur-r(mean))/r(sd)
			lab var proddur "Wealth index: Production Durables"
		
			
// 7. HOUSEHOLD TIME USE (HH Section 8)

	// GENERATE PROPORTION OF EACH ACTIVITY AT THE HH LEVEL	
	
		egen domestichh = rowtotal (*_domestic), m
		egen caringhh = rowtotal (*_caring), m
		egen fambushh = rowtotal (*_hhwork), m
		egen workhh = rowtotal (*_work), m
		egen schoolhh = rowtotal (*_school), m
		egen leisurehh = rowtotal (*_leisure), m
		egen tothhworkhrs = rowtotal (domestichh caringhh fambushh workhh schoolhh leisurehh), m
		
		gen sharedomestic = (domestichh/tothhworkhrs)^2
		gen sharecaring = (caringhh/tothhworkhrs)^2
		gen sharefambus = (fambushh/tothhworkhrs)^2
		gen sharework = (workhh/tothhworkhrs)^2
		gen shareschool = (schoolhh/tothhworkhrs)^2
		gen shareleisure = (leisurehh/tothhworkhrs)^2
		
		egen prehhi = rowtotal(sharedomestic sharecaring sharefambus sharework shareschool shareleisure), m
		gen hhi = sqrt(prehhi)
		drop prehhi sharedomestic sharecaring sharefambus sharework shareschool shareleisure
		la var hhi "Herfindahl-Hirchman index of Diversification: Higher index more specialization"
		
		la var domestichh "Total number of hours spent by hh members doing domestic tasks"
		la var caringhh "Total number of hours spent by hh members caring for others"
		la var fambushh "Total number of hours spent by hh members working on family business"
		la var workhh "Total number of hours spent by hh members doing income earning work"
		la var schoolhh "Total number of hours spent by hh members in school work"
		la var leisure "Total number of hours spent by hh members on leisure"
		la var tothhworkhrs " Total number of hours for all activities for all hh members"
		
// 8. PERCEPTION OF INDIVIDUAL (HH Section 9) //

	// INDIVIDUAL PERCEPTION INDEX (HIGHER VALUE: POSITIVE PERCEPTION OF INDIVIDUAL IN HH)

		recode enoughchores enoughtime enoughmoney consultlargeexpense consultsmallexpense consultbigdecisions /// 
		consultfirst respect valueopinionhh valueopinionpersonal (4=0) (3=1) (2=2) (1=3), pre(r_)

		egen indperception=rowtotal(r_enoughchores r_enoughtime r_enoughmoney r_consultlargeexpense r_consultsmallexpense r_consultbigdecisions r_consultfirst r_respect r_valueopinionhh r_valueopinionpersonal), m
		la var indperception "Perception of individual (job applicant) in the HH, 0-30 (positive perception)"

********************************************
saveold "$ILEdata\ILE.el_constructed.dta", replace 
********************************************
	
exit
