/* **************************************************
Analyze firm data from Fafchamps and Quinn **********
****************************************************/

/* Note: For Table C1, the publication should have reported the actual N rather than the percentage listed. */

*****************************************************
/* SECTION 1 - Import Data and Construct Variables */
*****************************************************

/* Merge F-Q dataset with extra Blattman data */
use "$ILEdata\raw\Firm_Survey_IPA.dta", clear
la define interested 1 "Not highly interested" 2 "Not interested" 3 "In-different" 4 "Interested" 5 "Very interested"
la val l4_32 interested
rename s1 scrambled_id
gen extrafirms = 1

qui append using "$ILEdata\raw\FirmBaselineAnon.dta"
rename scrambled_id firmid
replace extrafirms = 0 if missing(extrafirms)

/* Add indicator for firms in our study */
/* Note: Burayu = 171; Maa = 1001; Redfox = 1011; Jittu == 1013; Anbessa == 59 */
/* Note: we should double check Burayu and Anbessa to make sure I correctly identified them */
gen studyfirm = (firmid == 1009 | firmid == 1001 | firmid == 1011 | firmid == 1013 | firmid == 59)
la var studyfirm "In Blattman-Dercon Sample"

/* Recode missings */
foreach v of varlist _all {
	capture confirm numeric variable `v'
		if !_rc {
			replace `v' = . if (`v' == -7 | `v' == -8 | `v' == -9)
		}
}

/* Clean/recode sectors */
replace s22 = 13 if (firmid == 1005 | firmid == 1006 | firmid == 1008 | firmid == 1010 | firmid == 1011 | firmid == 1012 | firmid == 1013 | firmid == 1014 | firmid == 1015 | firmid == 1017 | firmid == 1018 | firmid == 1023 | firmid == 413 | firmid == 348 | firmid == 284 | firmid == 69 | firmid == 90 | firmid == 482 )
replace s22 = 2 if (firmid == 169 | firmid == 381)
replace s22 = 3 if (firmid == 147 | firmid == 246 | firm == 1009 | firmid == 1007 )
local lab: val la s22
la def `lab' 13 "Agriculture", add
la val s22 `lab'

/* Add Tigray regions */
replace s8_zone = 9 if (firmid == 1001 | firmid == 1002 | firmid == 1003 | firmid == 1004 | firmid == 1007 | firmid == 1016 | firmid == 1019 | firmid == 1020 | firmid == 1021 | firmid == 1022 )
local lab: val la s8_zone
la def `lab' 9 "Tigray", add
la val s8_zone `lab'

/* Generate variables for comparison */
gen age = 2014 - g5
qui sum age, d
replace age = r(p99) if age>r(p99) & !missing(age)
la var age "Number of years the firm has been in business (as of 2014)"

gen inaddis = s8_zone!=9 & !missing(s8_zone)
la var inaddis "In Addis Ababa" 

gen govtowned = g7_3 >50 if !missing(g7_3)
la var govtowned "Majority share government owned"

gen domesticowned = g7_1 >50 if !missing(g7_1)
la var domesticowned "Majority share domestically owned"

gen foreignowned = g7_2 >50 if !missing(g7_2)
la var foreignowned "Majority share foreign owned"

gen internatlcert = m17 == 1 if m17 != -7 & !missing(m17)
la var internatlcert "Certified international quality"

egen avrevenue = rowmean (p1_1_1 p1_1_2)
la var avrevenue "Average annual sales revenue (2004-2006), 000s ETB"

gen logrev = ln(avrevenue)
replace logrev = 0 if avrevenue == 0
la var logrev "Log of average sales revenue"

egen avprofit = rowmean (p1_10_1 p1_10_2)
la var avprofit "Average annual profits (2004-2006), 000s ETB"

gen competitors = c3
la var competitor "Number of competitors within 15 minute walk"

gen employees = l1_1_n
qui sum employees, d
replace employees = r(p99) if employees>r(p99) & !missing(employees)
la var employees "Number of persons employed"

gen productionemployees = l1_9_n
qui sum productionemployees, d
replace productionemployees = r(p99) if productionemployees>r(p99) & !missing(productionemployees)
la var productionemployees "Number of persons employed in production"

gen productionsalary = l1_15_w
qui sum productionsalary, d
replace productionsalary = r(p99) if productionsalary>r(p99) & !missing(productionsalary)
replace productionsalary = productionsalary*131.4/66.27285
la var productionsalary "Average starting salary of production workers (march 2010 birr)"

gen productionsalary1yrago = l1_16_w
qui sum productionsalary1yrago, d
replace productionsalary1yrago = r(p99) if productionsalary1yrago>r(p99) & !missing(productionsalary1yrago)
replace productionsalary1yrago = productionsalary1yrago*131.4/66.27285
la var productionsalary1yrago "Average starting salary of production workers, 12 months ago (march 2010 birr)"


gen leaverate = l2_1_w/l1_9_n
qui sum leaverate, d
replace leaverate = r(p99) if leaverate>r(p99) & !missing(leaverate)
la var leaverate "Ratio of productions workers who left in last year to current production workers"

gen quitrate = l2_4_w/l1_9_n
qui sum quitrate, d
replace quitrate = r(p99) if quitrate>r(p99) & !missing(quitrate)
la var quitrate "Ratio of productions workers who quit in last year to current production workers"

gen edushare = 1-l1_19_w_5/l1_9_n
la var edushare "Share of production workers who completed high school"

gen newhireedu = l3_5_w >= 6 if !missing(l3_5_w)
la var newhireedu "Typical new production hire completed high school"

gen wouldrandomize = l4_32>=4 if l4_32!=-9
la var wouldrandomize "Would participate in study using randomization"

gen agriculture = s22 == 13 if !missing(s22)
la var agriculture "Firm is in agricultural sector"

gen intigray = s8_zone == 9 if !missing(s8_zone)
replace intigray = 0 if missing(intigray)
la var intigray "In Tigray region"

gen garments = (s23 == 1311 | s23 == 1312 | s23 == 1313 | s23 == 1391 | s23 == 1392 | s23 == 1394 | s23 == 1399 | s23 == 1410 | s23 == 1430 | s23 == 1511 | s23 == 1512)
	la var garments "Produces garments, apparel, or textiles"

gen shoes = (s23 == 1520)
	la var shoes "Produces footwear"
	
gen garmentshoes = (garments == 1 | shoes == 1)
	la var garmentshoes "Produces garments, apparel, textiles, or shoes"

gen food = (s23 == 1010 | s23 == 1040 | s23 == 1061 | s23 == 1062 | s23 == 1071 | s23 == 1073 | s23 == 1074 | s23 == 1079 | s23 == 1080 | s23 == 1101 | s23 == 1102 | s23 == 1103 | s23 == 1104)
	la var food "Produces food or beverages"
	
/* 2. Create comparison tables */
drop if employees<10
gen all = 1
gen largefirms = employees >= 50
gen managlargefirms = (employees>=50 & (s22 == 3 | s22 == 13))

local group_A "((inaddis & agriculture == 0) | intigray == 1 | (agriculture == 1))"
local group_B "inaddis & agriculture == 0"
local group_C "agriculture == 1"
local group_D "intigray == 1 & agriculture == 0"
local i = 0
foreach x in age inaddis govtowned domesticowned foreignowned internatlcert avrevenue avprofit competitors employees productionemployees productionsalary productionsalary1yrago edushare newhireedu leaverate quitrate wouldrandomize {
	local ++i
	local var_`i': var la `x' 
	foreach g in A B C D  {
		qui sum `x' if managlargefirms & `group_`g'', d
			local group`g'mean_`i' = r(mean)
			local group`g'med_`i' = r(p50)
			local group`g'count_`i' = r(N) 
		qui sum `x' if studyfirm & `group_`g''
			local study`g'mean_`i' = r(mean)
		gen `x'_`g' = 0 if managlargefirms & `group_`g''
			replace `x'_`g' = 1 if managlargefirms & `group_`g'' & `x'< `study`g'mean_`i''
		egen `x'_`g'_sum = total(`x'_`g')
		qui sum `x'_`g'_sum
			local group_`g'_pct_`i' = r(mean)/`group`g'count_`i''
		drop `x'_`g' `x'_`g'_sum
	}
}
local ++i
local var_`i' "Observations"
foreach g in A B C D {
	qui count if managlargefirms & `group_`g''
		local group`g'mean_`i' = r(N)
	qui count if studyfirm & `group_`g''
		local study`g'mean_`i' = r(N)
}
local I = `i'
preserve
	clear
	set obs `I'
	foreach v in var groupAmean groupAmed studyAmean groupBmean groupBmed studyBmean groupCmean groupCmed studyCmean groupDmean groupDmed studyDmean group_A_pct {
		gen `v' = ""
		forv i = 1/`I' {
			qui replace `v' = "``v'_`i''" in `i'
		}
	}
	destring group* study*, replace
	export excel using "$ILEtables\Table C1.xlsx", sheet("raw") sheetreplace firstrow(var)
restore

/* 4. Find conditional correlations in wages */

/* Impute logrev */
qui reg internatlcert inaddis intigray agriculture garmentshoes food foreignowned productionemployees wouldrandomize
	predict internatlcert_imp, xb
	replace internatlcert_imp = internatlcert if !missing(internatlcert)
	la var internatlcert_imp "`: var la internatlcert'"
qui reg edushare inaddis intigray agriculture garmentshoes food foreignowned internatlcert_imp productionemployees wouldrandomize
	predict edushare_imp, xb
	replace edushare_imp = edushare if !missing(edushare)
	la var edushare_imp "`: var la edushare'"
qui reg competitors inaddis intigray agriculture garmentshoes food foreignowned internatlcert_imp productionemployees edushare_imp wouldrandomize
	predict competitors_imp, xb
	replace competitors_imp =  competitors if !missing(competitors)
	la var competitors_imp "`: var la competitors'"
qui reg age inaddis intigray agriculture garmentshoes food foreignowned internatlcert_imp competitors_imp productionemployees edushare_imp wouldrandomize
	predict age_imp, xb
	replace age_imp = age if !missing(age)
	la var age_imp "`: var la age'"
qui reg logrev age_imp inaddis intigray agriculture garmentshoes food foreignowned internatlcert_imp competitors_imp productionemployees edushare_imp wouldrandomize
	predict logrev_imp, xb
	replace logrev_imp = logrev if !missing(logrev)
	la var logrev_imp "`: var la logrev'"
	
local i = 0
foreach y in all largefirms managlargefirms {
	local ++i
	local c`i' = "`y'"
	local j = 0
	reg productionsalary studyfirm age_imp inaddis intigray agriculture garmentshoes food foreignowned internatlcert_imp logrev_imp competitors_imp productionemployees edushare_imp wouldrandomize i.s22 if `y'
	foreach v in studyfirm age_imp inaddis intigray agriculture garmentshoes food foreignowned internatlcert_imp logrev_imp competitors_imp productionemployees edushare_imp wouldrandomize _cons {
		local ++j
		local r`j' = "`:var label `v''"
		local b_`i'_`j' = _b[`v']
		local se_`i'_`j' = _se[`v']
		local p_`i'_`j' = 2*ttail((e(N)-1)-e(df_m),abs(_b[`v']/_se[`v']))
		/* Format standard errors */
			foreach x in `i'_`j' {
				local se_`x' = round(`se_`x'',.001)
				/* Occasionally the round function gives output 
				like 1.2340000000000001. Here, we truncate those outputs */
					local dec = ""
					local dec = substr("`se_`x''",strpos("`se_`x''","."),.)
					if (strlen("`dec'")>4 ) local se_`x' = substr("`se_`x''",1,strpos("`se_`x''",".")+3)
					if (strlen("`dec'")==3) local se_`x' = "`se_`x''0"
					if (strlen("`dec'")==2) local se_`x' = "`se_`x''00"
					if (strlen("`dec'")<2 ) local se_`x' = "`se_`x''000"
				/* Put some brackets and asterisks on the standard errors */
					local se_`x' = "[`se_`x'']"
					if (`p_`x''<=.1 ) local se_`x' = "`se_`x''*"
					if (`p_`x''<=.05) local se_`x' = "`se_`x''*"
					if (`p_`x''<=.01) local se_`x' = "`se_`x''*"
		}
	}
	local ++j
	local r`j' = "R-Squared"
	local b_`i'_`j' = e(r2)
	local ++j
	local r`j' = "Observations"
	local b_`i'_`j' = e(N)	
}
local I = `i'
local J = `j'
preserve
	clear
	qui set obs `J'
	qui gen var = ""
	forv j = 1/`J' {
		qui replace var = "`r`j''" in `j'
	}
	forv i = 1/`I' {
		foreach x in b se {
			qui gen `c`i''_`x' = ""
			forv j = 1/`J' {
				qui replace `c`i''_`x' = "``x'_`i'_`j''" in `j'
			}
		}
	}
	destring *_b, replace
	export excel using "$ILEtables\Table C2.xlsx", sheet("raw") sheetreplace firstrow(var)
restore
